@@ -8,9 +8,28 @@
 //
 // Author(s): andy_gotz, P.Verdier
 //
-// $Revision: 2.38 $
+// $Revision: 2.44 $
 //
 // $Log: DataBase.h,v $
+// Revision 2.44  2009/04/06 13:11:09  pascal_verdier
+// DbMySqlSelect command added.
+//
+// Revision 2.43  2009/04/06 12:19:45  taurel
+// - Fix compilation problem with Solaris CC
+//
+// Revision 2.42  2009/04/04 18:46:28  taurel
+// Fixed warnings when compiled with gcc 4.3
+//
+// Revision 2.41  2009/04/04 17:57:50  taurel
+// Device now inherits from Device_4Impl
+// Get env. variable from Tango lib to support tangorc file
+//
+// Revision 2.40  2009/01/30 08:17:51  taurel
+// - Added DbGetDeviceWideList command
+//
+// Revision 2.39  2008/05/23 08:33:28  taurel
+// - MIscellaneous bug fixes due to Windows compilation and tests
+//
 // Revision 2.38  2008/04/10 06:58:43  taurel
 // - Port changes to Solaris CC compiler
 //
@@ -90,7 +109,12 @@
 #ifndef _DATABASE_H
 #define _DATABASE_H
 
+
 #include <tango.h>
+#ifdef WIN32
+#include <my_global.h>
+#endif
+
 #include <mysql.h>
 #include <update_starter.h>
 
@@ -137,6 +161,21 @@ static LARGE_INTEGER	cpu_freq;
 
 namespace DataBase_ns {
 
+class DummyDev: public Tango::Connection
+{
+public:
+	DummyDev():Tango::Connection(true) {};
+
+	virtual string get_corba_name(bool) {string str;return str;}
+	virtual string build_corba_name() {string str;return str;}
+	virtual int get_lock_ctr() {return 0;}
+	virtual void set_lock_ctr(int) {};
+
+	virtual string dev_name() {string str;return str;}
+
+	int get_env_var(const char *cc,string &str_ref) {return Tango::Connection::get_env_var(cc,str_ref);}
+};
+
 /**
  * Class Description:
  * This class manage the TANGO database.
@@ -147,7 +186,7 @@ namespace DataBase_ns {
  */
 
 
-class DataBase: public Tango::Device_3Impl
+class DataBase: public Tango::Device_4Impl
 {
 public :
 	//	Add your own data members here
@@ -516,6 +555,10 @@ public :
  *	Execution allowed for DbGetDeviceList command.
  */
 	virtual bool is_DbGetDeviceList_allowed(const CORBA::Any &any);
+/**
+ *	Execution allowed for DbGetDeviceWideList command.
+ */
+	virtual bool is_DbGetDeviceWideList_allowed(const CORBA::Any &any);
 /**
  *	Execution allowed for DbGetDeviceMemberList command.
  */
@@ -660,6 +703,10 @@ public :
  *	Execution allowed for DbDeleteAllDeviceAttributeProperty command.
  */
 	virtual bool is_DbDeleteAllDeviceAttributeProperty_allowed(const CORBA::Any &any);
+/**
+ *	Execution allowed for DbMySqlSelect command.
+ */
+	virtual bool is_DbMySqlSelect_allowed(const CORBA::Any &any);
 /**
  * This command gets the device state (stored in its <i>device_state</i> data member) and returns it to the caller.
  *	@return	State Code
@@ -939,12 +986,19 @@ public :
  */
 	Tango::DevVarLongStringArray	*db_get_device_info(Tango::DevString);
 /**
- * 
- *	@param	argin	
- *	@return	
+ * Get a list of devices for specified server and class.
+ *	@param	argin	argin[0] : server name\nargin[1] : class name
+ *	@return	The list of devices for specified server and class.
  *	@exception DevFailed
  */
 	Tango::DevVarStringArray	*db_get_device_list(const Tango::DevVarStringArray *);
+/**
+ * Get a list of devices whose names satisfy the filter.
+ *	@param	argin	filter
+ *	@return	list of exported devices
+ *	@exception DevFailed
+ */
+	Tango::DevVarStringArray	*db_get_device_wide_list(Tango::DevString);
 /**
  * 
  *	@param	argin	
@@ -1186,6 +1240,14 @@ public :
  *	@exception DevFailed
  */
 	void	db_delete_all_device_attribute_property(const Tango::DevVarStringArray *);
+/**
+ * This is a very low level command.
+ *	It executes the specified  SELECT command on TANGO database and returns its result without filter.
+ *	@param	argin	MySql Select command
+ *	@return	MySql Select command result
+ *	@exception DevFailed
+ */
+	Tango::DevVarLongStringArray	*db_my_sql_select(Tango::DevString);
 
 //@}
 
@@ -1225,7 +1287,7 @@ protected :
 	omni_mutex		starter_mutex;
 	omni_mutex		sem_wait_mutex;
 				
-	void create_connection_pool(char *,char *);
+	void create_connection_pool(const char *,const char *);
 
 	inline void update_timing_stats(TimeVal before, TimeVal after, std::string command)
 	{
