@@ -1,7 +1,7 @@
 static const char *ClassId    = "$Id: DataBaseClass.cpp,v 2.38 2009/04/06 13:11:08 pascal_verdier Exp $";
 static const char *CvsPath    = "$Source: /cvsroot/tango-cs/tango/cppserver/dbase/DataBaseClass.cpp,v $";
 static const char *SvnPath    = "$HeadURL: $";
-static const char *TagName    = "$Name:  $";
+static const char *TagName    = "$Name: DataBase-Release_4_5 $";
 static const char *HttpServer = "http://www.esrf.fr/computing/cs/tango/tango_doc/ds_doc/";
 static const char *RcsId = "$Header: /cvsroot/tango-cs/tango/cppserver/dbase/DataBaseClass.cpp,v 2.38 2009/04/06 13:11:08 pascal_verdier Exp $";
 //+=============================================================================
