@@ -1,4 +1,4 @@
-static const char *RcsId = "$Header: /cvsroot/tango-cs/tango/cppserver/dbase/DataBaseUtils.cpp,v 2.10 2009/04/27 08:01:40 taurel Exp $";
+static const char *RcsId = "$Header: /cvsroot/tango-cs/tango/cppserver/dbase/DataBaseUtils.cpp,v 2.13 2009/09/10 15:04:02 taurel Exp $";
 //+=============================================================================
 //
 // file :         DataBaseUtils.cpp
@@ -15,6 +15,10 @@ static const char *RcsId = "$Header: /cvsroot/tango-cs/tango/cppserver/dbase/Dat
 //                FRANCE
 //
 
+#if HAVE_CONFIG_H
+#include <ac_config.h>
+#endif
+
 #include <tango.h>
 #include <DataBase.h>
 #include <DataBaseClass.h>
@@ -336,6 +340,7 @@ void DataBase::init_timing_stats()
 	timing_stats_map["DbImportEvent"] = new TimingStatsStruct;
 	timing_stats_map["DbGetDataForServerCache"] = new TimingStatsStruct;
 	timing_stats_map["DbPutClassProperty"] = new TimingStatsStruct;
+	timing_stats_map["DbMySqlSelect"] = new TimingStatsStruct;
 
 	timing_stats_size = timing_stats_map.size();
 	timing_stats_average = new double[timing_stats_size];
@@ -725,7 +730,11 @@ void DataBase::purge_att_property(const char *table,const char *field,const char
 
 void DataBase::create_connection_pool(const char *mysql_user,const char *mysql_password)
 {
+#ifndef HAVE_CONFIG_H
 	char *database = (char *)"tango";
+#else
+	char *database = (char *)TANGO_DB_NAME;
+#endif
 
 	if (mysql_user != NULL && mysql_password != NULL)
 	{	
