@@ -1,4 +1,4 @@
-static const char *RcsId = "$Header: /cvsroot/tango-cs/tango/cppserver/starter/PingThread.cpp,v 1.4 2006/11/10 14:53:28 pascal_verdier Exp $";
+static const char *RcsId = "$Header: /cvsroot/tango-cs/tango/cppserver/starter/PingThread.cpp,v 1.7 2008/12/16 10:44:57 pascal_verdier Exp $";
 //+=============================================================================
 //
 // file :         StarterUtil.cpp
@@ -9,9 +9,18 @@ static const char *RcsId = "$Header: /cvsroot/tango-cs/tango/cppserver/starter/P
 //
 // $Author: pascal_verdier $
 //
-// $Revision: 1.4 $
+// $Revision: 1.7 $
 //
 // $Log: PingThread.cpp,v $
+// Revision 1.7  2008/12/16 10:44:57  pascal_verdier
+// Memory leak fixed.
+//
+// Revision 1.6  2008/02/29 15:15:05  pascal_verdier
+// Checking running processes by system call added.
+//
+// Revision 1.5  2007/09/25 12:12:00  pascal_verdier
+// little memory leaks fixed.
+//
 // Revision 1.4  2006/11/10 14:53:28  pascal_verdier
 // Remove vc8 warnings.
 //
@@ -161,16 +170,6 @@ void PingThreadData::wake_up()
 
 
 
-//+----------------------------------------------------------------------------
-/**
- *	Create a thread to ping server
- */
-//+----------------------------------------------------------------------------
-PingThread::PingThread(PingThreadData *sd, string name)
-{
-	shared       = sd;
-	servname     = name;
-}
 //+----------------------------------------------------------------------------
 /**
  *	Execute the thread loop.
@@ -189,43 +188,49 @@ void *PingThread::run_undetached(void *ptr)
 	while(!stop_thread)
 	{
 		GetTime(before);
-		//	try to build DeviceProxy
-		if (dev==NULL)
+		//	Check before if server running or failed
+		if (process_util->is_server_running(servname))
 		{
-			try
+			//	try to build DeviceProxy
+			if (dev==NULL)
 			{
-				dev = new Tango::DeviceProxy(adm_devname);
+				try
+				{
+					if (dev==NULL)
+						dev = new Tango::DeviceProxy(adm_devname);
+				}
+				catch(Tango::DevFailed &e)
+				{
+					Tango::Except::print_exception(e);
+				}
+				catch(...)
+				{
+					cout << "============================================" << endl;
+					cout << "	Exception catched !!!!!!" << endl;
+					cout << "============================================" << endl;
+				}
 			}
-			catch(Tango::DevFailed &e)
+			if (dev!=NULL)
 			{
-				Tango::Except::print_exception(e);
-			}
-			catch(...)
-			{
-				cout << "============================================" << endl;
-				cout << "	Exception catched !!!!!!" << endl;
-				cout << "============================================" << endl;
-			}
-		}
-		if (dev!=NULL)
-		{
-			try
-			{
-				dev->ping();
-				state = Tango::ON;
-			}
-			catch(Tango::DevFailed &)
-			{
-				//Tango::Except::print_exception(e);
-				state = Tango::FAULT;
-				delete dev;
-				dev = NULL;
+				try
+				{
+					dev->ping();
+					state = Tango::ON;
+				}
+				catch(Tango::DevFailed &)
+				{
+					cout << servname << " is running but not responding !!!" << endl;
+					//Tango::Except::print_exception(e);
+					state = Tango::MOVING;
+				}
 			}
 		}
+		else
+			state = Tango::FAULT;
 		shared->set_state(state);
 
-		if (trace)	cout << "Ping thread:[" << servname << "]	" <<
-				((state==Tango::ON)? "Running" : "Stopped")    << endl;
+		if (trace) cout << "Ping thread:[" << servname << "]	" <<
+				Tango::DevStateName[state]    << endl;
 		
 		//	Compute time to sleep
 		GetTime(after);
@@ -244,7 +249,12 @@ void *PingThread::run_undetached(void *ptr)
 		}
 		stop_thread = shared->get_stop_thread();
 	}
+
+
+
 	delete shared;
+	if (dev!=NULL)
+		delete dev;
 	if (trace)	cout << "Ping thread:[" << servname << "] - leaving...." << endl;
 	return NULL;
 }
