@@ -1,4 +1,4 @@
-static const char *RcsId = "$Header: /cvsroot/tango-cs/tango/cppserver/starter/Starter.cpp,v 3.32 2007/05/25 06:08:00 pascal_verdier Exp $";
+static const char *RcsId = "$Header: /cvsroot/tango-cs/tango/cppserver/starter/Starter.cpp,v 3.42 2009/04/06 13:57:56 pascal_verdier Exp $";
 //+=============================================================================
 //
 // file :         Starter.cpp
@@ -13,9 +13,40 @@ static const char *RcsId = "$Header: /cvsroot/tango-cs/tango/cppserver/starter/S
 //
 // $Author: pascal_verdier $
 //
-// $Revision: 3.32 $
+// $Revision: 3.42 $
 //
 // $Log: Starter.cpp,v $
+// Revision 3.42  2009/04/06 13:57:56  pascal_verdier
+// IDL-4 (Tango-7) release.
+//
+// Revision 3.41  2008/12/12 13:29:56  pascal_verdier
+// Log in file start and stop for servers and itself.
+//
+// Revision 3.40  2008/09/23 14:19:40  pascal_verdier
+// Log files history added.
+//
+// Revision 3.39  2008/05/15 08:07:18  pascal_verdier
+// TangoSys_MemStream replaced by TangoSys_OMemStream
+// (for leaking problem under win32)
+//
+// Revision 3.38  2008/04/24 06:27:24  pascal_verdier
+// Check host and device but in same case.
+//
+// Revision 3.37  2008/04/09 14:46:11  pascal_verdier
+// Bug in init of NotifdState attribute fixed.
+//
+// Revision 3.36  2008/04/07 13:10:27  pascal_verdier
+// New pogo property management.
+//
+// Revision 3.35  2008/04/07 08:54:55  pascal_verdier
+// Check if this starter instance is able to run on this host.
+//
+// Revision 3.34  2008/02/29 15:15:05  pascal_verdier
+// Checking running processes by system call added.
+//
+// Revision 3.33  2007/09/25 12:12:00  pascal_verdier
+// little memory leaks fixed.
+//
 // Revision 3.32  2007/05/25 06:08:00  pascal_verdier
 // Iterator management modified (strange in vc8 ?)
 //
@@ -176,10 +207,10 @@ static const char *RcsId = "$Header: /cvsroot/tango-cs/tango/cppserver/starter/S
 
 //===================================================================
 //
-//	The following table gives the correspondance
-//	between commands and method's name.
+//	The following table gives the correspondence
+//	between commands and method name.
 //
-//  Command's name        |  Method's name
+//  Command name          |  Method name
 //	----------------------------------------
 //  State                 |  dev_state()
 //  Status                |  dev_status()
@@ -190,8 +221,9 @@ static const char *RcsId = "$Header: /cvsroot/tango-cs/tango/cppserver/starter/S
 //  DevStart              |  dev_start()
 //  DevStop               |  dev_stop()
 //  DevReadLog            |  dev_read_log()
-//  UpdateServersInfo     |  update_servers_info()
+//  HardKillServer        |  hard_kill_server()
 //  NotifyDaemonState     |  notify_daemon_state()
+//  UpdateServersInfo     |  update_servers_info()
 //
 //===================================================================
 
@@ -242,6 +274,8 @@ static const char *RcsId = "$Header: /cvsroot/tango-cs/tango/cppserver/starter/S
 
 namespace Starter_ns
 {
+
+
 //+------------------------------------------------------------------
 /**
  *	Class Destructor
@@ -249,13 +283,20 @@ namespace Starter_ns
 //+------------------------------------------------------------------
 Starter::~Starter()
 {
+	util->log_starter_info("Starter shutdown");
 	//	Stop ping threads
 	vector<ControledServer>::iterator it;
 	for (it=servers.begin() ; it<servers.end() ; it++)
 	{
 		it->thread_data->set_stop_thread();
 	}
+	util->proc_util->stop_it();
 	ms_sleep(1000);
+	delete dbase;
+	delete util;
+	delete attr_HostState_read;
+	delete attr_NotifdState_read;
+	delete start_proc_data;
 }
 
 //+----------------------------------------------------------------------------
@@ -268,20 +309,20 @@ Starter::~Starter()
 //      - s : Device name 
 //
 //-----------------------------------------------------------------------------
-Starter::Starter(Tango::DeviceClass *cl,string &s):Tango::Device_3Impl(cl,s.c_str())
+Starter::Starter(Tango::DeviceClass *cl,string &s):Tango::Device_4Impl(cl,s.c_str())
 {
 	starting = true;
 	init_device();
 }
 
-Starter::Starter(Tango::DeviceClass *cl,const char *s):Tango::Device_3Impl(cl,s)
+Starter::Starter(Tango::DeviceClass *cl,const char *s):Tango::Device_4Impl(cl,s)
 {
 	starting = true;
 	init_device();
 }
 
 Starter::Starter(Tango::DeviceClass *cl,const char *s,const char *d)
-:Tango::Device_3Impl(cl,s,d)
+:Tango::Device_4Impl(cl,s,d)
 {
 	starting = true;
 	init_device();
@@ -311,6 +352,14 @@ void Starter::init_device()
 			Tango::Except::print_exception(e);
 		}
 	}
+
+	if (serverStartupTimeout<SERVER_TIMEOUT)
+		serverStartupTimeout = SERVER_TIMEOUT;
+
+	//	First time, check if instance and host name are coherent
+	check_host();
+
+
 	//	Do it only at startup and not at Init command
 	//----------------------------------------------------
 	if (starting==true)
@@ -323,7 +372,6 @@ void Starter::init_device()
 		//--------------------------------------
 		dbase = new Tango::DeviceProxy(dbname);
 //		dbase->set_timeout_millis(500);
-//		starting_processes = 0;
 
 		//	Build a shared data for StartProcessShared
 		start_proc_data = new StartProcessShared();
@@ -359,11 +407,12 @@ void Starter::init_device()
 		//	Create a StarterUtil instance
 		//--------------------------------------
 		util = new StarterUtil(dbase, hosts_list);
+		util->log_starter_info("Starter startup");
 
 		//	Initialize Attribute data member
-		attr_HostState_read = new Tango::DevShort[1];
-		attr_RunningServers_read = NULL;
-		attr_StoppedServers_read = NULL;
+		attr_HostState_read   = new Tango::DevShort[1];
+		attr_NotifdState_read = new Tango::DevState[1];
+		attr_NotifdState_read[0] = notifyd_state = Tango::UNKNOWN;
 
 		//	Do not want exception during startup
 		throwable = false;
@@ -429,11 +478,20 @@ void Starter::init_device()
 			((static_cast<StarterClass *>(get_device_class()))->nbStartupLevels);
 
 		if (startServersAtStartup==true)
+		{
+			//	Update state before
+			for (unsigned int i=0 ; i<servers.size() ; i++)
+			{
+				ControledServer	*server = &servers[i];
+				server->state = server->thread_data->get_state();
+			}
+			//	And then start levels
 			for (int level=1 ; level<=nb_levels ; level++)
 			{
 				dev_start_all(level);
 				ms_sleep(50);
 			}
+		}
 
 		//	Want exception during normal run
 		throwable = true;
@@ -441,7 +499,7 @@ void Starter::init_device()
 		//	Set the default state
 		//-------------------------------
 		set_state(Tango::MOVING);
-		set_status("Tango::MOVING");
+		//set_status("Tango::MOVING");
 		*attr_HostState_read = get_state();
 
 		//	Update Loggs
@@ -451,7 +509,6 @@ void Starter::init_device()
 		//	Start a thread to start polling
 		PollingState	*poller = new PollingState(get_name());
 		poller->start();
-
 	}
 }
 
@@ -478,6 +535,7 @@ void Starter::get_device_property()
 	dev_prop.push_back(Tango::DbDatum("StartServersAtStartup"));
 	dev_prop.push_back(Tango::DbDatum("InterStartupLevelWait"));
 	dev_prop.push_back(Tango::DbDatum("ServerStartupTimeout"));
+	dev_prop.push_back(Tango::DbDatum("KeepLogFiles"));
 
 	//	Call database and extract values
 	//--------------------------------------------
@@ -491,57 +549,80 @@ void Starter::get_device_property()
 	//	Try to initialize StartDsPath from class property
 	cl_prop = ds_class->get_class_property(dev_prop[++i].name);
 	if (cl_prop.is_empty()==false)	cl_prop  >>  startDsPath;
-	//	Try to initialize StartDsPath from default device value
-	def_prop = ds_class->get_default_device_property(dev_prop[i].name);
-	if (def_prop.is_empty()==false)	def_prop  >>  startDsPath;
+	else {
+		//	Try to initialize StartDsPath from default device value
+		def_prop = ds_class->get_default_device_property(dev_prop[i].name);
+		if (def_prop.is_empty()==false)	def_prop  >>  startDsPath;
+	}
 	//	And try to extract StartDsPath value from database
 	if (dev_prop[i].is_empty()==false)	dev_prop[i]  >>  startDsPath;
 
 	//	Try to initialize WaitForDriverStartup from class property
 	cl_prop = ds_class->get_class_property(dev_prop[++i].name);
 	if (cl_prop.is_empty()==false)	cl_prop  >>  waitForDriverStartup;
-	//	Try to initialize WaitForDriverStartup from default device value
-	def_prop = ds_class->get_default_device_property(dev_prop[i].name);
-	if (def_prop.is_empty()==false)	def_prop  >>  waitForDriverStartup;
+	else {
+		//	Try to initialize WaitForDriverStartup from default device value
+		def_prop = ds_class->get_default_device_property(dev_prop[i].name);
+		if (def_prop.is_empty()==false)	def_prop  >>  waitForDriverStartup;
+	}
 	//	And try to extract WaitForDriverStartup value from database
 	if (dev_prop[i].is_empty()==false)	dev_prop[i]  >>  waitForDriverStartup;
 
 	//	Try to initialize UseEvents from class property
 	cl_prop = ds_class->get_class_property(dev_prop[++i].name);
 	if (cl_prop.is_empty()==false)	cl_prop  >>  useEvents;
-	//	Try to initialize UseEvents from default device value
-	def_prop = ds_class->get_default_device_property(dev_prop[i].name);
-	if (def_prop.is_empty()==false)	def_prop  >>  useEvents;
+	else {
+		//	Try to initialize UseEvents from default device value
+		def_prop = ds_class->get_default_device_property(dev_prop[i].name);
+		if (def_prop.is_empty()==false)	def_prop  >>  useEvents;
+	}
 	//	And try to extract UseEvents value from database
 	if (dev_prop[i].is_empty()==false)	dev_prop[i]  >>  useEvents;
 
 	//	Try to initialize StartServersAtStartup from class property
 	cl_prop = ds_class->get_class_property(dev_prop[++i].name);
 	if (cl_prop.is_empty()==false)	cl_prop  >>  startServersAtStartup;
-	//	Try to initialize StartServersAtStartup from default device value
-	def_prop = ds_class->get_default_device_property(dev_prop[i].name);
-	if (def_prop.is_empty()==false)	def_prop  >>  startServersAtStartup;
+	else {
+		//	Try to initialize StartServersAtStartup from default device value
+		def_prop = ds_class->get_default_device_property(dev_prop[i].name);
+		if (def_prop.is_empty()==false)	def_prop  >>  startServersAtStartup;
+	}
 	//	And try to extract StartServersAtStartup value from database
 	if (dev_prop[i].is_empty()==false)	dev_prop[i]  >>  startServersAtStartup;
 
 	//	Try to initialize InterStartupLevelWait from class property
 	cl_prop = ds_class->get_class_property(dev_prop[++i].name);
 	if (cl_prop.is_empty()==false)	cl_prop  >>  interStartupLevelWait;
-	//	Try to initialize InterStartupLevelWait from default device value
-	def_prop = ds_class->get_default_device_property(dev_prop[i].name);
-	if (def_prop.is_empty()==false)	def_prop  >>  interStartupLevelWait;
+	else {
+		//	Try to initialize InterStartupLevelWait from default device value
+		def_prop = ds_class->get_default_device_property(dev_prop[i].name);
+		if (def_prop.is_empty()==false)	def_prop  >>  interStartupLevelWait;
+	}
 	//	And try to extract InterStartupLevelWait value from database
 	if (dev_prop[i].is_empty()==false)	dev_prop[i]  >>  interStartupLevelWait;
 
 	//	Try to initialize ServerStartupTimeout from class property
 	cl_prop = ds_class->get_class_property(dev_prop[++i].name);
 	if (cl_prop.is_empty()==false)	cl_prop  >>  serverStartupTimeout;
-	//	Try to initialize ServerStartupTimeout from default device value
-	def_prop = ds_class->get_default_device_property(dev_prop[i].name);
-	if (def_prop.is_empty()==false)	def_prop  >>  serverStartupTimeout;
+	else {
+		//	Try to initialize ServerStartupTimeout from default device value
+		def_prop = ds_class->get_default_device_property(dev_prop[i].name);
+		if (def_prop.is_empty()==false)	def_prop  >>  serverStartupTimeout;
+	}
 	//	And try to extract ServerStartupTimeout value from database
 	if (dev_prop[i].is_empty()==false)	dev_prop[i]  >>  serverStartupTimeout;
 
+	//	Try to initialize KeepLogFiles from class property
+	cl_prop = ds_class->get_class_property(dev_prop[++i].name);
+	if (cl_prop.is_empty()==false)	cl_prop  >>  keepLogFiles;
+	else {
+		//	Try to initialize KeepLogFiles from default device value
+		def_prop = ds_class->get_default_device_property(dev_prop[i].name);
+		if (def_prop.is_empty()==false)	def_prop  >>  keepLogFiles;
+	}
+	//	And try to extract KeepLogFiles value from database
+	if (dev_prop[i].is_empty()==false)	dev_prop[i]  >>  keepLogFiles;
+
 
 
 	//	End of Automatic code generation
@@ -572,7 +653,6 @@ void Starter::get_device_property()
 	if (tmp=="false")
 		fireFromDbase = false;
 	cout << "fireFromDbase = " << fireFromDbase << endl;
-	
 }
 //+----------------------------------------------------------------------------
 //
@@ -593,6 +673,21 @@ void Starter::always_executed_hook()
 //-----------------------------------------------------------------------------
 void Starter::read_attr_hardware(vector<long> &attr_list)
 {
+	
+	//	Update servers state
+	for (unsigned int i=0 ; i < attr_list.size() ; i++)
+	{
+		Tango::WAttribute &att = dev_attr->get_w_attr_by_ind(attr_list[i]);
+		string attr_name = att.get_name();
+		if (attr_name == "Servers")
+			for (unsigned int j=0 ; j<servers.size() ; j++)
+			{
+				servers[j].state = servers[j].thread_data->get_state();
+				//if (servers[j].name=="")
+				//	cout << "read_attr_hardware:[" << servers[j].name << "]	" <<
+				//				Tango::DevStateName[servers[j].state]  << endl;
+			}
+	}
 }
 //+----------------------------------------------------------------------------
 //
@@ -609,6 +704,49 @@ void Starter::read_HostState(Tango::Attribute &attr)
 	attr.set_value(attr_HostState_read);
 }
 
+//+----------------------------------------------------------------------------
+//
+// method : 		Starter::read_NotifdState
+// 
+// description : 	Extract real attribute values for NotifdState acquisition result.
+//
+//-----------------------------------------------------------------------------
+void Starter::read_NotifdState(Tango::Attribute &attr)
+{
+	DEBUG_STREAM << "Starter::read_NotifdState(Tango::Attribute &attr) entering... "<< endl;
+	attr_NotifdState_read[0] = notifyd_state;
+	attr.set_value(attr_NotifdState_read);
+}
+
+//+----------------------------------------------------------------------------
+//
+// method : 		Starter::read_Servers
+// 
+// description : 	Extract real attribute values for Servers acquisition result.
+//
+//-----------------------------------------------------------------------------
+void Starter::read_Servers(Tango::Attribute &attr)
+{
+	DEBUG_STREAM << "Starter::read_Servers(Tango::Attribute &attr) entering... "<< endl;
+
+	//	Check starting ones
+	vector<string>	vs;
+	for (unsigned int i=0 ; i<servers.size() ; i++)
+	{
+		TangoSys_OMemStream tms;
+		tms << servers[i].name << "\t" << 
+					Tango::DevStateName[servers[i].state] << "\t" <<
+					servers[i].controled  << "\t" << servers[i].startup_level;
+		string	s = tms.str();
+		vs.push_back(s);
+		
+	}
+	//	And fill attribute
+	stringArrayServers << vs;	
+	attr.set_value(stringArrayServers.get_buffer(), stringArrayServers.length());
+}
+
+
 //+----------------------------------------------------------------------------
 //
 // method : 		Starter::read_RunningServers
@@ -623,8 +761,9 @@ void Starter::read_RunningServers(Tango::Attribute &attr)
 	//	Check running ones
 	vector<string>	runnings;
 	for (unsigned int i=0 ; i<servers.size() ; i++)
-		if (servers[i].running==true)
+		if (servers[i].state==Tango::ON)
 			runnings.push_back(servers[i].name);
+
 	//	And fill attribute
 	stringArrayRunning << runnings;	
 	attr.set_value(stringArrayRunning.get_buffer(), stringArrayRunning.length());
@@ -641,37 +780,16 @@ void Starter::read_StoppedServers(Tango::Attribute &attr)
 {
 	DEBUG_STREAM << "Starter::read_StoppedServers(Tango::Attribute &attr) entering... "<< endl;
 
-	//	Check running ones
+	//	Check stopped ones
 	vector<string>	stopped;
 	for (unsigned int i=0 ; i<servers.size() ; i++)
-		if (servers[i].running==false)
+		if (servers[i].state!=Tango::ON)
 			stopped.push_back(servers[i].name);
 	//	And fill attribute
 	stringArrayStopped << stopped;	
 	attr.set_value(stringArrayStopped.get_buffer(), stringArrayStopped.length());
 }
 
-//+------------------------------------------------------------------
-/**
- *	Check if server running.
- *	Try to import his device administrator.
- *
- *	@param devname	Device name.
- */
-//+------------------------------------------------------------------
-const bool Starter::is_running(ControledServer *server)
-{
-	bool	retval;
-	//	Check if thread has updated.
-	time_t	t0 = server->thread_data->get_last_write_time();
-	time_t	dt = time(NULL)-t0;
-	if (dt > PING_TIMEOUT)
-		retval = false;
-	else
-		retval = (server->thread_data->get_state()==Tango::ON);
-	return retval;
-}
-
 //+------------------------------------------------------------------
 /**
  *	method:	Starter::dev_state
@@ -687,7 +805,6 @@ const bool Starter::is_running(ControledServer *server)
 Tango::DevState Starter::dev_state()
 {
 	INFO_STREAM << "Starter::dev_state(): entering... !" << endl;
-	static int	cnt = 0;
 
 	//	Check if last command is more than readInfoDbPeriod class property
 	int	period =
@@ -712,12 +829,9 @@ Tango::DevState Starter::dev_state()
 	else
 	if (do_update_from_db)
 	{
-		//	do it two times to be sure (I know it is not really nice)
-		cnt++;
-		if ((cnt%2)==0)
-			do_update_from_db = false;
 		//	Has been fired from Dbase
 		util->build_server_ctrl_object(&servers);
+		do_update_from_db = false;
 	}
 	//	Check for notify daemon state if requested
 	//---------------------------------------------
@@ -743,21 +857,26 @@ Tango::DevState Starter::dev_state()
 	ControledServer		*p_serv;
 	int		nb_running   = 0;
 	int		nb_controled = 0;
+	int		nb_starting  = 0;
 	for (unsigned int i=0 ; i<servers.size() ; i++)
 	{
 		p_serv = &servers[i];
 		//	Count how many are controlled
 		if (p_serv->controled)
+		{
 			nb_controled++;
 
-		//	Fixe witch one is running and count how many controlled are running
-		if ((p_serv->running=is_running(p_serv)))
-			if (p_serv->controled)
+			//	Fixe witch one is running and count how many controlled are running
+			if ((p_serv->state==Tango::ON))
 				nb_running ++;
+			else
+			if (p_serv->state==Tango::MOVING)
+				nb_starting ++;
+		}
 	}
 
 	//	compare nb running with nb_controlled controled to set state
-	if (start_proc_data->get_starting_processes()>0)
+	if (nb_starting>0 || start_proc_data->get_starting_processes()>0)
 		set_state(Tango::MOVING);
 	else
 	if (nb_running==nb_controled && notifyd_state==Tango::ON)
@@ -789,15 +908,15 @@ NewProcess *Starter::processCouldStart(char *argin)
 		string	name(argin);
 		ControledServer	*server = util->get_server_by_name(name, servers);
 		if (server!=NULL)
-			if (server->running)
+			if (server->state!=Tango::FAULT)
 			{
 				INFO_STREAM << argin << " is already running !" <<endl;
-				TangoSys_MemStream out_stream;
-				out_stream << argin << " is already running !" << ends;
+				TangoSys_OMemStream tms;
+				tms << argin << " is already running !" << ends;
 				if (throwable)
 					Tango::Except::throw_exception(
 								(const char *)"ALREADY_RUNNING",
-								out_stream.str(),
+								tms.str(),
 								(const char *)"Starter::dev_start()");
 				return NULL;
 			}
@@ -813,7 +932,9 @@ NewProcess *Starter::processCouldStart(char *argin)
 	try {
 		filename = util->check_exe_file(servname, startDsPath);
 	}
-	catch(Tango::DevFailed &e) {
+	catch(Tango::DevFailed &e)
+	{
+		free(servname);
 		if (throwable)
 			throw e;
 		else
@@ -822,6 +943,7 @@ NewProcess *Starter::processCouldStart(char *argin)
 			return NULL;
 		}
 	}
+	free(servname);
 
 	//	Check if log dir already exists.
 	//-------------------------------------
@@ -830,7 +952,7 @@ NewProcess *Starter::processCouldStart(char *argin)
 	string	logpath;
 	LogPath(logpath);
 	INFO_STREAM << "LOG file : " << log_file << endl;
-	if (chdir(logpath.c_str()))
+	if (chdir(logpath.c_str())==-1)
 	{
 		if (errno==ENOENT)
 		{
@@ -850,17 +972,33 @@ NewProcess *Starter::processCouldStart(char *argin)
 #endif
 			if (r<0)
 			{
-				TangoSys_MemStream	message;
+				TangoSys_OMemStream	message;
 				message << "Cannot create error log directory:\n";
-				message << logpath << ends;
-				cerr << message.str() << "\n" << strerror(errno) << endl;
+				message << logpath;
+				message << "\n" << strerror(errno) << endl;
+				cerr << message.str() << endl;;
+				set_status(message.str());
 				Tango::Except::throw_exception(
 									(const char *)"CANNOT_CREATE_LOG_FILE",
 									message.str(),
 									(const char *)"Starter::dev_start");
 			}
 			else
-				INFO_STREAM << logpath << " Created !" << endl;
+			{
+				TangoSys_OMemStream	tms;
+				tms << logpath << " Created !" << endl;
+				INFO_STREAM << tms.str() << endl;
+				set_status(tms.str());
+			}
+		}
+		else
+		{
+			TangoSys_OMemStream	tms;
+			tms << "Cannot change to log directory:\n";
+			tms << logpath;
+			tms << "\n" << strerror(errno) << endl;
+			cerr << tms.str() << endl;;
+			set_status(tms.str());
 		}
 	}
 	
@@ -886,7 +1024,8 @@ NewProcess *Starter::processCouldStart(char *argin)
 //+------------------------------------------------------------------
 void Starter::dev_start(Tango::DevString argin)
 {
-	INFO_STREAM << "Starter::dev_start(\""<< argin << "\"): entering... !" << endl;
+	//INFO_STREAM 
+	cout << "Starter::dev_start(\""<< argin << "\"): entering... !" << endl;
 
 	NewProcess	*np = processCouldStart(argin);
 	if (np==NULL)
@@ -904,7 +1043,6 @@ void Starter::startProcesses(vector<NewProcess *> v_np, int level)
 	//	Start process to start processes
 	//-------------------------------------
 	start_proc_data->push_back_level(level);
-//	starting_processes++;
 	StartProcessThread	*pt =
 		new StartProcessThread(v_np, level, this);
 	pt->start();
@@ -929,7 +1067,7 @@ void Starter::dev_stop(Tango::DevString argin)
 	//---------------------------------------
 	if (servers.size()==0)
 	{
-		TangoSys_MemStream out_stream;
+		TangoSys_OMemStream out_stream;
 		out_stream << argin << ": Server  not controlled !" << ends;
 		Tango::Except::throw_exception(out_stream.str(),
 				out_stream.str(),
@@ -943,7 +1081,7 @@ void Starter::dev_stop(Tango::DevString argin)
 	ControledServer	*server = util->get_server_by_name(name, servers);
 	if (server==NULL)
 	{
-		TangoSys_MemStream out_stream;
+		TangoSys_OMemStream out_stream;
 		out_stream << argin << ": Unkown Server !" << ends;
 		Tango::Except::throw_exception(out_stream.str(),
 				out_stream.str(),
@@ -953,22 +1091,41 @@ void Starter::dev_stop(Tango::DevString argin)
 
 	//	Make shure that it's  running.
 	//---------------------------------------
-	if (server->running==false)
+	if (server->state==Tango::ON)
 	{
-		TangoSys_MemStream out_stream;
+		//	And Kill it with kill signal
+		if (server->dev==NULL)
+			server->dev =  new Tango::DeviceProxy(server->admin_name);
+		server->dev->command_inout("Kill");
+
+		TangoSys_OMemStream out_stream;
+		out_stream << argin << " stopped";
+		WARN_STREAM << out_stream.str() << endl;
+		cout << out_stream.str() << endl;
+		util->log_starter_info(out_stream.str());
+	}
+	else
+	if (server->state==Tango::MOVING)
+	{
+		TangoSys_OMemStream out_stream;
+		out_stream << argin << " is running but not responding !" << ends;
+		Tango::Except::throw_exception(
+				(const char *)"SERVER_NOT_RESPONDING",
+				out_stream.str(),
+				(const char *)"Starter::dev_stop()");
+		return;
+	}
+	else
+	{
+		TangoSys_OMemStream out_stream;
 		out_stream << argin << " is NOT running !" << ends;
-		Tango::Except::throw_exception(out_stream.str(),
+		Tango::Except::throw_exception(
+				(const char *)"SERVER_NOT_RUNNING",
 				out_stream.str(),
 				(const char *)"Starter::dev_stop()");
 		return;
 	}
 	
-	//	And Kill it
-	//-------------------
-	Tango::DeviceProxy	*dev = new Tango::DeviceProxy(server->admin_name);
-	dev->command_inout("Kill");
-	WARN_STREAM << argin << " stopped !" << endl;
-	cout << argin << " stopped !" << endl;
 }
 
 //+------------------------------------------------------------------
@@ -1003,7 +1160,7 @@ Tango::DevVarStringArray *Starter::dev_get_running_servers(Tango::DevBoolean all
 	unsigned int	i;
 	for (i=0 ; i<servers.size() ; i++)
 		if (all_serv || servers[i].controled)
-			if (servers[i].running)
+			if (servers[i].state==Tango::ON)
 				nb ++;
 
 	//	And fill it
@@ -1011,7 +1168,7 @@ Tango::DevVarStringArray *Starter::dev_get_running_servers(Tango::DevBoolean all
 	argout->length(nb);
 	for (i=0, x=0 ; i<servers.size() && x<nb ; i++)
 		if (all_serv || servers[i].controled)
-			if (servers[i].running)
+			if (servers[i].state==Tango::ON)
 			{
 				INFO_STREAM << "RUNNING: " << servers[i].name << endl;
 				(*argout)[x++] = CORBA::string_dup(servers[i].name.c_str());
@@ -1052,7 +1209,7 @@ Tango::DevVarStringArray *Starter::dev_get_stop_servers(Tango::DevBoolean all_se
 	unsigned int	i;
 	for (i=0 ; i<servers.size() ; i++)
 		if (all_serv || servers[i].controled)
-			if (servers[i].running==false)
+			if (servers[i].state!=Tango::ON)
 				nb ++;
 
 	//	And fill it
@@ -1060,7 +1217,7 @@ Tango::DevVarStringArray *Starter::dev_get_stop_servers(Tango::DevBoolean all_se
 	argout->length(nb);
 	for (i=0, x=0  ; i<servers.size() && x<nb; i++)
 		if (all_serv || servers[i].controled)
-			if (servers[i].running==false)
+			if (servers[i].state!=Tango::ON)
 			{
 				INFO_STREAM << "STOPPED: " << servers[i].name << endl;
 				(*argout)[x++] = CORBA::string_dup(servers[i].name.c_str());
@@ -1081,7 +1238,7 @@ int	Starter::nb_servers_to_start(int level)
 		ControledServer	*server = &servers[i];
 		//	server->running could not be initialized
 		if (server->controled  &&  server->startup_level==level)
-			if (is_running(server)==false)
+			if (server->state!=Tango::ON)
 				cnt++;
 	}
 	return cnt;
@@ -1112,7 +1269,7 @@ void Starter::dev_start_all(Tango::DevShort level)
 			return;
 	if (throw_it)
 	{
-			TangoSys_MemStream out_stream;
+			TangoSys_OMemStream out_stream;
 			out_stream << "NO Server  controlled !" << ends;
 			Tango::Except::throw_exception(out_stream.str(),
 			out_stream.str(),
@@ -1132,8 +1289,7 @@ void Starter::dev_start_all(Tango::DevShort level)
 		if (server->controled  &&  server->startup_level==level)
 		{
 			cout << "Check startup for " << server->name << endl;
-			server->running = is_running(server);
-			if (server->running==false)
+			if (server->state==Tango::FAULT)
 			{
 				NewProcess	*np = processCouldStart((char*)server->name.c_str());
 				if (np!=NULL)
@@ -1174,8 +1330,8 @@ void Starter::dev_stop_all(Tango::DevShort level)
 	//---------------------------------------
 	if (servers.size()==0)
 	{
-		TangoSys_MemStream out_stream;
-		out_stream << "NO Server  not controlled !" << ends;
+		TangoSys_OMemStream out_stream;
+		out_stream << "NO Server  controlled !" << ends;
 		Tango::Except::throw_exception(out_stream.str(),
 				out_stream.str(),
 				(const char *)"Starter::dev_stop_all()");
@@ -1188,7 +1344,7 @@ void Starter::dev_stop_all(Tango::DevShort level)
 		ControledServer	*server = &servers[i];
 		if (server->controled             &&
 			server->startup_level==level  &&
-			server->running==true)
+			server->state==Tango::ON)
 				dev_stop((char*)server->name.c_str());
 	}
 }
@@ -1227,7 +1383,19 @@ void Starter::update_servers_info()
 //+------------------------------------------------------------------
 Tango::ConstDevString Starter::dev_read_log(Tango::DevString argin)
 {
-	string filename = util->build_log_file_name(argin);
+	string	filename;
+	bool	on_starter;
+	//	Check if for Starter itself
+	if (strcmp(argin, "Starter")==0)
+	{
+		on_starter = true;
+		filename = util->starter_log_file;
+	}
+	else
+	{
+		on_starter = false;
+		filename = util->build_log_file_name(argin);
+	}
 
 	//	Try to open log file
 	ifstream	ifs((char *)filename.c_str());
@@ -1235,8 +1403,8 @@ Tango::ConstDevString Starter::dev_read_log(Tango::DevString argin)
 	{
 		//	Open log file failed -> Throw exception
 		//----------------------------------------------
-		TangoSys_MemStream reason;
-		TangoSys_MemStream description;
+		TangoSys_OMemStream reason;
+		TangoSys_OMemStream description;
 		reason << "Cannot open " << filename << ends;
 		description << strerror(errno);
 		Tango::Except::throw_exception(reason.str(),
@@ -1247,8 +1415,11 @@ Tango::ConstDevString Starter::dev_read_log(Tango::DevString argin)
 	//	Read and close log file, and return string read from it.
 	//-------------------------------------------------------------
 	stringstream	strlog;
-	strlog << filename << endl;
-	strlog << util->get_file_date((char *)filename.c_str()) << endl << endl;
+	if (!on_starter)
+	{
+		strlog << filename << endl;
+		strlog << util->get_file_date((char *)filename.c_str()) << endl << endl;
+	}
 	strlog << ifs.rdbuf() << ends;
 	ifs.close();
 	returned_str = strlog.str();
@@ -1278,4 +1449,111 @@ Tango::DevState Starter::notify_daemon_state()
 	return notifyd_state;
 }
 
+//+------------------------------------------------------------------
+/**
+ *	method:	Starter::hard_kill_server
+ *
+ *	description:	method to execute "HardKillServer"
+ *	Hard kill a server (kill -9)
+ *
+ * @param	argin	Server name
+ *
+ */
+//+------------------------------------------------------------------
+void Starter::hard_kill_server(Tango::DevString argin)
+{
+	DEBUG_STREAM << "Starter::hard_kill_server(): entering... !" << endl;
+
+	string	servname(argin);
+	int	pid = util->proc_util->get_server_pid(servname);
+	if (pid<0)
+	{
+		TangoSys_OMemStream tms;
+		tms << "Server " << argin << " is not running !";
+		Tango::Except::throw_exception(
+					(const char *)"SERVER_NOT_RUNNING",
+					tms.str().c_str(),
+					(const char *)"Starter::hard_kill_server()");
+	}
+#ifdef WIN32
+
+	HANDLE	handle = NULL;				//- process addr (in the heap)
+	if( (handle=OpenProcess(PROCESS_TERMINATE, false, pid)) == NULL)
+	{
+		TangoSys_OMemStream tms;
+		tms << "Open handle on server " << argin << " failed !";
+		Tango::Except::throw_exception(
+					(const char *)"KILL_DERVER_FAILED",
+					tms.str().c_str(),
+					(const char *)"Starter::hard_kill_server()");
+	}
+	
+	TerminateProcess(handle, 0);
+	CloseHandle(handle);
+	if (GetLastError()!= ERROR_SUCCESS)
+	{
+		TangoSys_OMemStream tms;
+		tms << "Kill server " << argin << " failed !";
+		Tango::Except::throw_exception(
+					(const char *)"KILL_DERVER_FAILED",
+					tms.str().c_str(),
+					(const char *)"Starter::hard_kill_server()");
+	}
+
+#else
+
+	TangoSys_OMemStream cmd;
+	cmd << "kill -9 " << pid;
+	if (system(cmd.str().c_str())<0)
+	{
+		TangoSys_OMemStream tms;
+		tms << "Kill server " << argin << " failed !";
+		Tango::Except::throw_exception(
+					(const char *)"KILL_DERVER_FAILED",
+					tms.str().c_str(),
+					(const char *)"Starter::hard_kill_server()");
+	}
+#endif
+}
+//=================================================================
+//=================================================================
+void Starter::check_host()
+{
+	string	hostname = Tango::Util::instance()->get_host_name();
+	transform(hostname.begin(), hostname.end(), hostname.begin(), ::tolower);
+	//	remove FQDN
+	string::size_type	pos = hostname.find('.');
+	if (pos!=string::npos)
+		hostname = hostname.substr(0, pos);
+
+	string	devname = device_name;
+	transform(devname.begin(), devname.end(), devname.begin(), ::tolower);
+
+	//	Get only member
+	pos = devname.find('/');
+	if (pos!=string::npos)
+	{
+		pos = devname.find('/', pos+1);
+		if (pos!=string::npos)
+			devname = devname.substr(pos+1);
+	}
+	//cout << hostname << " == " << devname << endl;
+	
+	if (devname != hostname)
+	{
+		TangoSys_OMemStream	tms;
+		tms << "This server must run on " << devname << " and not on "  << hostname;
+		string	descr(tms.str());
+		
+		Tango::Except::throw_exception(
+				(const char *)"BAD_PARAM",
+				(const char *) descr.c_str(),
+				(const char *)"Starter::check_host()");
+	}
+}
+
+
+
+
+
 }	//	namespace
