@@ -1,4 +1,7 @@
-static const char *RcsId     = "$Header: /cvsroot/tango-cs/tango/cppserver/starter/StarterClass.cpp,v 3.18 2007/02/13 06:45:13 pascal_verdier Exp $";
+static const char *ClassId    = "$Id: StarterClass.cpp,v 3.27 2009/04/06 13:57:57 pascal_verdier Exp $";
+static const char *CvsPath    = "$Source: /cvsroot/tango-cs/tango/cppserver/starter/StarterClass.cpp,v $";
+static const char *SvnPath    = "$HeadURL: $";
+static const char *RcsId     = "$Header: /cvsroot/tango-cs/tango/cppserver/starter/StarterClass.cpp,v 3.27 2009/04/06 13:57:57 pascal_verdier Exp $";
 static const char *TagName   = "$Name:  $";
 static const char *HttpServer= "http://www.esrf.fr/computing/cs/tango/tango_doc/ds_doc/";
 //+=============================================================================
@@ -14,9 +17,37 @@ static const char *HttpServer= "http://www.esrf.fr/computing/cs/tango/tango_doc/
 //
 // $Author: pascal_verdier $
 //
-// $Revision: 3.18 $
+// $Revision: 3.27 $
 //
 // $Log: StarterClass.cpp,v $
+// Revision 3.27  2009/04/06 13:57:57  pascal_verdier
+// IDL-4 (Tango-7) release.
+//
+// Revision 3.26  2008/12/12 13:29:56  pascal_verdier
+// Log in file start and stop for servers and itself.
+//
+// Revision 3.25  2008/09/23 14:19:40  pascal_verdier
+// Log files history added.
+//
+// Revision 3.24  2008/06/18 08:17:02  pascal_verdier
+// Pb with case unsensitive on win32 fixed.
+//
+// Revision 3.23  2008/05/15 08:07:18  pascal_verdier
+// TangoSys_MemStream replaced by TangoSys_OMemStream
+// (for leaking problem under win32)
+//
+// Revision 3.22  2008/04/09 14:46:11  pascal_verdier
+// Bug in init of NotifdState attribute fixed.
+//
+// Revision 3.21  2008/04/07 13:10:27  pascal_verdier
+// New pogo property management.
+//
+// Revision 3.20  2008/04/07 08:54:55  pascal_verdier
+// Check if this starter instance is able to run on this host.
+//
+// Revision 3.19  2008/02/29 15:15:05  pascal_verdier
+// Checking running processes by system call added.
+//
 // Revision 3.18  2007/02/13 06:45:13  pascal_verdier
 // *** empty log message ***
 //
@@ -135,6 +166,31 @@ static const char *HttpServer= "http://www.esrf.fr/computing/cs/tango/tango_doc/
 
 namespace Starter_ns
 {
+//+----------------------------------------------------------------------------
+//
+// method : 		HardKillServerClass::execute()
+// 
+// description : 	method to trigger the execution of the command.
+//                PLEASE DO NOT MODIFY this method core without pogo   
+//
+// in : - device : The device on which the command must be executed
+//		- in_any : The command input data
+//
+// returns : The command output data (packed in the Any object)
+//
+//-----------------------------------------------------------------------------
+CORBA::Any *HardKillServerClass::execute(Tango::DeviceImpl *device,const CORBA::Any &in_any)
+{
+
+	cout2 << "HardKillServerClass::execute(): arrived" << endl;
+
+	Tango::DevString	argin;
+	extract(in_any, argin);
+
+	((static_cast<Starter *>(device))->hard_kill_server(argin));
+	return new CORBA::Any();
+}
+
 //+----------------------------------------------------------------------------
 //
 // method : 		NotifyDaemonStateCmd::execute()
@@ -470,13 +526,13 @@ void StarterClass::command_factory()
 		"",
 		Tango::OPERATOR));
 	command_list.push_back(new DevReadLogCmd("DevReadLog",
-		Tango::DEV_STRING, Tango::CONST_DEV_STRING,
+		Tango::DEV_STRING, Tango::DEV_STRING,    //  Tango::CONST_DEV_STRING
 		"server name and domain",
 		"ig Starter/corvus)",
 		Tango::OPERATOR));
-	command_list.push_back(new UpdateServersInfoCmd("UpdateServersInfo",
-		Tango::DEV_VOID, Tango::DEV_VOID,
-		"",
+	command_list.push_back(new HardKillServerClass("HardKillServer",
+		Tango::DEV_STRING, Tango::DEV_VOID,
+		"Server name",
 		"",
 		Tango::OPERATOR));
 	command_list.push_back(new NotifyDaemonStateCmd("NotifyDaemonState",
@@ -484,6 +540,11 @@ void StarterClass::command_factory()
 		"",
 		"Tango::ON if Notify daemon is running else Tango::FAULT.",
 		Tango::OPERATOR));
+	command_list.push_back(new UpdateServersInfoCmd("UpdateServersInfo",
+		Tango::DEV_VOID, Tango::DEV_VOID,
+		"",
+		"",
+		Tango::OPERATOR));
 
 	//	add polling if any
 	for (unsigned int i=0 ; i<command_list.size(); i++)
@@ -579,12 +640,22 @@ void StarterClass::device_factory(const Tango::DevVarStringArray *devlist_ptr)
 //-----------------------------------------------------------------------------
 void StarterClass::attribute_factory(vector<Tango::Attr *> &att_list)
 {
+	//	Attribute : NotifdState
+	NotifdStateAttrib	*notifd_state = new NotifdStateAttrib();
+	Tango::UserDefaultAttrProp	notifd_state_prop;
+	notifd_state_prop.set_label("Notifd State");
+	notifd_state_prop.set_description("return ON or FAULT if notify daemon is running or not.");
+	notifd_state->set_default_properties(notifd_state_prop);
+	notifd_state->set_polling_period(1000);
+	att_list.push_back(notifd_state);
+
 	//	Attribute : HostState
 	HostStateAttrib	*host_state = new HostStateAttrib();
 	att_list.push_back(host_state);
 
 	//	Attribute : RunningServers
 	RunningServersAttrib	*running_servers = new RunningServersAttrib();
+	running_servers->set_polling_period(1000);
 	att_list.push_back(running_servers);
 
 	//	Attribute : StoppedServers
@@ -593,8 +664,20 @@ void StarterClass::attribute_factory(vector<Tango::Attr *> &att_list)
 	stopped_servers_prop.set_label("All Stopped Servers");
 	stopped_servers_prop.set_description("Return all the Stopped servers.\n");
 	stopped_servers->set_default_properties(stopped_servers_prop);
+	stopped_servers->set_polling_period(1000);
 	att_list.push_back(stopped_servers);
 
+	//	Attribute : Servers
+	ServersAttrib	*servers = new ServersAttrib();
+	Tango::UserDefaultAttrProp	servers_prop;
+	servers_prop.set_label("Servers");
+	servers_prop.set_description("Return all registred servers for this host.\nServer names are followed by their states and controls");
+	servers->set_default_properties(servers_prop);
+	servers->set_polling_period(1000);
+	att_list.push_back(servers);
+
+	//	End of Automatic code generation
+	//-------------------------------------------------------------
 }
 //+----------------------------------------------------------------------------
 //
@@ -614,8 +697,6 @@ void StarterClass::get_class_property()
 
 	//	Read class properties from database.(Automatic code generation)
 	//-------------------------------------------------------------
-	if (Tango::Util::instance()->_UseDb==false)
-		return;
 	cl_prop.push_back(Tango::DbDatum("ReadInfoDbPeriod"));
 	cl_prop.push_back(Tango::DbDatum("NbStartupLevels"));
 	cl_prop.push_back(Tango::DbDatum("CmdPollingTimeout"));
@@ -624,44 +705,75 @@ void StarterClass::get_class_property()
 
 	//	Call database and extract values
 	//--------------------------------------------
-	get_db_class()->get_property(cl_prop);
+	if (Tango::Util::instance()->_UseDb==true)
+		get_db_class()->get_property(cl_prop);
 	Tango::DbDatum	def_prop;
 	int	i = -1;
 
-	//	Extract ReadInfoDbPeriod value
-	def_prop = get_default_class_property(cl_prop[++i].name);
-	if (def_prop.is_empty()==false)	def_prop  >>  readInfoDbPeriod;
-	if (cl_prop[i].is_empty()==false)	cl_prop[i]  >>  readInfoDbPeriod;
+	//	Try to extract ReadInfoDbPeriod value
+	if (cl_prop[++i].is_empty()==false)	cl_prop[i]  >>  readInfoDbPeriod;
 	else
-		cl_prop[i]  <<  readInfoDbPeriod;
+	{
+		//	Check default value for ReadInfoDbPeriod
+		def_prop = get_default_class_property(cl_prop[i].name);
+		if (def_prop.is_empty()==false)
+		{
+			def_prop  >>  readInfoDbPeriod;
+			cl_prop[i]  <<  readInfoDbPeriod;
+		}
+	}
 
-	//	Extract NbStartupLevels value
-	def_prop = get_default_class_property(cl_prop[++i].name);
-	if (def_prop.is_empty()==false)	def_prop  >>  nbStartupLevels;
-	if (cl_prop[i].is_empty()==false)	cl_prop[i]  >>  nbStartupLevels;
+	//	Try to extract NbStartupLevels value
+	if (cl_prop[++i].is_empty()==false)	cl_prop[i]  >>  nbStartupLevels;
 	else
-		cl_prop[i]  <<  nbStartupLevels;
+	{
+		//	Check default value for NbStartupLevels
+		def_prop = get_default_class_property(cl_prop[i].name);
+		if (def_prop.is_empty()==false)
+		{
+			def_prop  >>  nbStartupLevels;
+			cl_prop[i]  <<  nbStartupLevels;
+		}
+	}
 
-	//	Extract CmdPollingTimeout value
-	def_prop = get_default_class_property(cl_prop[++i].name);
-	if (def_prop.is_empty()==false)	def_prop  >>  cmdPollingTimeout;
-	if (cl_prop[i].is_empty()==false)	cl_prop[i]  >>  cmdPollingTimeout;
+	//	Try to extract CmdPollingTimeout value
+	if (cl_prop[++i].is_empty()==false)	cl_prop[i]  >>  cmdPollingTimeout;
 	else
-		cl_prop[i]  <<  cmdPollingTimeout;
+	{
+		//	Check default value for CmdPollingTimeout
+		def_prop = get_default_class_property(cl_prop[i].name);
+		if (def_prop.is_empty()==false)
+		{
+			def_prop  >>  cmdPollingTimeout;
+			cl_prop[i]  <<  cmdPollingTimeout;
+		}
+	}
 
-	//	Extract UseEvents value
-	def_prop = get_default_class_property(cl_prop[++i].name);
-	if (def_prop.is_empty()==false)	def_prop  >>  useEvents;
-	if (cl_prop[i].is_empty()==false)	cl_prop[i]  >>  useEvents;
+	//	Try to extract UseEvents value
+	if (cl_prop[++i].is_empty()==false)	cl_prop[i]  >>  useEvents;
 	else
-		cl_prop[i]  <<  useEvents;
+	{
+		//	Check default value for UseEvents
+		def_prop = get_default_class_property(cl_prop[i].name);
+		if (def_prop.is_empty()==false)
+		{
+			def_prop  >>  useEvents;
+			cl_prop[i]  <<  useEvents;
+		}
+	}
 
-	//	Extract ServerStartupTimeout value
-	def_prop = get_default_class_property(cl_prop[++i].name);
-	if (def_prop.is_empty()==false)	def_prop  >>  serverStartupTimeout;
-	if (cl_prop[i].is_empty()==false)	cl_prop[i]  >>  serverStartupTimeout;
+	//	Try to extract ServerStartupTimeout value
+	if (cl_prop[++i].is_empty()==false)	cl_prop[i]  >>  serverStartupTimeout;
 	else
-		cl_prop[i]  <<  serverStartupTimeout;
+	{
+		//	Check default value for ServerStartupTimeout
+		def_prop = get_default_class_property(cl_prop[i].name);
+		if (def_prop.is_empty()==false)
+		{
+			def_prop  >>  serverStartupTimeout;
+			cl_prop[i]  <<  serverStartupTimeout;
+		}
+	}
 
 	//	End of Automatic code generation
 	//-------------------------------------------------------------
@@ -692,6 +804,7 @@ void StarterClass::set_default_property()
 	prop_name = "ReadInfoDbPeriod";
 	prop_desc = "Period to read database for new info if not fired from Database server.";
 	prop_def  = "";
+	vect_data.clear();
 	if (prop_def.length()>0)
 	{
 		Tango::DbDatum	data(prop_name);
@@ -720,6 +833,7 @@ void StarterClass::set_default_property()
 	prop_name = "CmdPollingTimeout";
 	prop_desc = "Timeout value in seconds to stop polling if no command has been received.";
 	prop_def  = "";
+	vect_data.clear();
 	if (prop_def.length()>0)
 	{
 		Tango::DbDatum	data(prop_name);
@@ -764,6 +878,7 @@ void StarterClass::set_default_property()
 	prop_name = "StartDsPath";
 	prop_desc = "Path to find executable files\nto start device servers";
 	prop_def  = "";
+	vect_data.clear();
 	if (prop_def.length()>0)
 	{
 		Tango::DbDatum	data(prop_name);
@@ -849,6 +964,21 @@ void StarterClass::set_default_property()
 	else
 		add_wiz_dev_prop(prop_name, prop_desc);
 
+	prop_name = "KeepLogFiles";
+	prop_desc = "Number of log file kept.";
+	prop_def  = "3";
+	vect_data.clear();
+	vect_data.push_back("3");
+	if (prop_def.length()>0)
+	{
+		Tango::DbDatum	data(prop_name);
+		data << vect_data ;
+		dev_def_prop.push_back(data);
+		add_wiz_dev_prop(prop_name, prop_desc,  prop_def);
+	}
+	else
+		add_wiz_dev_prop(prop_name, prop_desc);
+
 }
 //+----------------------------------------------------------------------------
 //
@@ -883,17 +1013,23 @@ void StarterClass::write_class_property()
 	description << str_desc;
 	data.push_back(description);
 		
-	//	put cvs location
-	string	rcsId(RcsId);
+	//	put cvs or svn location
 	string	filename(classname);
-	start = rcsId.find("/");
+	filename += "Class.cpp";
+	
+	// Create a string with the class ID to
+	// get the string into the binary
+	string	class_id(ClassId);
+	
+	// check for cvs information
+	string	src_path(CvsPath);
+	start = src_path.find("/");
 	if (start!=string::npos)
 	{
-		filename += "Class.cpp";
-		end   = rcsId.find(filename);
+		end   = src_path.find(filename);
 		if (end>start)
 		{
-			string	strloc = rcsId.substr(start, end-start);
+			string	strloc = src_path.substr(start, end-start);
 			//	Check if specific repository
 			start = strloc.find("/cvsroot/");
 			if (start!=string::npos && start>0)
@@ -907,12 +1043,35 @@ void StarterClass::write_class_property()
 			data.push_back(cvs_loc);
 		}
 	}
+	// check for svn information
+	else
+	{
+		string	src_path(SvnPath);
+		start = src_path.find("://");
+		if (start!=string::npos)
+		{
+			end = src_path.find(filename);
+			if (end>start)
+			{
+				header = "$HeadURL: ";
+				start = header.length();
+				string	strloc = src_path.substr(start, (end-start));
+				
+				Tango::DbDatum	svn_loc("svn_location");
+				svn_loc << strloc;
+				data.push_back(svn_loc);
+			}
+		}
+	}
 
-	//	Get CVS tag revision
+	//	Get CVS or SVN revision tag
+	
+	// CVS tag
 	string	tagname(TagName);
 	header = "$Name: ";
 	start = header.length();
 	string	endstr(" $");
+	
 	end   = tagname.find(endstr);
 	if (end!=string::npos && end>start)
 	{
@@ -921,6 +1080,30 @@ void StarterClass::write_class_property()
 		cvs_tag << strtag;
 		data.push_back(cvs_tag);
 	}
+	
+	// SVN tag
+	string	svnpath(SvnPath);
+	header = "$HeadURL: ";
+	start = header.length();
+	
+	end   = svnpath.find(endstr);
+	if (end!=string::npos && end>start)
+	{
+		string	strloc = svnpath.substr(start, end-start);
+		
+		string tagstr ("/tags/");
+		start = strloc.find(tagstr);
+		if ( start!=string::npos )
+		{
+			start = start + tagstr.length();
+			end   = strloc.find(filename);
+			string	strtag = strloc.substr(start, end-start-1);
+			
+			Tango::DbDatum	svn_tag("svn_tag");
+			svn_tag << strtag;
+			data.push_back(svn_tag);
+		}
+	}
 
 	//	Get URL location
 	string	httpServ(HttpServer);
@@ -931,6 +1114,13 @@ void StarterClass::write_class_property()
 		data.push_back(db_doc_url);
 	}
 
+	//  Put inheritance
+	Tango::DbDatum	inher_datum("InheritedFrom");
+	vector<string> inheritance;
+	inheritance.push_back("Device_4Impl");
+	inher_datum << inheritance;
+	data.push_back(inher_datum);
+
 	//	Call database and and values
 	//--------------------------------------------
 	get_db_class()->put_property(data);
