@@ -12,9 +12,12 @@
 //
 // $Author: pascal_verdier $
 //
-// $Revision: 3.11 $
+// $Revision: 3.12 $
 //
 // $Log: StarterClass.h,v $
+// Revision 3.12  2008/04/07 13:10:33  pascal_verdier
+// New pogo property management.
+//
 // Revision 3.11  2008/02/29 15:15:05  pascal_verdier
 // Checking running processes by system call added.
 //
@@ -468,6 +471,8 @@ protected:
 	void attribute_factory(vector<Tango::Attr *> &);
 	void write_class_property();
 	void set_default_property();
+	string get_cvstag();
+	string get_cvsroot();
 
 private:
 	void device_factory(const Tango::DevVarStringArray *);
