@@ -1,4 +1,4 @@
-static const char *RcsId = "$Header: /cvsroot/tango-cs/tango/cppserver/starter/StarterUtil.cpp,v 3.20 2008/03/27 07:55:17 pascal_verdier Exp $";
+static const char *RcsId = "$Header: /cvsroot/tango-cs/tango/cppserver/starter/StarterUtil.cpp,v 3.23 2008/12/12 13:29:56 pascal_verdier Exp $";
 //+=============================================================================
 //
 // file :         StarterUtil.cpp
@@ -9,9 +9,19 @@ static const char *RcsId = "$Header: /cvsroot/tango-cs/tango/cppserver/starter/S
 //
 // $Author: pascal_verdier $
 //
-// $Revision: 3.20 $
+// $Revision: 3.23 $
 //
 // $Log: StarterUtil.cpp,v $
+// Revision 3.23  2008/12/12 13:29:56  pascal_verdier
+// Log in file start and stop for servers and itself.
+//
+// Revision 3.22  2008/09/23 14:19:41  pascal_verdier
+// Log files history added.
+//
+// Revision 3.21  2008/05/15 08:07:18  pascal_verdier
+// TangoSys_MemStream replaced by TangoSys_OMemStream
+// (for leaking problem under win32)
+//
 // Revision 3.20  2008/03/27 07:55:17  pascal_verdier
 // *** empty log message ***
 //
@@ -128,7 +138,6 @@ static const char *RcsId = "$Header: /cvsroot/tango-cs/tango/cppserver/starter/S
 #ifndef WIN32
 #	include <sys/time.h>
 #endif
-//#include <dirent.h>
 
 
 #include <tango.h>
@@ -165,6 +174,17 @@ StarterUtil::StarterUtil(Tango::DeviceProxy *database, vector<string> host_names
 
 	proc_util = new CheckProcessUtil();
 	proc_util->start();
+	//	Wait a bit to be sure 
+	//	that runningp rocess list is updated.
+#ifdef WIN32
+	_sleep(1000);
+#else
+	sleep(1);
+#endif
+
+	//	Build starter log file name.
+	LogPath(starter_log_file);
+	starter_log_file += "/Starter.log";
 }
 //+------------------------------------------------------------------
 /**
@@ -288,7 +308,7 @@ char *StarterUtil::check_exe_file(char *servname, vector<string>v_path)
 
 	//	server has not been found in path(es)
 	//----------------------------------------------
-	TangoSys_MemStream out_stream;
+	TangoSys_OMemStream out_stream;
 	out_stream << servname << " :  not found in \'StartDsPath\' property:" << endl;
 	for (i=0 ; i<v_path.size() ; i++)
 		out_stream << " - " << v_path[i] << endl;
@@ -327,6 +347,198 @@ char *StarterUtil::get_file_date(char *filename)
 	stat(filename, &info);
 	return strtime(info.st_mtime);
 }
+//+------------------------------------------------------------------
+/**
+ *	Log info for starter.
+ *	@param	message	 mesage to be logged
+ */
+//+------------------------------------------------------------------
+void StarterUtil::log_starter_info(string message)
+{
+
+	stringstream	strlog;
+	strlog << strtime(time(NULL)) << "\t" << message  << endl;
+
+	//	Read and close log file.
+	ifstream	ifs((char *)starter_log_file.c_str());
+	if (ifs)
+	{
+		strlog << ifs.rdbuf() << ends;
+		ifs.close();
+	}
+	//	Check for nb lines
+	string	str(strlog.str());
+	string::size_type	pos = 0;
+	int nb = 0;
+	while (nb<STARTER_LOG_DEPTH && (pos=str.find('\n', pos+1))!=string::npos)
+		nb++;
+
+	if (pos!=string::npos)
+		str = str.substr(0, pos);
+
+	//	Write to log file
+	ofstream	ofs((char *)starter_log_file.c_str());
+	ofs << str << ends;
+	ofs.close();
+}
+//+------------------------------------------------------------------
+/**
+ *	check if there is no to much log file and rename last one
+ *	@param	filename	file's name to get the date and rename.
+ */
+//+------------------------------------------------------------------
+void StarterUtil::manage_log_file_history(char *filename, int nb_max)
+{
+	string	log_file(filename);
+
+	//	Try to open log file
+	ifstream	ifs((char *)log_file.c_str());
+	if (!ifs)
+		return;	//	Does not exist-> do nothing
+	
+	//	Get the log file list
+	vector<string>	list =  get_log_file_list(log_file);
+	for (int i=0 ; i<list.size() ; i++)
+		cout << list[i] << endl;
+	
+	//	Check if too much files -> delete
+	while (list.size()>(nb_max-1))	//	-1 because a new one will exist bellow
+	{
+		cout << "Removing " << list[0] << endl;
+		if (remove(list[0].c_str())<0)
+			cerr << "remove failed : " << strerror(errno) << endl;
+		list.erase(list.begin());
+	}
+
+	//	Build date and time (of file creation) part
+	struct stat	info;
+	stat(filename, &info);
+	struct tm	*st = localtime(&info.st_mtime) ;
+	if (st->tm_year>=100)
+		st->tm_year -= 100 ;
+	char	strdate[32];
+	sprintf (strdate, "_[20%02d-%02d-%02d_%02d-%02d-%02d]",
+						st->tm_year, st->tm_mon+1, st->tm_mday,
+						st->tm_hour, st->tm_min, st->tm_sec ) ;
+
+	//	search position to insert (before extention)
+	string	str(filename);
+	string::size_type	pos = str.rfind(".log");
+	if (pos != string::npos)
+		str = str.substr(0, pos);
+
+	char	*new_filename = new char[strlen(filename) + strlen(strdate) +1];
+	strcpy(new_filename, str.c_str());
+	strcat(new_filename, strdate);
+	strcat(new_filename, ".log");
+	int ret = rename(filename, new_filename);
+	cout << "Renaming " << filename << " to " << new_filename;
+	if (ret<0)
+		cout << " failed : " << strerror(errno) << endl;
+	else
+		cout << "  done: " << ret << endl;
+	delete new_filename;
+}
+//-----------------------------------------------------------------------------
+//-----------------------------------------------------------------------------
+bool  alphabetical(string a,string b)
+{
+	//	returns alphabetic order.
+	return (a < b);
+}
+//+------------------------------------------------------------------
+/**
+ *	Rename log file list
+ *	@param	filename	log file name
+ */
+//+------------------------------------------------------------------
+vector<string> StarterUtil::get_log_file_list(string logfile)
+{
+	vector<string>	list;
+	//	Split path and file name
+	string::size_type	pos = logfile.rfind(slash);
+	if (pos != string::npos)
+	{
+		string	path = logfile.substr(0, pos);
+		pos++;
+		//	remove extention
+		string	str = logfile.substr(pos);
+		pos = str.rfind('.');
+		string	filter = str.substr(0, pos);
+		filter += "_[";
+		
+#ifndef WIN32
+		cout << "Searching " << filter << "  in " << path << endl;
+		DIR		*dir = opendir ((char *)path.c_str()) ;
+		if(dir==NULL)
+		{
+			string	desc;
+			//	error
+			switch(errno)
+			{
+			case EACCES: desc = "Permission denied.";
+				break;
+			case EMFILE: desc = "Too many file descriptors in use by process.";
+				break;
+			case ENFILE: desc = "Too many file are currently open in the system.";
+				break;
+			case ENOENT: desc = "Directory does not exist or NAME is an empty string.";
+				break;
+			case ENOMEM: desc = "Insufficient memory to complete the operation.";
+				break;
+			case ENOTDIR:desc  = "NAME is not a directory.";
+				break;
+			}
+			Tango::Except::throw_exception(
+					(const char *)"READ_FILE_LIST_FAILED",
+					desc,
+					(const char *)"StarterUtil::get_log_file_list()");
+
+		} 
+		struct dirent	*ent;
+		while (ent=readdir (dir))
+		{
+			string	name(ent->d_name);
+			pos = name.find(filter);
+			if (pos == 0)
+			{
+				string	full_name(path);
+				full_name += "/";
+				full_name += name;
+				list.push_back(full_name);
+			}
+		}
+#else
+		cout << "Searching " << filter << "  in " << path << endl;
+		path += "\\";
+		path += filter;
+		path += "*";
+		WCHAR	*w_path = ProcessData::string2wchar(path);
+
+		WIN32_FIND_DATA fd;
+		DWORD dwAttr = FILE_ATTRIBUTE_DIRECTORY;
+		HANDLE hFind = FindFirstFile(w_path, &fd);
+		if(hFind != INVALID_HANDLE_VALUE)
+		{
+			do
+			{
+				string	s = ProcessData::wchar2string(fd.cFileName);
+				list.push_back(s);
+			}
+			while (FindNextFile( hFind, &fd));
+			FindClose( hFind);
+		}
+		else
+		{
+			string desc = ProcessData::errorCodeToString(GetLastError(), "FindFirstFile()" );
+			cerr << "Invalid Handle value " << desc << endl;
+		}
+		delete w_path;
+#endif
+	}
+	sort(list.begin(), list.end(), alphabetical);
+	return list;
+}
 
 //+------------------------------------------------------------------
 /**
@@ -367,31 +579,6 @@ string StarterUtil::build_log_file_name(char *server)
 	log_file += ".log";
 	return log_file;
 }
-#ifdef WIN32
-//+------------------------------------------------------------------
-/**
- *	This method does not exist in visual cpp
- *
- *    The  strcasecmp()  and  strncasecmp()  functions  are  case-
- *    insensitive  versions  of   strcmp()  and  strncmp() respec-
- *    tively, described below.  They assume  the  ASCII  character
- *    set  and ignore differences in case when comparing lower and
- *    upper case characters.
- */
-//+------------------------------------------------------------------
-int StarterUtil::strcasecmp(const char *s1, const char *s2)
-{
-	if (strlen(s1) != strlen(s2))
-		return 1;
-
-	for ( ; *s1 ; s1++, s2++)
-		if (tolower(*s1) != tolower(*s2))
-			return 1;
-	return 0;
-}
-#endif
-
-
 
 
 
@@ -607,39 +794,6 @@ ControledServer *StarterUtil::get_server_by_name(string &servname, vector<Contro
 	return NULL;
 }
 
-//+----------------------------------------------------------------------------
-//
-// method : 		StarterUtil::start_timer()
-// 
-// description : 	initilize a timer
-//
-//-----------------------------------------------------------------------------
-void StarterUtil::start_timer()
-{
-#ifndef WIN32
-	gettimeofday(&before, NULL);
-#else
-#endif /* WIN32 */
-}
-
-//+----------------------------------------------------------------------------
-//
-// method : 		StarterUtil::get_timer_value()
-// 
-// description : 	Return the current value of the timer
-//
-//-----------------------------------------------------------------------------
-int	StarterUtil::get_timer_value()
-{
-#ifndef WIN32
-	gettimeofday(&after, NULL);
-	elapsed = (after.tv_sec-before.tv_sec)*1000000;
-	elapsed = (after.tv_usec-before.tv_usec) + elapsed;
-#else
-	elapsed = -1;
-#endif /* WIN32 */
-	return elapsed;
-}
 //+----------------------------------------------------------------------------
 //
 // method : 		StarterUtil::
