@@ -1,4 +1,4 @@
-static const char *RcsId = "$Header: /cvsroot/tango-cs/tango/cppserver/TangoAccessControl/DbUtils.cpp,v 1.12 2009/05/11 08:56:58 taurel Exp $";
+static const char *RcsId = "$Header: /cvsroot/tango-cs/tango/cppserver/TangoAccessControl/DbUtils.cpp,v 1.14 2009/09/11 10:46:09 taurel Exp $";
 //+=============================================================================
 //
 // file :         DbUtils.cpp
@@ -9,9 +9,15 @@ static const char *RcsId = "$Header: /cvsroot/tango-cs/tango/cppserver/TangoAcce
 //
 // $Author: taurel $
 //
-// $Revision: 1.12 $
+// $Revision: 1.14 $
 //
 // $Log: DbUtils.cpp,v $
+// Revision 1.14  2009/09/11 10:46:09  taurel
+// - Set the MySQL reconnection flag only for MySQL V5
+//
+// Revision 1.13  2009/09/10 07:48:55  taurel
+// - The database name can now be defined using a configure option
+//
 // Revision 1.12  2009/05/11 08:56:58  taurel
 // Fix bug in previous change !!
 //
@@ -56,6 +62,10 @@ static const char *RcsId = "$Header: /cvsroot/tango-cs/tango/cppserver/TangoAcce
 //
 //-=============================================================================
 
+#if HAVE_CONFIG_H
+#include <ac_config.h>
+#endif
+
 #include <tango.h>
 #include <TangoAccessControl.h>
 #include <TangoAccessControlClass.h>
@@ -88,7 +98,12 @@ void TangoAccessControl::mysql_connection()
 {
 	// Initialise variables to default values
 	//--------------------------------------------
+	
+#ifndef HAVE_CONFIG_H
 	char *database = (char *)"tango";
+#else
+	char *database = (char *)TANGO_DB_NAME;
+#endif
 	const char *mysql_user = NULL;
 	const char *mysql_password = NULL;
 
@@ -114,7 +129,8 @@ void TangoAccessControl::mysql_connection()
 	            << " , password = " << mysql_password << endl;
 
 	mysql_options(&mysql,MYSQL_READ_DEFAULT_GROUP,"client");
-	
+
+#if   (MYSQL_VERSION_ID > 50000)	
 	if(mysql_get_client_version() >= 50013)
 	{
 		my_bool my_auto_reconnect=1;
@@ -123,6 +139,7 @@ void TangoAccessControl::mysql_connection()
 		else
 			WARN_STREAM << "AccessControl: set mysql auto reconnect to true" << endl;
 	}
+#endif
 		
 	if (!mysql_real_connect(&mysql, NULL, mysql_user, mysql_password, database, 0, NULL, 0))
 	{
