@@ -27,9 +27,12 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 //
-// $Revision: 3.10 $
+// $Revision: 3.11 $
 //
 // $Log: accessproxy.cpp,v $
+// Revision 3.11  2009/09/22 11:04:45  taurel
+// - Environment variables in file also supported for Windows
+//
 // Revision 3.10  2009/04/20 13:25:50  taurel
 // - Fix bug in case of default constructed DeviceProxy and alias() method
 // - Add some ctors from "const char *" to make programmer's life easier
@@ -127,16 +130,10 @@ void AccessProxy::real_ctor()
 //	Check if forced mode
 //
 	string super_tango;
-#ifndef _TG_WINDOWS_
+
 	int ret = get_env_var("SUPER_TANGO",super_tango);
 	if (ret == 0)
 	{
-#else
-	char *forced_str = getenv("SUPER_TANGO");
-	if (forced_str != NULL)
-	{
-		super_tango = forced_str;
-#endif
 		transform(super_tango.begin(),super_tango.end(),super_tango.begin(),::tolower);
 		if (super_tango == "true")
 			forced = true;
