@@ -1,4 +1,4 @@
-static const char *RcsId = "$Id: api_util.cpp,v 3.27 2009/04/27 14:52:18 taurel Exp $\n$Name:  $";
+static const char *RcsId = "$Id: api_util.cpp,v 3.28 2009/08/27 07:22:43 taurel Exp $\n$Name: Release_7_1_1 $";
 
 //
 // cpp 	- C++ source code file for TANGO api class ApiUtil
@@ -28,6 +28,9 @@ static const char *RcsId = "$Id: api_util.cpp,v 3.27 2009/04/27 14:52:18 taurel
 // original 	- May 2002
 //
 // $Log: api_util.cpp,v $
+// Revision 3.28  2009/08/27 07:22:43  taurel
+// - Commit after anothre merge with Release_7_0_2-bugfixes branch
+//
 // Revision 3.27  2009/04/27 14:52:18  taurel
 // - No change, just to make tkcvs quiet
 //
@@ -290,14 +293,14 @@ namespace Tango
 ApiUtil *ApiUtil::_instance = NULL;
 omni_mutex ApiUtil::inst_mutex;
 
-ApiUtil *ApiUtil::instance()
+/*ApiUtil *ApiUtil::instance()
 {
 	omni_mutex_lock lo(inst_mutex);
 	
 	if (_instance == NULL)
 		_instance = new ApiUtil();
 	return _instance;
-}
+}*/
 
 //+----------------------------------------------------------------------------
 //
