@@ -2,6 +2,26 @@
 // apiexcept.h - include file for TANGO device api exceptions
 //
 // 
+// Copyright (C) :      2004,2005,2006,2007,2008,2009
+//						European Synchrotron Radiation Facility
+//                      BP 220, Grenoble 38043
+//                      FRANCE
+//
+// This file is part of Tango.
+//
+// Tango is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+// 
+// Tango is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+// 
+// You should have received a copy of the GNU Lesser General Public License
+// along with Tango.  If not, see <http://www.gnu.org/licenses/>.
+
 
 #ifndef _APIEXCEPT_H
 #define _APIEXCEPT_H
@@ -37,7 +57,7 @@ public:
 	NamedDevFailedList(const Tango::MultiDevFailed &,string,const char *,const char *);
 	NamedDevFailedList() {};
 		
-	long get_faulty_attr_nb() {return err_list.size();}
+	size_t get_faulty_attr_nb() {return err_list.size();}
 	bool call_failed() {if ((err_list.size()==0) && (errors.length()!=0))return true;else return false;}
 	
 	vector<NamedDevFailed>	err_list;
@@ -103,8 +123,10 @@ public: \
 	{\
 		Tango::DevErrorList errors(2);\
 		errors.length(2);\
+		Tango::Except::the_mutex.lock(); \
 		char *tmp = Tango::Except::print_CORBA_SystemException(&cex);\
 		errors[0].desc = CORBA::string_dup(tmp);\
+		Tango::Except::the_mutex.unlock(); \
 		errors[0].severity = sever;\
 		errors[0].reason = CORBA::string_dup("API_CorbaException");\
 		errors[0].origin = CORBA::string_dup(origin);\
@@ -122,8 +144,10 @@ public: \
 	{\
 		Tango::DevErrorList errors(2);\
 		errors.length(2);\
+		Tango::Except::the_mutex.lock(); \
 		char *tmp = Tango::Except::print_CORBA_SystemException(&cex);\
 		errors[0].desc = CORBA::string_dup(tmp);\
+		Tango::Except::the_mutex.unlock(); \
 		errors[0].severity = sever;\
 		errors[0].reason = CORBA::string_dup("API_CorbaException");\
 		errors[0].origin = CORBA::string_dup(origin);\
@@ -142,8 +166,10 @@ public: \
 	{\
 		Tango::DevErrorList errors(2);\
 		errors.length(2);\
+		Tango::Except::the_mutex.lock(); \
 		char *tmp = Tango::Except::print_CORBA_SystemException(&cex);\
 		errors[0].desc = CORBA::string_dup(tmp);\
+		Tango::Except::the_mutex.unlock(); \
 		errors[0].severity = sever;\
 		errors[0].reason = CORBA::string_dup("API_CorbaException");\
 		errors[0].origin = CORBA::string_dup(origin);\
@@ -160,8 +186,10 @@ public: \
 	{\
 		Tango::DevErrorList errors(2);\
 		errors.length(2);\
+		Tango::Except::the_mutex.lock(); \
 		char *tmp = Tango::Except::print_CORBA_SystemException(&cex);\
 		errors[0].desc = CORBA::string_dup(tmp);\
+		Tango::Except::the_mutex.unlock(); \
 		errors[0].severity = sever;\
 		errors[0].reason = CORBA::string_dup("API_CorbaException");\
 		errors[0].origin = CORBA::string_dup(origin.c_str());\
@@ -179,8 +207,10 @@ public: \
 	{\
 		Tango::DevErrorList errors(2);\
 		errors.length(2);\
+		Tango::Except::the_mutex.lock(); \
 		char *tmp = Tango::Except::print_CORBA_SystemException(&cex);\
 		errors[0].desc = CORBA::string_dup(tmp);\
+		Tango::Except::the_mutex.unlock(); \
 		errors[0].severity = sever;\
 		errors[0].reason = CORBA::string_dup("API_CorbaException");\
 		errors[0].origin = CORBA::string_dup(origin);\
@@ -309,6 +339,8 @@ MAKE_EXCEPT(NonSupportedFeature,ApiNonSuppExcept)
 MAKE_EXCEPT(AsynCall,ApiAsynExcept)
 MAKE_EXCEPT(AsynReplyNotArrived,ApiAsynNotThereExcept)
 MAKE_EXCEPT(EventSystemFailed,EventSystemExcept)
+MAKE_EXCEPT(DeviceUnlocked,DeviceUnlockedExcept)
+MAKE_EXCEPT(NotAllowed,NotAllowedExcept)
 
 //
 // Define macros for the management of the Corba TRANSIENT exception
@@ -362,6 +394,14 @@ MAKE_EXCEPT(EventSystemFailed,EventSystemExcept)
 	else \
 	{ \
 		connection_state = CONNECTION_NOTOK; \
+		if (get_lock_ctr() != 0) \
+		{ \
+			set_lock_ctr(0); \
+			TangoSys_OMemStream desc; \
+			desc << "Device " << dev_name() << " has lost your lock(s) (server re-start?) while executing command " << command << ends; \
+			DeviceUnlockedExcept::re_throw_exception(E,(const char*)DEVICE_UNLOCKED_REASON, \
+						desc.str(), (const char*)"Connection::command_inout()"); \
+		} \
 		ctr++; \
 \
 		if ((ext->tr_reco == false) || \
