@@ -132,6 +132,10 @@ public :
 	DevErrorList &get_access_except_errors() {return access_except_errors;}
 	void clear_access_except_errors() {access_except_errors.length(0);}
 	bool is_command_allowed(string &,string &);
+	
+	bool is_multi_tango_host() {return db_multi_svc;}
+	vector<string> &get_multi_host() {return multi_db_host;}
+	vector<string> &get_multi_port() {return multi_db_port;}
 
 #ifdef _TG_WINDOWS_
 	Database(CORBA::ORB *orb,string &,string &);
