@@ -1,4 +1,4 @@
-static const char *RcsId = "$Id: dbapi_datum.cpp,v 3.10 2009/04/20 13:25:50 taurel Exp $\n$Name:  $";
+static const char *RcsId = "$Id: dbapi_datum.cpp,v 3.13 2009/11/02 08:35:03 taurel Exp $\n$Name: Release_7_1_1 $";
 //
 // dbdatum.cpp 	- C++ source code file for TANGO dbapi class DbDatum
 //
@@ -27,6 +27,18 @@ static const char *RcsId = "$Id: dbapi_datum.cpp,v 3.10 2009/04/20 13:25:50 taur
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 //
 // $Log: dbapi_datum.cpp,v $
+// Revision 3.13  2009/11/02 08:35:03  taurel
+// - Fix warnings reported when compiling using the option -Wall
+//
+// Revision 3.12  2009/08/27 07:22:43  taurel
+// - Commit after anothre merge with Release_7_0_2-bugfixes branch
+//
+// Revision 3.11  2009/06/17 08:52:49  taurel
+// - Commit after a merge with branch Release_7_0_2-bugfixes
+//
+// Revision 3.10.2.1  2009/06/12 09:24:18  taurel
+// - Fix some typos in Exception reason field
+//
 // Revision 3.10  2009/04/20 13:25:50  taurel
 // - Fix bug in case of default constructed DeviceProxy and alias() method
 // - Add some ctors from "const char *" to make programmer's life easier
@@ -221,7 +233,7 @@ DbDatum::DbDatum(string p_name):ext(NULL)
 	value_string.resize(0);
 }
 
-DbDatum::DbDatum(const char *p_name):ext(NULL),name(p_name)
+DbDatum::DbDatum(const char *p_name):name(p_name),ext(NULL)
 {
 	value_size = 0;
 	value_string.resize(0);
@@ -650,7 +662,7 @@ bool DbDatum::operator >> (DevLong& datum)
 	{
 		if (exceptions_flags.test(isempty_flag))
 		{
-			ApiDataExcept::throw_exception((const char*)"Api_EmptyDbDbDatum",
+			ApiDataExcept::throw_exception((const char*)"API_EmptyDbDbDatum",
 					     (const char*)"cannot extract long, no data in DbDatum object ",
 					     (const char*)"DbDatum::operator >>(long)");
 		}
@@ -930,7 +942,7 @@ bool DbDatum::operator >> (float& datum)
 	{
 		if (exceptions_flags.test(isempty_flag))
 		{
-			ApiDataExcept::throw_exception((const char*)"Api_EmptyDbDbDatum",
+			ApiDataExcept::throw_exception((const char*)"API_EmptyDbDbDatum",
 					     (const char*)"cannot extract float, no data in DbDatum object ",
 					     (const char*)"DbDatum::operator >>(float)");
 		}
@@ -1007,7 +1019,7 @@ bool DbDatum::operator >> (double& datum)
 	{
 		if (exceptions_flags.test(isempty_flag))
 		{
-			ApiDataExcept::throw_exception((const char*)"Api_EmptyDbDatum",
+			ApiDataExcept::throw_exception((const char*)"API_EmptyDbDatum",
 					     (const char*)"cannot extract double, no data in DbDatum object ",
 					     (const char*)"DbDatum::operator >>(double)");
 		}
