@@ -323,7 +323,7 @@ enum cb_sub_model
 class ApiUtil
 {
 public:
-	TANGO_IMP_EXP static ApiUtil *instance();
+	TANGO_IMP_EXP static inline ApiUtil *instance();
 
 	CORBA::ORB_ptr get_orb() {return CORBA::ORB::_duplicate(_orb);}
 	void set_orb(CORBA::ORB_ptr orb_in) {_orb = orb_in;}
@@ -579,6 +579,7 @@ public :
 	DeviceAttribute(string&, DevLong);
 	DeviceAttribute(string&, double);
 	DeviceAttribute(string&, string&);
+	DeviceAttribute(string&, const char *);
 	DeviceAttribute(string&, float);
 	DeviceAttribute(string&, bool);
 	DeviceAttribute(string&, unsigned short);
@@ -619,6 +620,7 @@ public :
 	DeviceAttribute(const char *, DevLong);
 	DeviceAttribute(const char *, double);
 	DeviceAttribute(const char *, string&);
+	DeviceAttribute(const char *, const char *);
 	DeviceAttribute(const char *, float);
 	DeviceAttribute(const char *, bool);
 	DeviceAttribute(const char *, unsigned short);
@@ -1034,10 +1036,9 @@ protected :
 	ConnectionExt		*ext; 	// Class extension
 	
 	DeviceData redo_synch_cmd(TgRequest &);
-#ifndef _TG_WINDOWS_
+
 	int get_env_var(const char *,string &);
 	int get_env_var_from_file(string &,const char *,string &);
-#endif
 		
 public :
 	virtual string dev_name()=0;
@@ -1051,6 +1052,7 @@ public :
 	string &get_db_port() {return db_port;}
 	int get_db_port_num() {return db_port_num;}
 	bool get_from_env_var() {return from_env_var;}
+	void get_fqdn(string &);
 	
 	void connect(string &name);
 	virtual void reconnect(bool);
@@ -1132,7 +1134,7 @@ private :
 	omni_mutex 			netcalls_mutex;
 	int					lock_ctr;
 	int					lock_valid;
-
+	
 	void connect_to_adm_device();
 	
 	void retrieve_read_args(TgRequest &,vector<string> &);
@@ -1187,7 +1189,7 @@ public :
 	DeviceProxy & operator=(const DeviceProxy &);
 	virtual ~DeviceProxy();
 	
-	DeviceProxy():Connection((CORBA::ORB *)NULL),adm_device(NULL),ext_proxy(NULL),db_dev(NULL)
+	DeviceProxy():Connection((CORBA::ORB *)NULL),db_dev(NULL),adm_device(NULL),ext_proxy(NULL)
 	{dbase_used = false;}
 
 //
@@ -1244,6 +1246,8 @@ public :
 	
 	virtual DeviceAttribute read_attribute(string&);
 	virtual DeviceAttribute read_attribute(const char *at) {string str(at);return read_attribute(str);}
+	void read_attribute(const char *,DeviceAttribute &);
+	void read_attribute(string &at,DeviceAttribute &da) {read_attribute(at.c_str(),da);}
 	virtual vector<DeviceAttribute> *read_attributes(vector<string>&);
 	
 	virtual void write_attribute(DeviceAttribute&);
@@ -1500,6 +1504,92 @@ public :
 		
 };
 
+//
+// 					Some inline methods
+//					-------------------
+//
+
+inline ApiUtil *ApiUtil::instance()
+{
+	omni_mutex_lock lo(inst_mutex);
+	
+	if (_instance == NULL)
+		_instance = new ApiUtil();
+	return _instance;
+}
+
+//
+//					Some macros
+//					-----------
+//
+
+#define READ_ATT_EXCEPT(NAME_CHAR) \
+		catch (Tango::ConnectionFailed &e) \
+		{ \
+			TangoSys_OMemStream desc; \
+			desc << "Failed to read_attribute on device " << device_name; \
+			desc << ", attribute " << NAME_CHAR << ends; \
+			ApiConnExcept::re_throw_exception(e,(const char*)"API_AttributeFailed", \
+                        	desc.str(), (const char*)"DeviceProxy::read_attribute()"); \
+		} \
+		catch (Tango::DevFailed &e) \
+		{ \
+			TangoSys_OMemStream desc; \
+			desc << "Failed to read_attribute on device " << device_name; \
+			desc << ", attribute " << NAME_CHAR << ends; \
+			Except::re_throw_exception(e,(const char*)"API_AttributeFailed", \
+                        	desc.str(), (const char*)"DeviceProxy::read_attribute()"); \
+		} \
+		catch (CORBA::TRANSIENT &trans) \
+		{ \
+			TRANSIENT_NOT_EXIST_EXCEPT(trans,"DeviceProxy","read_attribute"); \
+		} \
+		catch (CORBA::OBJECT_NOT_EXIST &one) \
+		{ \
+			if (one.minor() == omni::OBJECT_NOT_EXIST_NoMatch) \
+			{ \
+				TRANSIENT_NOT_EXIST_EXCEPT(one,"DeviceProxy","read_attribute"); \
+			} \
+			else \
+			{ \
+				connection_state = CONNECTION_NOTOK; \
+				TangoSys_OMemStream desc; \
+				desc << "Failed to read_attribute on device " << device_name << ends; \
+				ApiCommExcept::re_throw_exception(one, \
+							      (const char*)"API_CommunicationFailed", \
+                        				      desc.str(), \
+							      (const char*)"DeviceProxy::read_attribute()"); \
+			} \
+		} \
+		catch (CORBA::COMM_FAILURE &comm) \
+		{ \
+			if (comm.minor() == omni::COMM_FAILURE_WaitingForReply) \
+			{ \
+				TRANSIENT_NOT_EXIST_EXCEPT(comm,"DeviceProxy","read_attribute"); \
+			} \
+			else \
+			{ \
+				connection_state = CONNECTION_NOTOK; \
+				TangoSys_OMemStream desc; \
+				desc << "Failed to read_attribute on device " << device_name << ends; \
+				ApiCommExcept::re_throw_exception(comm, \
+							      (const char*)"API_CommunicationFailed", \
+                        				      desc.str(), \
+							      (const char*)"DeviceProxy::read_attribute()"); \
+			} \
+		} \
+		catch (CORBA::SystemException &ce) \
+        { \
+			connection_state = CONNECTION_NOTOK; \
+			TangoSys_OMemStream desc; \
+			desc << "Failed to read_attribute on device " << device_name << ends; \
+			ApiCommExcept::re_throw_exception(ce, \
+						      (const char*)"API_CommunicationFailed", \
+                        			      desc.str(), \
+						      (const char*)"DeviceProxy::read_attribute()"); \
+		}
+	
+//
 // 					Small utility classes
 //					---------------------
  
