@@ -8,9 +8,55 @@
 //
 // author(s) :          N.Leclercq
 //
-// $Revision: 3.14 $
+// Copyright (C) :      2004,2005,2006,2007,2008,2009
+//						European Synchrotron Radiation Facility
+//                      BP 220, Grenoble 38043
+//                      FRANCE
+//
+// This file is part of Tango.
+//
+// Tango is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+// 
+// Tango is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+// 
+// You should have received a copy of the GNU Lesser General Public License
+// along with Tango.  If not, see <http://www.gnu.org/licenses/>.
+//
+// $Revision: 3.20 $
 //
 // $Log: group.cpp,v $
+// Revision 3.20  2009/01/21 12:45:15  taurel
+// - Change CopyRights for 2009
+//
+// Revision 3.19  2008/10/06 15:02:16  taurel
+// - Changed the licensing info from GPL to LGPL
+//
+// Revision 3.18  2008/10/02 16:09:25  taurel
+// - Add some licensing information in each files...
+//
+// Revision 3.17  2008/05/20 12:42:30  taurel
+// - Commit after merge with release 7 branch
+//
+// Revision 3.15.2.1  2008/03/04 14:04:50  nleclercq
+// Fixed a problem in Group::next_req_id
+// Revision 3.16  2008/03/04 13:55:10  nleclercq
+// Fixed a pb in Group::next_req_id
+//
+// Revision 1.2  2008/03/04 12:58:03  leclercq
+// Fixed a bug in Group::next_req_id
+//
+// Revision 1.1  2008/02/28 10:36:10  leclercq
+// Added 5.5.2 patches
+//
+// Revision 3.15  2007/06/20 10:10:38  nleclercq
+// Better error handling in GroupDeviceElement::read_attributes_reply
+//
 // Revision 3.14  2007/03/06 08:20:45  taurel
 // - Added 64 bits data types for 64 bits computer...
 //
@@ -24,10 +70,6 @@
 // Add a constructor to GroupDeviceElement class with a timeout parameter.
 //
 //
-// copyleft :           European Synchrotron Radiation Facility
-//                      BP 220, Grenoble 38043
-//                      FRANCE
-//
 //=============================================================================
 
 #include <group.h>
@@ -379,7 +421,7 @@ GroupAttrReply::GroupAttrReply (const std::string& _dev_name,
                                 const Tango::DeviceAttribute& _dev_attr)
  : GroupReply(_dev_name, _obj_name, true), data_m(_dev_attr)
 {
-   
+  //-noop impl  
 }
 //-----------------------------------------------------------------------------
 GroupAttrReply::GroupAttrReply (const std::string& _dev_name, 
@@ -1269,7 +1311,9 @@ GroupReplyList Group::write_attribute_reply (long req_id, long tmo)
 //-----------------------------------------------------------------------------
 long Group::next_req_id (void) 
 {
-  asynch_req_id = (asynch_req_id++) % (long)0xFF;
+ 	asynch_req_id++;
+  asynch_req_id %= (long)0x0FFF;
+  //- std::cerr << "Group::next_req_id::asynch_req_id = " << asynch_req_id << std::endl;
   return asynch_req_id;
 }
 //-----------------------------------------------------------------------------
@@ -1691,7 +1735,15 @@ GroupAttrReplyList GroupDeviceElement::read_attribute_reply (long id, long tmo)
     }
     else 
     {
-      rl.push_back(GroupAttrReply(get_name(), it->second.obj_names[0], *da));
+		  if (da->has_failed())
+      {
+        DevFailed df(da->get_err_stack());
+        rl.push_back(GroupAttrReply(get_name(), it->second.obj_names[0], df));
+      }
+      else
+      {
+        rl.push_back(GroupAttrReply(get_name(), it->second.obj_names[0], *da));
+      }
       delete da;
     }
   }
@@ -1758,7 +1810,8 @@ GroupAttrReplyList GroupDeviceElement::read_attributes_reply (long id, long tmo)
 
   //- search actual asynch request id in this' repository
   AsynchRequestRepIterator it = arp.find(id);
-  if (it == arp.end()) {
+  if (it == arp.end()) 
+  {
     //- error description
     Tango::DevErrorList errors(1);
 		errors.length(1);
@@ -1800,7 +1853,8 @@ GroupAttrReplyList GroupDeviceElement::read_attributes_reply (long id, long tmo)
   try 
   {
     std::vector<DeviceAttribute>* dal = dev_proxy()->read_attributes_reply(it->second.rq_id, tmo);
-    if (dal == 0) {
+    if (dal == 0) 
+    {
       Tango::DevErrorList errors(1);
 		  errors.length(1);
 		  errors[0].severity = Tango::ERR;
@@ -1808,23 +1862,37 @@ GroupAttrReplyList GroupDeviceElement::read_attributes_reply (long id, long tmo)
 		  errors[0].reason = CORBA::string_dup("Tango::DeviceProxy::read_attribute_reply returned NULL");
 		  errors[0].origin = CORBA::string_dup("GroupDeviceElement::read_attribute_reply");
       DevFailed df(errors);
-      for (a = 0; a < it->second.obj_names.size(); a++) {
+      for (a = 0; a < it->second.obj_names.size(); a++) 
+      {
         rl.push_back(GroupAttrReply(get_name(), it->second.obj_names[a], df));
       }
     }
-    else {
-      for (a = 0; a < it->second.obj_names.size(); a++) {
-        rl.push_back(GroupAttrReply(get_name(), it->second.obj_names[a], (*dal)[a]));
-      }
+    else 
+    {
+      for (a = 0; a < it->second.obj_names.size(); a++) 
+      {
+        if ((*dal)[a].has_failed())
+        {
+          DevFailed df((*dal)[a].get_err_stack());
+          rl.push_back(GroupAttrReply(get_name(), it->second.obj_names[a], df));
+        }
+        else
+        {
+          rl.push_back(GroupAttrReply(get_name(), it->second.obj_names[a], (*dal)[a]));
+        }
+      } 
       delete dal;
     }
   }
-  catch (const Tango::DevFailed& df) {
-    for (a = 0; a < it->second.obj_names.size(); a++) {
+  catch (const Tango::DevFailed& df) 
+  {
+    for (a = 0; a < it->second.obj_names.size(); a++) 
+    {
       rl.push_back(GroupAttrReply(get_name(), it->second.obj_names[a], df));
     }
   }
-  catch (...) {
+  catch (...) 
+  {
     //- create a pseudo devfailed
     Tango::DevErrorList errors(1);
 		errors.length(1);
@@ -1833,7 +1901,8 @@ GroupAttrReplyList GroupDeviceElement::read_attributes_reply (long id, long tmo)
 		errors[0].reason = CORBA::string_dup("unknown exception caught");
 		errors[0].origin = CORBA::string_dup("GroupDeviceElement::read_attribute_reply");
     DevFailed df(errors);
-    for (a = 0; a < it->second.obj_names.size(); a++) {
+    for (a = 0; a < it->second.obj_names.size(); a++) 
+    {
       rl.push_back(GroupAttrReply(get_name(), it->second.obj_names[a], df));
     }
   }
