@@ -1,4 +1,4 @@
-static const char *RcsId = "$Id: proxy_asyn.cpp,v 3.25 2009/03/27 13:05:10 taurel Exp $\n$Name:  $";
+static const char *RcsId = "$Id: proxy_asyn.cpp,v 3.26 2009/09/01 14:02:50 taurel Exp $\n$Name: Release_7_1_1 $";
 
 //
 // cpp 	- C++ source code file for TANGO api Connection and DeviceProxy
@@ -30,6 +30,9 @@ static const char *RcsId = "$Id: proxy_asyn.cpp,v 3.25 2009/03/27 13:05:10 taure
 //
 //
 // $Log: proxy_asyn.cpp,v $
+// Revision 3.26  2009/09/01 14:02:50  taurel
+// - Still some HP-UX code !!
+//
 // Revision 3.25  2009/03/27 13:05:10  taurel
 // - Fix bug due to new Attribute format data member in AttributeValue4
 // structure
@@ -1056,7 +1059,7 @@ vector<DeviceAttribute> *DeviceProxy::read_attributes_reply(long id)
 					(*dev_attr)[i].ext->err_list.inout().length(nb_except + 1);
 					(*dev_attr)[i].ext->err_list[nb_except].reason = CORBA::string_dup("API_AttributeFailed");
 					(*dev_attr)[i].ext->err_list[nb_except].origin = CORBA::string_dup("DeviceProxy::read_attribute()");
-#if ((defined _TG_WINDOWS_) || (defined __SUNPRO_CC) || (defined GCC_STD) || (defined __HP_aCC))
+#if ((defined _TG_WINDOWS_) || (defined __SUNPRO_CC) || (defined GCC_STD))
 					string st = desc.str();
 					(*dev_attr)[i].ext->err_list[nb_except].desc = CORBA::string_dup(st.c_str());
 #else
@@ -1206,7 +1209,7 @@ DeviceAttribute *DeviceProxy::read_attribute_reply(long id)
 				dev_attr->ext->err_list.inout().length(nb_except + 1);
 				dev_attr->ext->err_list[nb_except].reason = CORBA::string_dup("API_AttributeFailed");
 				dev_attr->ext->err_list[nb_except].origin = CORBA::string_dup("DeviceProxy::read_attribute_reply()");
-#if ((defined _TG_WINDOWS_) || (defined __SUNPRO_CC) || (defined GCC_STD) || (defined __HP_aCC))
+#if ((defined _TG_WINDOWS_) || (defined __SUNPRO_CC) || (defined GCC_STD))
 				string st = desc.str();
 				dev_attr->ext->err_list[nb_except].desc = CORBA::string_dup(st.c_str());
 #else
@@ -1404,7 +1407,7 @@ vector<DeviceAttribute> *DeviceProxy::read_attributes_reply(long id,long call_ti
 				(*dev_attr)[i].ext->err_list.inout().length(nb_except + 1);
 				(*dev_attr)[i].ext->err_list[nb_except].reason = CORBA::string_dup("API_AttributeFailed");
 				(*dev_attr)[i].ext->err_list[nb_except].origin = CORBA::string_dup("DeviceProxy::read_attributes_reply()");
-#if ((defined _TG_WINDOWS_) || (defined __SUNPRO_CC) || (defined GCC_STD) || (defined __HP_aCC))
+#if ((defined _TG_WINDOWS_) || (defined __SUNPRO_CC) || (defined GCC_STD))
 				string st = desc.str();
 				(*dev_attr)[i].ext->err_list[nb_except].desc = CORBA::string_dup(st.c_str());
 #else
@@ -1586,7 +1589,7 @@ DeviceAttribute *DeviceProxy::read_attribute_reply(long id,long call_timeout)
 			dev_attr->ext->err_list.inout().length(nb_except + 1);
 			dev_attr->ext->err_list[nb_except].reason = CORBA::string_dup("API_AttributeFailed");
 			dev_attr->ext->err_list[nb_except].origin = CORBA::string_dup("DeviceProxy::read_attribute_reply()");
-#if ((defined _TG_WINDOWS_) || (defined __SUNPRO_CC) || (defined GCC_STD) || (defined __HP_aCC))
+#if ((defined _TG_WINDOWS_) || (defined __SUNPRO_CC) || (defined GCC_STD))
 			string st = desc.str();
 			dev_attr->ext->err_list[nb_except].desc = CORBA::string_dup(st.c_str());
 #else
