@@ -1,4 +1,4 @@
-static const char *RcsId = "$Id: attrdesc.cpp,v 3.14 2009/01/21 12:49:04 taurel Exp $\n$Name:  $";
+static const char *RcsId = "$Id: attrdesc.cpp,v 3.15 2009/09/16 12:16:19 taurel Exp $\n$Name: Release_7_1_1 $";
 
 //+============================================================================
 //
@@ -36,9 +36,13 @@ static const char *RcsId = "$Id: attrdesc.cpp,v 3.14 2009/01/21 12:49:04 taurel
 // You should have received a copy of the GNU Lesser General Public License
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 //
-// $Revision: 3.14 $
+// $Revision: 3.15 $
 //
 // $Log: attrdesc.cpp,v $
+// Revision 3.15  2009/09/16 12:16:19  taurel
+// - Better management of the RDS alarm properties. They were not taken into
+// account by the set_default_properties() method
+//
 // Revision 3.14  2009/01/21 12:49:04  taurel
 // - Change CopyRights for 2009
 //
@@ -412,6 +416,12 @@ void Attr::set_default_properties(UserDefaultAttrProp &prop_list)
 
 	if (prop_list.max_alarm.empty() == false)
 		user_default_properties.push_back(AttrProperty("max_alarm",prop_list.max_alarm));
+		
+	if (prop_list.delta_val.empty() == false)
+		user_default_properties.push_back(AttrProperty("delta_val",prop_list.delta_val));
+		
+	if (prop_list.delta_t.empty() == false)
+		user_default_properties.push_back(AttrProperty("delta_t",prop_list.delta_t));
 
 }
 
