@@ -1,4 +1,4 @@
-static const char *RcsId = "$Id: blackbox.cpp,v 3.23 2009/03/27 12:21:46 taurel Exp $\n$Name:  $";
+static const char *RcsId = "$Id: blackbox.cpp,v 3.24 2009/09/01 07:41:31 taurel Exp $\n$Name: Release_7_1_1 $";
 
 //+============================================================================
 //
@@ -36,9 +36,12 @@ static const char *RcsId = "$Id: blackbox.cpp,v 3.23 2009/03/27 12:21:46 taurel
 // You should have received a copy of the GNU Lesser General Public License
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 //
-// $Revision: 3.23 $
+// $Revision: 3.24 $
 //
 // $Log: blackbox.cpp,v $
+// Revision 3.24  2009/09/01 07:41:31  taurel
+// - Commit after test suite for Tango 7.1
+//
 // Revision 3.23  2009/03/27 12:21:46  taurel
 // - Now the peer address coming from omniORB is coded in IP v6 format!
 //
@@ -1440,7 +1443,9 @@ void BlackBox::build_info_as_str(long index)
 //
 
 	bool ipv6=false;
-	if ((box[index].host_ip_str[0] != '\0') && (box[index].host_ip_str[0] != 'p'))
+	if ((box[index].host_ip_str[0] != '\0') && 
+	    (box[index].host_ip_str[0] != 'p') && 
+		(box[index].host_ip_str[5] != 'u'))
 	{
 		string omni_addr = box[index].host_ip_str;
 		string::size_type pos;
@@ -1557,6 +1562,11 @@ void BlackBox::build_info_as_str(long index)
 			}
 		}
 	}
+	else if (box[index].host_ip_str[5] == 'u')
+	{
+		Tango::Util *tg = Tango::Util::instance();
+		elt_str = elt_str + "requested from " + tg->get_host_name();
+	}
 	else if (box[index].host_ip_str[0] == 'p')
 	{
 		elt_str = elt_str + "requested from polling";
