@@ -1,4 +1,4 @@
-static const char *RcsId = "$Id: device_3.cpp,v 3.45 2009/04/29 14:33:10 jensmeyer Exp $\n$Name:  $";
+static const char *RcsId = "$Id: device_3.cpp,v 3.50 2009/11/09 12:04:31 taurel Exp $\n$Name: Release_7_1_1 $";
 
 //+============================================================================
 //
@@ -35,9 +35,28 @@ static const char *RcsId = "$Id: device_3.cpp,v 3.45 2009/04/29 14:33:10 jensmey
 // You should have received a copy of the GNU Lesser General Public License
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 //
-// $Revision: 3.45 $
+// $Revision: 3.50 $
 //
 // $Log: device_3.cpp,v $
+// Revision 3.50  2009/11/09 12:04:31  taurel
+// - The attribute mutex management is in the AttributeValue_4 struct
+//
+// Revision 3.49  2009/10/27 16:33:44  taurel
+// - Fix a bug in attribute mutex management in case the attribute
+// is_allowed() method returns false
+//
+// Revision 3.48  2009/10/23 14:36:27  taurel
+// - Tango 7.1.1
+// - Fix bugs 2880372 and 2881841
+// - Now support event in case of Tango system with multi db server
+// - The polling threads start with polling inactive
+//
+// Revision 3.47  2009/09/18 09:18:06  taurel
+// - End of attribute serialization implementation?
+//
+// Revision 3.46  2009/09/17 08:28:06  taurel
+// - Add a mutual exclusion to protect attribute buffer
+//
 // Revision 3.45  2009/04/29 14:33:10  jensmeyer
 // Corrected sub device diagnostics when accessing
 // internal devices in a server.
@@ -576,13 +595,16 @@ void Device_3Impl::read_attributes_no_except(const Tango::DevVarStringArray& nam
 //  During device access inside the same server,
 //  the thread stays the same!
 //
+
 	SubDevDiag &sub = (Tango::Util::instance())->get_sub_dev_diag();
 	string last_associated_device = sub.get_associated_device();
 	sub.set_associated_device(get_name());
 
-
+//
 // Catch all execeptions to set back the associated device after
 // execution
+//
+
 	try
 	{
 	
@@ -599,6 +621,8 @@ void Device_3Impl::read_attributes_no_except(const Tango::DevVarStringArray& nam
 		long state_idx,status_idx;
 		long i;
 
+		state_idx = status_idx = -1;
+		
 		for (i = 0;i < nb_names;i++)
 		{
 			long j;
@@ -683,6 +707,7 @@ void Device_3Impl::read_attributes_no_except(const Tango::DevVarStringArray& nam
 				}
 			}		
 		}
+		
 		long nb_wanted_attr = wanted_attr.size();
 		long nb_wanted_w_attr = wanted_w_attr.size();
 
@@ -725,12 +750,15 @@ void Device_3Impl::read_attributes_no_except(const Tango::DevVarStringArray& nam
 		{
 			if (wanted_attr[i].idx_in_multi_attr != -1)
 			{
+				Attribute &att = dev_attr->get_attr_by_ind(wanted_attr[i].idx_in_multi_attr);
+				bool is_allowed_failed = false;
+				
 				try
 				{
-					Attribute &att = dev_attr->get_attr_by_ind(wanted_attr[i].idx_in_multi_attr);
 					vector<Tango::Attr *> &attr_vect = device_class->get_class_attr()->get_attr_list();
 					if (attr_vect[att.get_attr_idx()]->is_allowed(this,Tango::READ_REQ) == false)
 					{
+						is_allowed_failed = true;
 						TangoSys_OMemStream o;
 
 						o << "It is currently not allowed to read attribute ";
@@ -740,6 +768,22 @@ void Device_3Impl::read_attributes_no_except(const Tango::DevVarStringArray& nam
 					        			o.str(),
 					        			(const char *)"Device_3Impl::read_attributes_no_except");
 					}
+
+//
+// Take the attribute mutex before calling the user read method
+//
+
+					if ((att.get_attr_serial_model() == ATTR_BY_KERNEL) && (back4 != NULL))
+					{
+						cout4 << "Locking attribute mutex for attribute " << att.get_name() << endl;
+						omni_mutex *attr_mut = att.get_attr_mutex();
+						attr_mut->lock();
+					}
+					
+//
+// Call the user read method
+//
+
 					attr_vect[att.get_attr_idx()]->read(this,att);
 
 				}
@@ -761,6 +805,13 @@ void Device_3Impl::read_attributes_no_except(const Tango::DevVarStringArray& nam
 					}
 					else
 					{
+						if ((att.get_attr_serial_model() == ATTR_BY_KERNEL) && (is_allowed_failed == false))
+						{
+							cout4 << "Releasing attribute mutex for attribute " << att.get_name() << " due to error" << endl;
+							omni_mutex *attr_mut = att.get_attr_mutex();
+							attr_mut->unlock();
+						}
+							
 						(*back4)[index].err_list = e.errors;
 						(*back4)[index].quality = Tango::ATTR_INVALID;
 						(*back4)[index].name = CORBA::string_dup(names[wanted_attr[i].idx_in_names]);
@@ -776,9 +827,9 @@ void Device_3Impl::read_attributes_no_except(const Tango::DevVarStringArray& nam
 
 		for (i = 0;i < nb_wanted_w_attr;i++)
 		{
+			Tango::AttrWriteType w_type = dev_attr->get_attr_by_ind(wanted_w_attr[i].idx_in_multi_attr).get_writable();
 			try
 			{
-				Tango::AttrWriteType w_type = dev_attr->get_attr_by_ind(wanted_w_attr[i].idx_in_multi_attr).get_writable();
 				if ((w_type == Tango::READ_WITH_WRITE) || (w_type == Tango::WRITE)) 
 					dev_attr->get_attr_by_ind(wanted_w_attr[i].idx_in_multi_attr).set_rvalue();
 			}
@@ -800,6 +851,15 @@ void Device_3Impl::read_attributes_no_except(const Tango::DevVarStringArray& nam
 				}
 				else
 				{
+					Attribute &att = dev_attr->get_attr_by_ind(wanted_w_attr[i].idx_in_multi_attr);
+					AttrSerialModel atsm = att.get_attr_serial_model();
+					if ((atsm != ATTR_NO_SYNC) && (w_type == Tango::READ_WITH_WRITE))
+					{
+						cout4 << "Releasing attribute mutex for attribute " << att.get_name() << " due to error" << endl;
+						omni_mutex *attr_mut = (atsm == ATTR_BY_KERNEL) ? att.get_attr_mutex() : att.get_user_attr_mutex();
+						attr_mut->unlock();
+					}
+					
 					(*back4)[index].err_list = e.errors;		
 					(*back4)[index].quality = Tango::ATTR_INVALID;
 					(*back4)[index].name = CORBA::string_dup(names[wanted_w_attr[i].idx_in_names]);
@@ -1005,6 +1065,14 @@ void Device_3Impl::read_attributes_no_except(const Tango::DevVarStringArray& nam
 						}
 						else
 						{
+							AttrSerialModel atsm = att.get_attr_serial_model();
+							if ((i != state_idx) && (i != status_idx) && (atsm != ATTR_NO_SYNC) && (att.get_writable() != Tango::WRITE))
+							{
+								cout4 << "Releasing attribute mutex for attribute " << att.get_name() << " due to error" << endl;
+								omni_mutex *attr_mut = (atsm == ATTR_BY_KERNEL) ? att.get_attr_mutex() : att.get_user_attr_mutex();
+								attr_mut->unlock();
+							}
+							
 							(*back4)[index].err_list.length(1);
 							(*back4)[index].err_list[0].severity = Tango::ERR;
 							(*back4)[index].err_list[0].reason = CORBA::string_dup("API_AttrValueNotSet");
@@ -1082,6 +1150,16 @@ void Device_3Impl::read_attributes_no_except(const Tango::DevVarStringArray& nam
 							}
 							else
 							{
+								AttrSerialModel atsm = att.get_attr_serial_model();
+								if ((atsm != ATTR_NO_SYNC) && (w_type != Tango::WRITE))
+								{
+									cout4 << "Giving attribute mutex to CORBA structure for attribute " << att.get_name() << endl;
+									if (atsm == ATTR_BY_KERNEL)
+										GIVE_ATT_MUTEX(back4,index,att);
+									else
+										GIVE_USER_ATT_MUTEX(back4,index,att);
+								}
+							
 								(*back4)[index].time = att.get_when();
 								(*back4)[index].quality = att.get_quality();
 								(*back4)[index].data_format = att.get_data_format();
@@ -1123,6 +1201,10 @@ void Device_3Impl::read_attributes_no_except(const Tango::DevVarStringArray& nam
 							}
 							else
 							{
+								cout4 << "Asking CORBA structure to release attribute mutex for attribute " << att.get_name() << endl;
+								if (att.get_writable() != Tango::WRITE)
+									REL_ATT_MUTEX(back4,index,att);
+								
 								(*back4)[index].err_list = e.errors;
 								(*back4)[index].quality = Tango::ATTR_INVALID;
 								(*back4)[index].name = CORBA::string_dup(att.get_name().c_str());
@@ -1149,6 +1231,14 @@ void Device_3Impl::read_attributes_no_except(const Tango::DevVarStringArray& nam
 					}
 					else
 					{
+						AttrSerialModel atsm = att.get_attr_serial_model();
+						if ((atsm != ATTR_NO_SYNC) && (att.get_writable() != Tango::WRITE))
+						{
+							cout4 << "Releasing attribute mutex for attribute " << att.get_name() << " due to error" << endl;
+							omni_mutex *attr_mut = (atsm == ATTR_BY_KERNEL) ? att.get_attr_mutex() : att.get_user_attr_mutex();
+							attr_mut->unlock();
+						}
+						
 						(*back4)[index].time = att.get_when();
 						(*back4)[index].quality = qual;
 						(*back4)[index].data_format = att.get_data_format();
@@ -2890,6 +2980,7 @@ void Device_3Impl::alarmed_not_read(vector<AttIdx> &wanted_attr)
 	vector<long> &alarmed_list = dev_attr->get_alarm_list();
 	long nb_alarmed_attr = alarmed_list.size();
 	long nb_attr = wanted_attr.size();
+	
 	ext->alarmed_not_read.clear();
 		
 	for (int i = 0;i < nb_alarmed_attr;i++)
