@@ -1,4 +1,4 @@
-static const char *RcsId = "$Id: device_4.cpp,v 3.9 2009/01/21 12:49:04 taurel Exp $";
+static const char *RcsId = "$Id: device_4.cpp,v 3.11 2009/11/09 12:04:31 taurel Exp $";
 
 //+============================================================================
 //
@@ -35,9 +35,15 @@ static const char *RcsId = "$Id: device_4.cpp,v 3.9 2009/01/21 12:49:04 taurel E
 // You should have received a copy of the GNU Lesser General Public License
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 //
-// $Revision: 3.9 $
+// $Revision: 3.11 $
 //
 // $Log: device_4.cpp,v $
+// Revision 3.11  2009/11/09 12:04:31  taurel
+// - The attribute mutex management is in the AttributeValue_4 struct
+//
+// Revision 3.10  2009/09/17 08:28:06  taurel
+// - Add a mutual exclusion to protect attribute buffer
+//
 // Revision 3.9  2009/01/21 12:49:04  taurel
 // - Change CopyRights for 2009
 //
@@ -101,7 +107,6 @@ static const char *RcsId = "$Id: device_4.cpp,v 3.9 2009/01/21 12:49:04 taurel E
 #include <tango.h>
 #include <device_4.h>
 
-
 namespace Tango
 {
 
@@ -546,7 +551,7 @@ throw (Tango::DevFailed, CORBA::SystemException)
 
 //+-------------------------------------------------------------------------
 //
-// method : 		Device_3Impl::read_attributes_4 
+// method : 		Device_4Impl::read_attributes_4 
 // 
 // description : 	Method called for each read_attributes operation executed
 //			from any client on a Tango device version 4.
@@ -609,8 +614,8 @@ throw (Tango::DevFailed, CORBA::SystemException)
 	
 	try
 	{	
-		back = new Tango::AttributeValueList_4(nb_names);
-		back->length(nb_names);
+		Tango::AttributeValue_4 *l_back = new Tango::AttributeValue_4 [nb_names];
+		back = new Tango::AttributeValueList_4(nb_names,nb_names,l_back,true);
 		
 		for (unsigned long loop = 0;loop < nb_names;loop++)
 			(*back)[loop].value.union_no_data(true);
@@ -631,7 +636,6 @@ throw (Tango::DevFailed, CORBA::SystemException)
 	
 	if (source == Tango::DEV)
 	{
-
 		try
 		{	
 			AutoTangoMonitor sync(this);
