@@ -1,4 +1,4 @@
-static const char *RcsId = "$Id: deviceclass.cpp,v 1.32 2009/01/21 12:49:04 taurel Exp $\n$Name:  $";
+static const char *RcsId = "$Id: deviceclass.cpp,v 1.33 2009/09/18 09:18:06 taurel Exp $\n$Name: Release_7_1_1 $";
 
 //+============================================================================
 //
@@ -33,9 +33,12 @@ static const char *RcsId = "$Id: deviceclass.cpp,v 1.32 2009/01/21 12:49:04 taur
 // You should have received a copy of the GNU Lesser General Public License
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 //
-// $Revision: 1.32 $
+// $Revision: 1.33 $
 //
 // $Log: deviceclass.cpp,v $
+// Revision 1.33  2009/09/18 09:18:06  taurel
+// - End of attribute serialization implementation?
+//
 // Revision 1.32  2009/01/21 12:49:04  taurel
 // - Change CopyRights for 2009
 //
@@ -910,7 +913,7 @@ void DeviceClass::delete_dev(long idx,Tango::Util *tg,PortableServer::POA_ptr r_
 		Device_3Impl *dev_3 = static_cast<Device_3Impl *>(device_list[idx]);
 		dev_3->delete_dev();
 	}
-	
+
 	cout4 << "Leaving DeviceClass delete_dev" << endl;	
 }
 
