@@ -1,4 +1,4 @@
-static const char *RcsId = "$Id: dserver.cpp,v 3.39 2009/03/23 15:21:40 taurel Exp $\n$Name:  $";
+static const char *RcsId = "$Id: dserver.cpp,v 3.44 2009/10/23 14:36:27 taurel Exp $\n$Name: Release_7_1_1 $";
 
 //+=============================================================================
 //
@@ -34,9 +34,36 @@ static const char *RcsId = "$Id: dserver.cpp,v 3.39 2009/03/23 15:21:40 taurel E
 // You should have received a copy of the GNU Lesser General Public License
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 //
-// $Revision: 3.39 $
+// $Revision: 3.44 $
 //
 // $Log: dserver.cpp,v $
+// Revision 3.44  2009/10/23 14:36:27  taurel
+// - Tango 7.1.1
+// - Fix bugs 2880372 and 2881841
+// - Now support event in case of Tango system with multi db server
+// - The polling threads start with polling inactive
+//
+// Revision 3.43  2009/09/18 09:18:06  taurel
+// - End of attribute serialization implementation?
+//
+// Revision 3.42  2009/09/01 07:41:31  taurel
+// - Commit after test suite for Tango 7.1
+//
+// Revision 3.41  2009/08/27 07:23:45  taurel
+// - Commit after another merge with Release_7_0_2-bugfixes branch
+//
+// Revision 3.40  2009/06/17 08:52:08  taurel
+// - Commit after a merge with branch Release_7_0_2-bugfixes
+// Revision 3.39.2.2  2009/06/22 06:58:09  taurel
+// - Fix bug introduced by previous bug fix. It makes the db server crashes.
+//
+// Revision 3.39.2.1  2009/06/12 08:28:51  taurel
+// - Fix bug when using events in multi Tango host environment.
+// The TANGO_HOST is now transferred within the even tin the fixed
+// header event_type field.
+// The DS admin device EventSubscriptionChange command now returns with which Tango lib it is runnig.
+// This allows the client to know if the tango host info will be transmitted within the event
+//
 // Revision 3.39  2009/03/23 15:21:40  taurel
 // - Forgot to remove some commented code when debugging  on Windows Vista
 //
@@ -236,6 +263,14 @@ DServer::DServer(DeviceClass *cl_ptr,const char *n,const char *d,Tango::DevState
 	full_name.append(1,'/');
 	full_name.append(instance_name);
 	
+	fqdn = "tango://";
+	Tango::Util *tg = Tango::Util::instance();
+	Database *db = tg->get_database();
+	if (db != NULL)
+		fqdn = fqdn + db->get_db_host() + ':' + db->get_db_port() + "/dserver/" + full_name;
+	else
+		fqdn = "dserver/" + full_name;
+	
 	last_heartbeat = time(NULL);
 	heartbeat_started = false;
 	
@@ -624,7 +659,6 @@ DServer::~DServer()
 
 void DServer::delete_devices()
 {
-
 	if (class_list.empty() == false)
 	{
 		for (long i = class_list.size() - 1;i >= 0;i--)
@@ -996,7 +1030,6 @@ void DServer::restart(string &d_name)
 // Delete the device (deactivate it and remove it)
 //
 	
-	//Tango::Util *tg = Tango::Util::instance();
 	PortableServer::POA_ptr r_poa = tg->get_poa();
 	if (dev_to_del->get_exported_flag() == true)
 		r_poa->deactivate_object(dev_to_del->get_obj_id().in());
@@ -1550,7 +1583,7 @@ void DServer::get_dev_prop(Tango::Util *tg)
 		}
 
 //
-// If the prop is not defined in db and if the user has defines it in the Util class,
+// If the prop is not defined in db and if the user has defined it in the Util class,
 // takes the user definition
 //
 		
