@@ -31,9 +31,30 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 //
-// $Revision: 3.15 $
+// $Revision: 3.18 $
 //
 // $Log: dserver.h,v $
+// Revision 3.18  2009/10/23 14:36:27  taurel
+// - Tango 7.1.1
+// - Fix bugs 2880372 and 2881841
+// - Now support event in case of Tango system with multi db server
+// - The polling threads start with polling inactive
+//
+// Revision 3.17  2009/08/27 07:23:45  taurel
+// - Commit after another merge with Release_7_0_2-bugfixes branch
+//
+// Revision 3.16  2009/06/17 08:52:08  taurel
+// - Commit after a merge with branch Release_7_0_2-bugfixes
+// Revision 3.15.2.2  2009/06/22 06:58:09  taurel
+// - Fix bug introduced by previous bug fix. It makes the db server crashes.
+//
+// Revision 3.15.2.1  2009/06/12 08:28:51  taurel
+// - Fix bug when using events in multi Tango host environment.
+// The TANGO_HOST is now transferred within the even tin the fixed
+// header event_type field.
+// The DS admin device EventSubscriptionChange command now returns with which Tango lib it is runnig.
+// This allows the client to know if the tango host info will be transmitted within the event
+//
 // Revision 3.15  2009/02/03 15:15:08  jensmeyer
 // Added a QuerySubDevice command to read the list of opened sub device
 // connections.
@@ -272,6 +293,7 @@ public :
 	void rem_obj_polling(const Tango::DevVarStringArray *,bool with_db_upd = true);
 	void stop_polling();
 	void start_polling();
+	void start_polling(PollingThreadInfo *);
 	void add_event_heartbeat();
 	void rem_event_heartbeat();
 	
@@ -296,6 +318,7 @@ public :
 	string &get_personal_name() {return instance_name;}
 	string &get_instance_name() {return instance_name;}
 	string &get_full_name() {return full_name;}
+	string &get_fqdn() {return fqdn;}
 	bool get_heartbeat_started() {return heartbeat_started;}
 	void set_heartbeat_started(bool val) {heartbeat_started = val;}
 		
@@ -312,6 +335,7 @@ protected :
 	string			process_name;
 	string			instance_name;
 	string			full_name;
+	string 			fqdn;
 	
 	vector<DeviceClass *>	class_list;
 	
