@@ -1,4 +1,4 @@
-static const char *RcsId = "$Id: dserverpoll.cpp,v 3.30 2009/04/01 06:31:25 taurel Exp $\n$Name:  $";
+static const char *RcsId = "$Id: dserverpoll.cpp,v 3.31 2009/10/23 14:36:27 taurel Exp $\n$Name: Release_7_1_1 $";
 
 //+=============================================================================
 //
@@ -34,9 +34,15 @@ static const char *RcsId = "$Id: dserverpoll.cpp,v 3.30 2009/04/01 06:31:25 taur
 // You should have received a copy of the GNU Lesser General Public License
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 //
-// $Revision: 3.30 $
+// $Revision: 3.31 $
 //
 // $Log: dserverpoll.cpp,v $
+// Revision 3.31  2009/10/23 14:36:27  taurel
+// - Tango 7.1.1
+// - Fix bugs 2880372 and 2881841
+// - Now support event in case of Tango system with multi db server
+// - The polling threads start with polling inactive
+//
 // Revision 3.30  2009/04/01 06:31:25  taurel
 // - Only some changes in printed messages when using -v5
 //
@@ -1024,7 +1030,7 @@ void DServer::add_obj_polling(const Tango::DevVarLongStringArray *argin,
 					if (thread_created == -1)
 					{
 						shared_cmd.cmd_pending = true;
-						shared_cmd.cmd_code = POLL_ADD_OBJ;
+						shared_cmd.cmd_code = POLL_EXIT;
 						
 						mon.signal();
 					}
@@ -1127,7 +1133,16 @@ void DServer::add_obj_polling(const Tango::DevVarLongStringArray *argin,
 		send_data.push_back(db_info);	
 		dev->get_db_device()->put_property(send_data);
 	}
-		
+
+//
+// If a polling thread has just been created, ask it to poll
+//
+
+	if (thread_created == -1)
+	{
+		start_polling(th_info);
+	}
+			
 //
 // Also update the polling threads pool conf if one thread has been created by this call
 //
@@ -1939,6 +1954,37 @@ void DServer::start_polling()
 	str = "The device is ON\nThe polling is ON";
 }
 
+void DServer::start_polling(PollingThreadInfo *th_info)
+{
+	TangoMonitor &mon = th_info->poll_mon;
+	PollThCmd &shared_cmd = th_info->shared_data;
+	int interupted;
+	
+	{
+		omni_mutex_lock sync(mon);
+		if (shared_cmd.cmd_pending == true)
+		{
+			mon.wait();
+		}
+		shared_cmd.cmd_pending = true;
+		shared_cmd.cmd_code = POLL_START;
+
+		mon.signal();
+
+		while (shared_cmd.cmd_pending == true)
+		{
+			interupted = mon.wait(DEFAULT_TIMEOUT);
+
+			if ((shared_cmd.cmd_pending == true) && (interupted == false))
+			{
+				cout4 << "TIME OUT" << endl;
+				Except::throw_exception((const char *)"API_CommandTimedOut",
+						    (const char *)"Polling thread blocked while trying to start thread polling!!!",
+						    (const char *)"DServer::start_polling");
+			}
+		}
+	}
+}
 
 //+----------------------------------------------------------------------------
 //
