@@ -28,9 +28,18 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 //
-// $Revision: 3.5 $
+// $Revision: 3.8 $
 //
 // $Log: encoded_attribute.cpp,v $
+// Revision 3.8  2009/09/18 09:18:06  taurel
+// - End of attribute serialization implementation?
+//
+// Revision 3.7  2009/09/08 14:22:15  taurel
+// - Manage internal buffer(s) as a cicular buffer pool
+//
+// Revision 3.6  2009/09/02 08:00:54  taurel
+// - Fix Solaris CC warning
+//
 // Revision 3.5  2009/04/20 14:55:58  jlpons
 // Added GPL header, changed memory allocation to C++ fashion.
 //
@@ -59,53 +68,88 @@ using namespace Tango;
 
 // ----------------------------------------------------------------------------
 
-EncodedAttribute::EncodedAttribute() {
+EncodedAttribute::EncodedAttribute():manage_exclusion(false),ext(NULL) {
 
-  buffer = NULL;
+  buffer_array = (unsigned char **)calloc(1,sizeof(unsigned char *));
+  buffer_array[0] = NULL;
+  buffSize_array = (int *)calloc(1,sizeof(int));
+  buffSize_array[0] = 0;
   format = NULL;
-  buffSize = 0;
+  mutex_array = NULL;
+  index = 0;
+  buf_elt_nb = 1;
+}
 
+EncodedAttribute::EncodedAttribute(int si,bool excl):manage_exclusion(excl),ext(NULL) {
+
+  buffer_array = (unsigned char **)calloc(si,sizeof(unsigned char *));
+  buffSize_array = (int *)calloc(si,sizeof(int));
+  for (int i = 0;i < si;i++)
+  {
+     buffer_array[i] = NULL;
+	 buffSize_array[i] = 0;
+  }
+  format = NULL;
+  index = 0;
+  buf_elt_nb = si;
+  
+  if (manage_exclusion == true)
+  	mutex_array = new omni_mutex[si];
 }
 
 // ----------------------------------------------------------------------------
 
 EncodedAttribute::~EncodedAttribute() {
 
-  SAFE_FREE(buffer);
+  for (int i = 0;i < buf_elt_nb;i++)
+  	SAFE_FREE(buffer_array[i]);
+  SAFE_FREE(buffer_array);
+  SAFE_FREE(buffSize_array);
 
+  if (mutex_array != NULL)
+    delete [] mutex_array;
 }
 
 // ----------------------------------------------------------------------------
 
 void EncodedAttribute::encode_jpeg_gray8(unsigned char *gray8,int width,int height,double quality) {
 
-  SAFE_FREE(buffer);
-  buffSize = 0;
+  if (manage_exclusion == true)
+  	mutex_array[index].lock();
+	
+  SAFE_FREE(buffer_array[index]);
+  buffSize_array[index] = 0;
   format = (char *)"JPEG_GRAY8";
-  jpeg_encode_gray8(width,height,gray8,quality,&buffSize,&buffer);
-
+  jpeg_encode_gray8(width,height,gray8,quality,&(buffSize_array[index]),&(buffer_array[index]));
+  INC_INDEX()
 }
 
 // ----------------------------------------------------------------------------
 
 void EncodedAttribute::encode_jpeg_rgb32(unsigned char *rgb32,int width,int height,double quality) {
 
-  SAFE_FREE(buffer);
-  buffSize = 0;
+  if (manage_exclusion == true)
+  	mutex_array[index].lock();
+	
+  SAFE_FREE(buffer_array[index]);
+  buffSize_array[index] = 0;
   format = (char *)"JPEG_RGB";
-  jpeg_encode_rgb32(width,height,rgb32,quality,&buffSize,&buffer);
-
+  jpeg_encode_rgb32(width,height,rgb32,quality,&(buffSize_array[index]),&(buffer_array[index]));
+  INC_INDEX()
 }
 
 // ----------------------------------------------------------------------------
 
 void EncodedAttribute::encode_jpeg_rgb24(unsigned char *rgb24,int width,int height,double quality) {
 
-  SAFE_FREE(buffer);
-  buffSize = 0;
+  if (manage_exclusion == true)
+  	mutex_array[index].lock();
+	
+  SAFE_FREE(buffer_array[index]);
+  buffSize_array[index] = 0;
   format = (char *)"JPEG_RGB";
-  jpeg_encode_rgb24(width,height,rgb24,quality,&buffSize,&buffer);
-
+  jpeg_encode_rgb24(width,height,rgb24,quality,&(buffSize_array[index]),&(buffer_array[index]));
+  INC_INDEX()
 }
 
 // ----------------------------------------------------------------------------
@@ -113,23 +157,28 @@ void EncodedAttribute::encode_jpeg_rgb24(unsigned char *rgb24,int width,int heig
 void EncodedAttribute::encode_gray8(unsigned char *gray8,int width,int height) {
 
   int newSize = width*height + 4;
-  if( newSize!=buffSize ) {
-    SAFE_FREE(buffer);
-    buffer = (unsigned char *)malloc(newSize);
-    buffSize = newSize;
+  
+  if (manage_exclusion == true)
+  	mutex_array[index].lock();
+	
+  if( newSize!=buffSize_array[index] ) {
+    SAFE_FREE(buffer_array[index]);
+    buffer_array[index] = (unsigned char *)malloc(newSize);
+    buffSize_array[index] = newSize;
   }
 
   format = (char *)"GRAY8";
   
   // Store image dimension (big endian)
-  buffer[0] = (unsigned char)( (width>>8) & 0xFF );
-  buffer[1] = (unsigned char)( width & 0xFF );
-  buffer[2] = (unsigned char)( (height>>8) & 0xFF );
-  buffer[3] = (unsigned char)( height & 0xFF );
+  unsigned char *tmp_ptr = buffer_array[index];
+  tmp_ptr[0] = (unsigned char)( (width>>8) & 0xFF );
+  tmp_ptr[1] = (unsigned char)( width & 0xFF );
+  tmp_ptr[2] = (unsigned char)( (height>>8) & 0xFF );
+  tmp_ptr[3] = (unsigned char)( height & 0xFF );
 
   // Copy image
-  memcpy(buffer+4,gray8,newSize-4);
-
+  memcpy(tmp_ptr+4,gray8,newSize-4);
+  INC_INDEX()
 }
 
 // ----------------------------------------------------------------------------
@@ -137,19 +186,24 @@ void EncodedAttribute::encode_gray8(unsigned char *gray8,int width,int height) {
 void EncodedAttribute::encode_gray16(unsigned short *gray16,int width,int height) {
 
   int newSize = width*height*2 + 4;
-  if( newSize!=buffSize ) {
-    SAFE_FREE(buffer);
-    buffer = (unsigned char *)malloc(newSize);
-    buffSize = newSize;
+  
+  if (manage_exclusion == true)
+  	mutex_array[index].lock();
+	
+  if( newSize!=buffSize_array[index] ) {
+    SAFE_FREE(buffer_array[index]);
+    buffer_array[index] = (unsigned char *)malloc(newSize);
+    buffSize_array[index] = newSize;
   }
 
   format = (char *)"GRAY16";
   
   // Store image dimension (big endian)
-  buffer[0] = (unsigned char)( (width>>8) & 0xFF );
-  buffer[1] = (unsigned char)( width & 0xFF );
-  buffer[2] = (unsigned char)( (height>>8) & 0xFF );
-  buffer[3] = (unsigned char)( height & 0xFF );
+  unsigned char *tmp_ptr = buffer_array[index];
+  tmp_ptr[0] = (unsigned char)( (width>>8) & 0xFF );
+  tmp_ptr[1] = (unsigned char)( width & 0xFF );
+  tmp_ptr[2] = (unsigned char)( (height>>8) & 0xFF );
+  tmp_ptr[3] = (unsigned char)( height & 0xFF );
 
   // Store image (big endian)
   int srcIdx = 0;
@@ -157,11 +211,11 @@ void EncodedAttribute::encode_gray16(unsigned short *gray16,int width,int height
   for(int j=0;j<height;j++) {
     for(int i=0;i<width;i++) {
       unsigned short s = gray16[srcIdx++];
-      buffer[dstIdx++] = (unsigned char)(s >> 8);
-      buffer[dstIdx++] = (unsigned char)(s & 0xFF);
+      tmp_ptr[dstIdx++] = (unsigned char)(s >> 8);
+      tmp_ptr[dstIdx++] = (unsigned char)(s & 0xFF);
     }
   }
-
+  INC_INDEX()
 }
 
 // ----------------------------------------------------------------------------
@@ -169,22 +223,27 @@ void EncodedAttribute::encode_gray16(unsigned short *gray16,int width,int height
 void EncodedAttribute::encode_rgb24(unsigned char *rgb24,int width,int height) {
 
   int newSize = width*height*3 + 4;
-  if( newSize!=buffSize ) {
-    SAFE_FREE(buffer);
-    buffer = (unsigned char *)malloc(newSize);
-    buffSize = newSize;
+  
+  if (manage_exclusion == true)
+  	mutex_array[index].lock();
+	
+  if( newSize!=buffSize_array[index] ) {
+    SAFE_FREE(buffer_array[index]);
+    buffer_array[index] = (unsigned char *)malloc(newSize);
+    buffSize_array[index] = newSize;
   }
 
   format = (char *)"RGB24";
   
   // Store image dimension (big endian)
-  buffer[0] = (unsigned char)( (width>>8) & 0xFF );
-  buffer[1] = (unsigned char)( width & 0xFF );
-  buffer[2] = (unsigned char)( (height>>8) & 0xFF );
-  buffer[3] = (unsigned char)( height & 0xFF );
+  unsigned char *tmp_ptr = buffer_array[index];
+  tmp_ptr[0] = (unsigned char)( (width>>8) & 0xFF );
+  tmp_ptr[1] = (unsigned char)( width & 0xFF );
+  tmp_ptr[2] = (unsigned char)( (height>>8) & 0xFF );
+  tmp_ptr[3] = (unsigned char)( height & 0xFF );
 
   // Copy image
-  memcpy(buffer+4,rgb24,newSize-4);
+  memcpy(tmp_ptr+4,rgb24,newSize-4);
 
 }
 
@@ -193,11 +252,11 @@ void EncodedAttribute::encode_rgb24(unsigned char *rgb24,int width,int height) {
 void EncodedAttribute::decode_rgb32(DeviceAttribute *attr,int *width,int *height,unsigned char **rgb32) {
 
   vector<unsigned char> rawBuff;
-  string format;
-  attr->extract(format,rawBuff);
+  string local_format;
+  attr->extract(local_format,rawBuff);
 
-  int isRGB  = (strcmp(format.c_str() ,"RGB24" ) == 0);
-  int isJPEG = (strcmp(format.c_str() ,"JPEG_RGB" ) == 0);
+  int isRGB  = (strcmp(local_format.c_str() ,"RGB24" ) == 0);
+  int isJPEG = (strcmp(local_format.c_str() ,"JPEG_RGB" ) == 0);
 
   if( !isRGB && !isJPEG ) {
 
@@ -274,11 +333,11 @@ void EncodedAttribute::decode_rgb32(DeviceAttribute *attr,int *width,int *height
 void EncodedAttribute::decode_gray8(DeviceAttribute *attr,int *width,int *height,unsigned char **gray8) {
 
   vector<unsigned char> rawBuff;
-  string format;
-  attr->extract(format,rawBuff);
+  string local_format;
+  attr->extract(local_format,rawBuff);
 
-  int isGrey  = (strcmp(format.c_str() ,"GRAY8" ) == 0);
-  int isJPEG = (strcmp(format.c_str() ,"JPEG_GRAY8" ) == 0);
+  int isGrey  = (strcmp(local_format.c_str() ,"GRAY8" ) == 0);
+  int isJPEG = (strcmp(local_format.c_str() ,"JPEG_GRAY8" ) == 0);
 
   if( !isGrey && !isJPEG ) {
 
@@ -344,10 +403,10 @@ void EncodedAttribute::decode_gray8(DeviceAttribute *attr,int *width,int *height
 void EncodedAttribute::decode_gray16(DeviceAttribute *attr,int *width,int *height,unsigned short **gray16) {
 
   vector<unsigned char> rawBuff;
-  string format;
-  attr->extract(format,rawBuff);
+  string local_format;
+  attr->extract(local_format,rawBuff);
 
-  int isGrey  = (strcmp(format.c_str() ,"GRAY16" ) == 0);
+  int isGrey  = (strcmp(local_format.c_str() ,"GRAY16" ) == 0);
 
   if( !isGrey ) {
 
