@@ -28,9 +28,18 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 //
-// $Revision: 3.4 $
+// $Revision: 3.7 $
 //
 // $Log: encoded_attribute.h,v $
+// Revision 3.7  2009/09/18 09:18:06  taurel
+// - End of attribute serialization implementation?
+//
+// Revision 3.6  2009/09/10 07:00:30  taurel
+// - Add some documentation fo rthe new ctor
+//
+// Revision 3.5  2009/09/08 14:22:15  taurel
+// - Manage internal buffer(s) as a cicular buffer pool
+//
 // Revision 3.4  2009/04/06 06:54:34  taurel
 // - Fix some typos
 // - Commit in Unix format
@@ -55,6 +64,9 @@
 namespace Tango
 {
 
+class EncodedAttributeExt
+{
+};
 
 /**
  * This class provides method to deal with Tango::DevEncoded attribute format.
@@ -73,6 +85,20 @@ public:
  *
  */
 	EncodedAttribute();
+	
+/**
+ * Create a new EncodedAttribute object with a user defined buffer pool.
+ *
+ * This constructor allows the user to define the size of the buffer pool used to
+ * store the encoded images. This buffer pool is managed as a circular pool.
+ * A different buffer is used each time an image is encoded. The last used buffer is then
+ * passed to the attribute with the attribute::set_value() method
+ *
+ * @param buf_pool_size    Buffer pool size
+ * @param serialization	   Set to true if the instance manage the data buffer serialization
+ *
+ */
+	EncodedAttribute(int buf_pool_size,bool serialization = false);
 //@}
 
 /**@name Destructor
@@ -192,18 +218,46 @@ public:
 
 //@}
 
- DevUChar  *get_data()   {return (DevUChar *)buffer;}
+ DevUChar  *get_data()
+ {if (index==0)
+    return (DevUChar *)buffer_array[buf_elt_nb-1];
+  else
+    return (DevUChar *)buffer_array[index-1];}
+	
+ long       get_size()
+ {if (index==0)
+    return (long)buffSize_array[buf_elt_nb-1];
+  else
+    return (long)buffSize_array[index-1];}
+	
  DevString *get_format() {return &format;}
- long       get_size()   {return (long)buffSize;}
-
+ bool get_exclusion() {return manage_exclusion;}
+ omni_mutex *get_mutex()
+ {if (index==0)
+ 	return &(mutex_array[buf_elt_nb-1]);
+  else
+    return &(mutex_array[index-1]);}
+ 
 private:
 
-  unsigned char *buffer;
-  int            buffSize;
-  char          *format;
+  unsigned char 		**buffer_array;
+  int           		*buffSize_array;
+  omni_mutex			*mutex_array;
+  char          		*format;
+  
+  int 					index;
+  int					buf_elt_nb;
+  bool					manage_exclusion;
+  
+  EncodedAttributeExt	*ext;
 
 };
 
+#define INC_INDEX() \
+  index++; \
+  if (index == buf_elt_nb) \
+  	index = 0;
+	
 } // End of Tango namespace
 
 #endif // _ENCODED_ATT_H
