@@ -33,7 +33,7 @@
 ///
 /// 		original : 7 April 2003
 ///
-/// 		$Revision: 1.22 $
+/// 		$Revision: 1.25 $
 ///
 /// 		copyright : European Synchrotron Radiation Facility
 ///                         BP 220, Grenoble 38043
@@ -366,8 +366,8 @@ typedef struct event_callback
 	CallBack 					*callback;
 	EventQueue                  *ev_queue;
 	CosNotifyFilter::FilterID 	filter_id;
-	bool 						 filter_ok;
-	int 						 id;
+	bool 						filter_ok;
+	int 						id;
 	TangoMonitor				*callback_monitor;
 } EventCallBackStruct;
 
@@ -470,7 +470,8 @@ private :
 	ReadersWritersLock map_modification_lock;
 
 	vector<EventNotConnected> event_not_connected;
-	int subscribe_event_id; // unique event id		
+	int subscribe_event_id; // unique event id
+	vector<string> env_var_fqdn_prefix;		
 };
 
 typedef std::map<std::string,EventChannelStruct>::iterator EvChanIte;
@@ -502,6 +503,25 @@ private :
 
 };
 
+/********************************************************************************
+ * 																				*
+ * 						DelayedEventUnsubThread class							*
+ * 																				*
+ *******************************************************************************/
+ 
+class DelayedEventUnsubThread: public omni_thread
+{
+public:
+	DelayedEventUnsubThread(EventConsumer *ec,int id,TangoMonitor *m):omni_thread(),event_id(id),ev_cons(ec),the_mon(m) {}
+	
+	void run(void *);
+	
+private:
+	int 			event_id;
+	EventConsumer 	*ev_cons;
+	TangoMonitor	*the_mon;
+};
+
 } // End of namespace
 
 
