@@ -1,4 +1,4 @@
-static const char *RcsId = "$Id: eventcmds.cpp,v 1.24 2009/04/27 11:16:34 taurel Exp $";
+static const char *RcsId = "$Id: eventcmds.cpp,v 1.27 2009/10/27 08:25:03 taurel Exp $";
 //+=============================================================================
 //
 // file :        eventcmds.cpp
@@ -30,9 +30,25 @@ static const char *RcsId = "$Id: eventcmds.cpp,v 1.24 2009/04/27 11:16:34 taurel
 // You should have received a copy of the GNU Lesser General Public License
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 //
-// $Revision: 1.24 $
+// $Revision: 1.27 $
 //
 // $Log: eventcmds.cpp,v $
+// Revision 1.27  2009/10/27 08:25:03  taurel
+// - No real changes. Only some code beautifulling
+//
+// Revision 1.26  2009/08/27 07:23:45  taurel
+// - Commit after another merge with Release_7_0_2-bugfixes branch
+//
+// Revision 1.25  2009/06/17 08:52:08  taurel
+// - Commit after a merge with branch Release_7_0_2-bugfixes
+//
+// Revision 1.24.2.1  2009/06/12 08:28:51  taurel
+// - Fix bug when using events in multi Tango host environment.
+// The TANGO_HOST is now transferred within the even tin the fixed
+// header event_type field.
+// The DS admin device EventSubscriptionChange command now returns with which Tango lib it is runnig.
+// This allows the client to know if the tango host info will be transmitted within the event
+//
 // Revision 1.24  2009/04/27 11:16:34  taurel
 // - Attribute with DevState data type do not need a relative or absolute
 // change property
@@ -269,7 +285,6 @@ bool EventSubscriptionChangeCmd::is_allowed(Tango::DeviceImpl *device, const COR
 //-----------------------------------------------------------------------------
 CORBA::Any *EventSubscriptionChangeCmd::execute(Tango::DeviceImpl *device,const CORBA::Any &in_any)
 {
-
 	cout4 << "EventSubscriptionChangeCmd::execute(): arrived" << endl;
 
 	const Tango::DevVarStringArray	*argin;
@@ -522,9 +537,9 @@ CORBA::Any *EventSubscriptionChangeCmd::execute(Tango::DeviceImpl *device,const
 // to the attribute
 //
 			
+		Tango::Util *tg = Tango::Util::instance();
 		try
 		{
-			Tango::Util *tg = Tango::Util::instance();
 			DServer *adm_dev = tg->get_dserver_device();
 
 			if (adm_dev->get_heartbeat_started() == false)
@@ -538,8 +553,11 @@ CORBA::Any *EventSubscriptionChangeCmd::execute(Tango::DeviceImpl *device,const
 		}
 	}
 
-	CORBA::Any *ret = return_empty_any("EventSubscriptionChange");
-	return ret;
+	Tango::DevLong ret = (Tango::DevLong)tg->get_tango_lib_release();
+	CORBA::Any *out_any = new CORBA::Any();	
+	(*out_any) <<= ret;	
+	return out_any;
+	
 }
 
 
