@@ -1,4 +1,4 @@
-static const char *RcsId = "$Id: eventkeepalive.cpp,v 1.6 2009/03/13 09:33:29 taurel Exp $";
+static const char *RcsId = "$Id: eventkeepalive.cpp,v 1.7 2009/09/22 07:55:05 jensmeyer Exp $";
 
 ////////////////////////////////////////////////////////////////////////////////
 ///
@@ -35,9 +35,13 @@ static const char *RcsId = "$Id: eventkeepalive.cpp,v 1.6 2009/03/13 09:33:29 ta
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 //
 ///
-///		$Revision: 1.6 $
+///		$Revision: 1.7 $
 ///
 ///		$Log: eventkeepalive.cpp,v $
+///		Revision 1.7  2009/09/22 07:55:05  jensmeyer
+///		Changed readers to writers lock in EventConsumerKeepAliveThread::run_undetached() for connection
+///		test of not yet connected events.
+///		
 ///		Revision 1.6  2009/03/13 09:33:29  taurel
 ///		- Small changes to fix Windows VC8 warnings in Warning level 3
 ///		
@@ -358,7 +362,7 @@ void *EventConsumerKeepAliveThread::run_undetached(void *arg)
 //
  
 		// lock the maps only for reading
-		event_consumer->map_modification_lock.readerIn();
+		event_consumer->map_modification_lock.writerIn();
 			
 		now = time(NULL);
 			
@@ -366,42 +370,35 @@ void *EventConsumerKeepAliveThread::run_undetached(void *arg)
 // check the list of not yet connected events and try to subscribe
 //
 			
-		if ( event_consumer->event_not_connected.size() > 0 )
-			{
+		if ( !event_consumer->event_not_connected.empty() )
+		{
 			std::vector<EventNotConnected>::iterator vpos;
 			for (vpos = event_consumer->event_not_connected.begin(); 
 				 vpos != event_consumer->event_not_connected.end();
-				 vpos++ )
-				{
-				
+				 /*vpos++*/)
+			{
+				bool inc_vpos = true;
 				// check wether it is necessary to try to subscribe again!
 				if ( (now - vpos->last_heartbeat) >= (EVENT_HEARTBEAT_PERIOD) )
-					{
+				{
 					try
-						{
+					{
 						// try to subscribe
-						
-						event_consumer->map_modification_lock.readerOut();
+
 						event_consumer->connect_event (vpos->device,vpos->attribute,vpos->event_type, 
 																					vpos->callback,
 																					vpos->ev_queue, 
 																					vpos->filters,
 																					vpos->event_name,
 																					vpos->event_id);	
-						event_consumer->map_modification_lock.readerIn();
 							
 						// delete element from vector when subscribe worked
 						vpos = event_consumer->event_not_connected.erase(vpos);
-						if ( vpos == event_consumer->event_not_connected.end() )
-							{
-							break;
-							}
-						}
+						inc_vpos = false;
+					}
 		
 					catch (Tango::DevFailed &e) 
-						{
-						event_consumer->map_modification_lock.readerIn();
-						
+					{
 						// subscribe has not worked, try again in the next hearbeat period
 						vpos->last_heartbeat = now;
 						
@@ -423,7 +420,7 @@ void *EventConsumerKeepAliveThread::run_undetached(void *arg)
 	    					(vpos->event_name == "quality") || 
 	    					(vpos->event_name == "archive") ||
 	    					(vpos->event_name == "user_event"))
-							{						
+						{
 							//DeviceAttribute da;
 							DeviceAttribute *da = NULL;
 							EventData *event_data = new EventData(vpos->device,
@@ -434,34 +431,34 @@ void *EventConsumerKeepAliveThread::run_undetached(void *arg)
 							
 							// if a callback method was specified, call it!
 							if (vpos->callback != NULL )
-								{										
+							{										
 								try
-									{
+								{
 									vpos->callback->push_event(event_data);
-									}
+								}
 								catch (...)
-									{
+								{
 									cerr << "EventConsumerKeepAliveThread::run_undetached() exception in callback method of " << domain_name << endl;
-									}
+								}
 						
 								//event_data->attr_value = NULL;							
 								delete event_data;
-								}
-								
-							// no calback method, the event has to be instered
+							}
+
+							// no callback method, the event has to be instered
 							// into the event queue
 							else
-								{
+							{
 								vpos->ev_queue->insert_event(event_data);
-								}							
-							}
+							}							
+						}
 						
 //
 // For attribute configuration event
 //
 							
 						else if (vpos->event_name == CONF_TYPE_EVENT)
-							{
+						{
 							//AttributeInfoEx aie;
 							AttributeInfoEx *aie = NULL;
 							AttrConfEventData *event_data = new AttrConfEventData(vpos->device,
@@ -472,27 +469,27 @@ void *EventConsumerKeepAliveThread::run_undetached(void *arg)
 							
 							// if a callback method was specified, call it!
 							if (vpos->callback != NULL )
-								{
+							{
 								try
-									{
+								{
 									vpos->callback->push_event(event_data);
-									}
+								}
 								catch (...)
-									{
+								{
 									cerr << "EventConsumerKeepAliveThread::run_undetached() exception in callback method of " << domain_name << endl;
-									}
+								}
 							
 								//event_data->attr_conf = NULL;
 								delete event_data;
-								}
+							}
 								
 							// no calback method, the event has to be inserted
 							// into the event queue
 							else
-								{
+							{
 								vpos->ev_queue->insert_event(event_data);
-								}					
-							}
+							}					
+						}
 						else if (vpos->event_name == DATA_READY_TYPE_EVENT)
 						{
 							DataReadyEventData *event_data = new DataReadyEventData(vpos->device,NULL,vpos->event_name,err);
@@ -516,21 +513,22 @@ void *EventConsumerKeepAliveThread::run_undetached(void *arg)
 							else
 								vpos->ev_queue->insert_event(event_data);	
 						}
-						}
+					}
 					
 					catch (...)
-						{
-						event_consumer->map_modification_lock.readerIn();
-						
+					{						
 						// subscribe has not worked, try again in the next hearbeat period
 						vpos->last_heartbeat = now;
 						
 						cout << "During the event subscription an exception was send which is not a Tango::DevFailed exception!" << endl;	
-						}						
-					}
+					}						
 				}
+				if (inc_vpos) 
+					++vpos;
 			}
-		event_consumer->map_modification_lock.readerOut();
+		}
+
+		event_consumer->map_modification_lock.writerOut();
 		
 //		
 // Check for all other event reconnections
