@@ -1,4 +1,4 @@
-static const char *RcsId = "$Id: eventsupplier.cpp,v 1.32 2009/03/13 09:33:29 taurel Exp $";
+static const char *RcsId = "$Id: eventsupplier.cpp,v 1.35 2009/10/27 08:25:02 taurel Exp $";
 
 ////////////////////////////////////////////////////////////////////////////////
 ///
@@ -34,9 +34,27 @@ static const char *RcsId = "$Id: eventsupplier.cpp,v 1.32 2009/03/13 09:33:29 ta
 // You should have received a copy of the GNU Lesser General Public License
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 ///
-///		$Revision: 1.32 $
+///		$Revision: 1.35 $
 ///
 ///		$Log: eventsupplier.cpp,v $
+///		Revision 1.35  2009/10/27 08:25:02  taurel
+///		- No real changes. Only some code beautifulling
+///		
+///		Revision 1.34  2009/08/27 07:23:45  taurel
+///		- Commit after another merge with Release_7_0_2-bugfixes branch
+///		
+///		Revision 1.33  2009/06/17 08:52:08  taurel
+///		- Commit after a merge with branch Release_7_0_2-bugfixes
+///		Revision 1.32.2.2  2009/06/26 06:46:06  taurel
+///		- No change, simply commit to test the "commit" mailing list
+///		
+///		Revision 1.32.2.1  2009/06/12 08:28:51  taurel
+///		- Fix bug when using events in multi Tango host environment.
+///		The TANGO_HOST is now transferred within the even tin the fixed
+///		header event_type field.
+///		The DS admin device EventSubscriptionChange command now returns with which Tango lib it is runnig.
+///		This allows the client to know if the tango host info will be transmitted within the event
+///		
 ///		Revision 1.32  2009/03/13 09:33:29  taurel
 ///		- Small changes to fix Windows VC8 warnings in Warning level 3
 ///		
@@ -266,6 +284,9 @@ EventSupplier *EventSupplier::create(CORBA::ORB_var _orb,
 
 	EventSupplier *_event_supplier =
 		new EventSupplier(_orb,ns.SupAdm,ns.pID,ns.ProCon,ns.StrProPush,ns.EveChaFac,ns.EveCha,ns.ec_ior);
+		
+	_event_supplier->fqdn_prefix = "tango://";
+	_event_supplier->fqdn_prefix = _event_supplier->fqdn_prefix + db->get_db_host() + ':' + db->get_db_port() + '/' ;
 	
 	return _event_supplier;
 }
@@ -772,7 +793,7 @@ void EventSupplier::push_heartbeat_event()
 		domain_name = "dserver/" + adm_dev->get_full_name();
 		
 		struct_event.header.fixed_header.event_type.domain_name = CORBA::string_dup(domain_name.c_str());
-  		struct_event.header.fixed_header.event_type.type_name   = CORBA::string_dup("Tango::Heartbeat");
+ 		struct_event.header.fixed_header.event_type.type_name   = CORBA::string_dup(fqdn_prefix.c_str());
   		struct_event.header.variable_header.length( 0 );
 		
 		cout3 << "EventSupplier::push_heartbeat_event(): detected heartbeat event for " << domain_name << endl;
@@ -2444,7 +2465,6 @@ void EventSupplier::detect_and_push_periodic_event_3(DeviceImpl *device_impl,
 					    string &attr_name,
 					    DevFailed *except)
 {
-					    
 	string event, domain_name;
 	double now_ms, ms_since_last_periodic;
 #ifdef _TG_WINDOWS_
@@ -2505,7 +2525,9 @@ void EventSupplier::detect_and_push_periodic_event_3(DeviceImpl *device_impl,
 		eve_period = (int)eve_round;
 	}
 
+//
 // calculate the time 
+//
 	ms_since_last_periodic = now_ms - attr.ext->last_periodic;
 	cout3 << "EventSupplier::detect_and_push_is_periodic_event(): delta since last periodic " << ms_since_last_periodic << " event_period " << eve_period << " for " << device_impl->get_name()+"/"+attr_name << endl;
 		
@@ -2596,7 +2618,7 @@ void EventSupplier::push_event_3(DeviceImpl *device_impl,
 	domain_name = device_impl->get_name_lower() + "/" + loc_attr_name;
 
 	struct_event.header.fixed_header.event_type.domain_name = CORBA::string_dup(domain_name.c_str());
-	struct_event.header.fixed_header.event_type.type_name = CORBA::string_dup("Tango::EventValue");
+	struct_event.header.fixed_header.event_type.type_name = CORBA::string_dup(fqdn_prefix.c_str());
 
 	struct_event.header.variable_header.length( 0 );
 
