@@ -32,7 +32,7 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 ///
-/// 		$Revision: 1.29 $
+/// 		$Revision: 1.31 $
 ///
 /// 		copyright : European Synchrotron Radiation Facility
 ///                         BP 220, Grenoble 38043
@@ -123,6 +123,7 @@ private :
 	int heartbeat_period;
 	int subscription_timeout;
 	string event_channel_ior;
+	string fqdn_prefix;
 
 	void get_attribute_value(AttributeValue attr_value, LastAttrValue &curr_attr_value);
 	void reconnect_notifd();
@@ -1454,7 +1455,7 @@ public :
 		domain_name = device_impl->get_name_lower() + "/" + loc_attr_name;
 
 		struct_event.header.fixed_header.event_type.domain_name = CORBA::string_dup(domain_name.c_str());
-  		struct_event.header.fixed_header.event_type.type_name = CORBA::string_dup("Tango::EventValue");
+  		struct_event.header.fixed_header.event_type.type_name = CORBA::string_dup(fqdn_prefix.c_str());
 
 		struct_event.header.variable_header.length( 0 );
 
