@@ -1,4 +1,4 @@
-static const char *RcsId = "$Id: multiattribute.cpp,v 3.20 2009/01/21 12:47:15 taurel Exp $\n$Name:  $";
+static const char *RcsId = "$Id: multiattribute.cpp,v 3.23 2009/10/27 16:33:44 taurel Exp $\n$Name: Release_7_1_1 $";
 
 //+============================================================================
 //
@@ -34,9 +34,22 @@ static const char *RcsId = "$Id: multiattribute.cpp,v 3.20 2009/01/21 12:47:15 t
 // You should have received a copy of the GNU Lesser General Public License
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 //
-// $Revision: 3.20 $
+// $Revision: 3.23 $
 //
 // $Log: multiattribute.cpp,v $
+// Revision 3.23  2009/10/27 16:33:44  taurel
+// - Fix a bug in attribute mutex management in case the attribute
+// is_allowed() method returns false
+//
+// Revision 3.22  2009/10/23 14:36:27  taurel
+// - Tango 7.1.1
+// - Fix bugs 2880372 and 2881841
+// - Now support event in case of Tango system with multi db server
+// - The polling threads start with polling inactive
+//
+// Revision 3.21  2009/09/18 09:18:06  taurel
+// - End of attribute serialization implementation?
+//
 // Revision 3.20  2009/01/21 12:47:15  taurel
 // - Change CopyRights for 2009
 //
@@ -516,7 +529,7 @@ MultiAttribute::~MultiAttribute()
 {
 	for(unsigned long i = 0;i < attr_list.size();i++)
 		delete attr_list[i];
-		
+
 	delete ext;
 }
 
