@@ -1,4 +1,4 @@
-static const char *RcsId = "$Id: pollobj.cpp,v 3.13 2009/02/27 13:26:46 taurel Exp $\n$Name:  $";
+static const char *RcsId = "$Id: pollobj.cpp,v 3.14 2009/09/18 09:18:06 taurel Exp $\n$Name: Release_7_1_1 $";
 
 //+============================================================================
 //
@@ -33,9 +33,12 @@ static const char *RcsId = "$Id: pollobj.cpp,v 3.13 2009/02/27 13:26:46 taurel E
 // You should have received a copy of the GNU Lesser General Public License
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 //
-// $Revision: 3.13 $
+// $Revision: 3.14 $
 //
 // $Log: pollobj.cpp,v $
+// Revision 3.14  2009/09/18 09:18:06  taurel
+// - End of attribute serialization implementation?
+//
 // Revision 3.13  2009/02/27 13:26:46  taurel
 // - Small changes for Solaris
 //
@@ -317,8 +320,11 @@ void PollObj::insert_data(Tango::AttributeValueList_4 *res,
 			  struct timeval &needed)
 {
 	omni_mutex_lock(*this);
-	
-	ring.insert_data(res,when);
+
+	bool unlock = true;
+	if ((needed.tv_sec == 0) && (needed.tv_usec == 0))
+		unlock = false;	
+	ring.insert_data(res,when,unlock);
 	needed_time = needed;
 }
 
