@@ -1,4 +1,4 @@
-static const char *RcsId = "$Id: pollring.cpp,v 3.20 2009/03/18 12:18:45 taurel Exp $\n$Name:  $";
+static const char *RcsId = "$Id: pollring.cpp,v 3.24 2009/11/09 12:04:31 taurel Exp $\n$Name: Release_7_1_1 $";
 
 //+============================================================================
 //
@@ -34,9 +34,21 @@ static const char *RcsId = "$Id: pollring.cpp,v 3.20 2009/03/18 12:18:45 taurel
 // You should have received a copy of the GNU Lesser General Public License
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 //
-// $Revision: 3.20 $
+// $Revision: 3.24 $
 //
 // $Log: pollring.cpp,v $
+// Revision 3.24  2009/11/09 12:04:31  taurel
+// - The attribute mutex management is in the AttributeValue_4 struct
+//
+// Revision 3.23  2009/11/02 08:35:47  taurel
+// - Fix warnings reported when compiling using the option -Wall
+//
+// Revision 3.22  2009/09/18 09:18:06  taurel
+// - End of attribute serialization implementation?
+//
+// Revision 3.21  2009/09/17 08:28:06  taurel
+// - Add a mutual exclusion to protect attribute buffer
+//
 // Revision 3.20  2009/03/18 12:18:45  taurel
 // - Fix warnings reported when compiled with the option -Wall
 //
@@ -413,7 +425,7 @@ void PollRing::insert_data(Tango::AttributeValueList_3 *attr_val,struct timeval
 	inc_indexes();
 }
 
-void PollRing::insert_data(Tango::AttributeValueList_4 *attr_val,struct timeval &t)
+void PollRing::insert_data(Tango::AttributeValueList_4 *attr_val,struct timeval &t,bool unlock)
 {
 	
 //
@@ -428,6 +440,19 @@ void PollRing::insert_data(Tango::AttributeValueList_4 *attr_val,struct timeval
 	ring[insert_elt].when = t;
 
 	force_copy_data(ring[insert_elt].attr_value_4);
+	
+//
+// Release attribute mutexes because the data are now copied
+//
+
+	if (unlock == true)
+	{
+		for (unsigned int loop = 0;loop < attr_val->length();loop++)
+		{
+			Tango::AttributeValue_4 *tmp_ptr = &((*attr_val)[loop]);
+			(tmp_ptr)->rel_attr_mutex();
+		}
+	}
 				
 //
 // Manage insert and read indexes
@@ -451,7 +476,7 @@ void PollRing::insert_data(Tango::AttributeValueList_4 *attr_val,struct timeval
 //						union sequence replace call
 //					3 - Transfer the data from the temporary sequence within the
 //						union sequence using again the sequence replace call
-//						in order not to trgiier a real data copy
+//						in order not to trigger a real data copy
 //
 // argument : in : 	- attr_value_4 : The exception to be stored
 //
@@ -1395,7 +1420,7 @@ void PollRing::get_cmd_history(long n,Tango::DevCmdHistory_4 *ptr,Tango::CmdArgT
 				}
 				(*ring[index].cmd_result) >>= tmp_uch;
 				ADD_ELT_DATA_TO_GLOBAL_SEQ(new_tmp_uch,tmp_uch,ind_in_seq);
-				MANAGE_DIM_ARRAY(tmp_uch->length());
+				MANAGE_DIM_ARRAY((long)tmp_uch->length());
 				break;
 
 			case DEV_SHORT:
@@ -1417,7 +1442,7 @@ void PollRing::get_cmd_history(long n,Tango::DevCmdHistory_4 *ptr,Tango::CmdArgT
 				}
 				(*ring[index].cmd_result) >>= tmp_sh;
 				ADD_ELT_DATA_TO_GLOBAL_SEQ(new_tmp_sh,tmp_sh,ind_in_seq);
-				MANAGE_DIM_ARRAY(tmp_sh->length());
+				MANAGE_DIM_ARRAY((long)tmp_sh->length());
 				break;
 
 			case DEV_LONG:
@@ -1439,7 +1464,7 @@ void PollRing::get_cmd_history(long n,Tango::DevCmdHistory_4 *ptr,Tango::CmdArgT
 				}
 				(*ring[index].cmd_result) >>= tmp_lg;
 				ADD_ELT_DATA_TO_GLOBAL_SEQ(new_tmp_lg,tmp_lg,ind_in_seq);
-				MANAGE_DIM_ARRAY(tmp_lg->length());
+				MANAGE_DIM_ARRAY((long)tmp_lg->length());
 				break;
 
 			case DEV_FLOAT:
@@ -1461,7 +1486,7 @@ void PollRing::get_cmd_history(long n,Tango::DevCmdHistory_4 *ptr,Tango::CmdArgT
 				}
 				(*ring[index].cmd_result) >>= tmp_fl;
 				ADD_ELT_DATA_TO_GLOBAL_SEQ(new_tmp_fl,tmp_fl,ind_in_seq);
-				MANAGE_DIM_ARRAY(tmp_fl->length());
+				MANAGE_DIM_ARRAY((long)tmp_fl->length());
 				break;
 
 			case DEV_DOUBLE:
@@ -1483,7 +1508,7 @@ void PollRing::get_cmd_history(long n,Tango::DevCmdHistory_4 *ptr,Tango::CmdArgT
 				}
 				(*ring[index].cmd_result) >>= tmp_db;
 				ADD_ELT_DATA_TO_GLOBAL_SEQ(new_tmp_db,tmp_db,ind_in_seq);
-				MANAGE_DIM_ARRAY(tmp_db->length());
+				MANAGE_DIM_ARRAY((long)tmp_db->length());
 				break;
 
 			case DEV_USHORT:
@@ -1505,7 +1530,7 @@ void PollRing::get_cmd_history(long n,Tango::DevCmdHistory_4 *ptr,Tango::CmdArgT
 				}
 				(*ring[index].cmd_result) >>= tmp_ush;
 				ADD_ELT_DATA_TO_GLOBAL_SEQ(new_tmp_ush,tmp_ush,ind_in_seq);
-				MANAGE_DIM_ARRAY(tmp_ush->length());
+				MANAGE_DIM_ARRAY((long)tmp_ush->length());
 				break;
 
 			case DEV_ULONG:
@@ -1527,7 +1552,7 @@ void PollRing::get_cmd_history(long n,Tango::DevCmdHistory_4 *ptr,Tango::CmdArgT
 				}
 				(*ring[index].cmd_result) >>= tmp_ulg;
 				ADD_ELT_DATA_TO_GLOBAL_SEQ(new_tmp_ulg,tmp_ulg,ind_in_seq);
-				MANAGE_DIM_ARRAY(tmp_ulg->length());
+				MANAGE_DIM_ARRAY((long)tmp_ulg->length());
 				break;
 
 			case DEV_STRING:
@@ -1549,7 +1574,7 @@ void PollRing::get_cmd_history(long n,Tango::DevCmdHistory_4 *ptr,Tango::CmdArgT
 				}
 				(*ring[index].cmd_result) >>= tmp_str;
 				ADD_ELT_DATA_TO_GLOBAL_SEQ(new_tmp_str,tmp_str,ind_in_seq);
-				MANAGE_DIM_ARRAY(tmp_str->length());
+				MANAGE_DIM_ARRAY((long)tmp_str->length());
 				break;
 
 			case DEV_BOOLEAN:
@@ -1571,7 +1596,7 @@ void PollRing::get_cmd_history(long n,Tango::DevCmdHistory_4 *ptr,Tango::CmdArgT
 				}
 				(*ring[index].cmd_result) >>= tmp_boo;
 				ADD_ELT_DATA_TO_GLOBAL_SEQ(new_tmp_boo,tmp_boo,ind_in_seq);
-				MANAGE_DIM_ARRAY(tmp_boo->length());
+				MANAGE_DIM_ARRAY((long)tmp_boo->length());
 				break;
 
 			case DEV_LONG64:
@@ -1593,7 +1618,7 @@ void PollRing::get_cmd_history(long n,Tango::DevCmdHistory_4 *ptr,Tango::CmdArgT
 				}
 				(*ring[index].cmd_result) >>= tmp_lg64;
 				ADD_ELT_DATA_TO_GLOBAL_SEQ(new_tmp_lg64,tmp_lg64,ind_in_seq);
-				MANAGE_DIM_ARRAY(tmp_lg64->length());
+				MANAGE_DIM_ARRAY((long)tmp_lg64->length());
 				break;
 
 			case DEV_ULONG64:
@@ -1615,7 +1640,7 @@ void PollRing::get_cmd_history(long n,Tango::DevCmdHistory_4 *ptr,Tango::CmdArgT
 				}
 				(*ring[index].cmd_result) >>= tmp_ulg64;
 				ADD_ELT_DATA_TO_GLOBAL_SEQ(new_tmp_ulg64,tmp_ulg64,ind_in_seq);
-				MANAGE_DIM_ARRAY(tmp_ulg64->length());
+				MANAGE_DIM_ARRAY((long)tmp_ulg64->length());
 				break;
 				
 			case DEVVAR_LONGSTRINGARRAY:
@@ -1628,7 +1653,7 @@ void PollRing::get_cmd_history(long n,Tango::DevCmdHistory_4 *ptr,Tango::CmdArgT
 				(*ring[index].cmd_result) >>= tmp_lg_str;
 				ADD_ELT_DATA_TO_GLOBAL_SEQ_BY_REF(new_tmp_lg_str->svalue,tmp_lg_str->svalue,ind_str_in_seq);
 				ADD_ELT_DATA_TO_GLOBAL_SEQ_BY_REF(new_tmp_lg_str->lvalue,tmp_lg_str->lvalue,ind_num_in_seq);
-				MANAGE_DIM_ARRAY_SEQ(tmp_lg_str->svalue.length(),tmp_lg_str->lvalue.length());
+				MANAGE_DIM_ARRAY_SEQ((long)tmp_lg_str->svalue.length(),(long)tmp_lg_str->lvalue.length());
 				break;
 				
 			case DEVVAR_DOUBLESTRINGARRAY:
@@ -1641,7 +1666,7 @@ void PollRing::get_cmd_history(long n,Tango::DevCmdHistory_4 *ptr,Tango::CmdArgT
 				(*ring[index].cmd_result) >>= tmp_db_str;
 				ADD_ELT_DATA_TO_GLOBAL_SEQ_BY_REF(new_tmp_db_str->svalue,tmp_db_str->svalue,ind_str_in_seq);
 				ADD_ELT_DATA_TO_GLOBAL_SEQ_BY_REF(new_tmp_db_str->dvalue,tmp_db_str->dvalue,ind_num_in_seq);
-				MANAGE_DIM_ARRAY_SEQ(tmp_db_str->svalue.length(),tmp_db_str->dvalue.length());
+				MANAGE_DIM_ARRAY_SEQ((long)tmp_db_str->svalue.length(),(long)tmp_db_str->dvalue.length());
 				break;
 				
 			default:
