@@ -31,9 +31,12 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 //
-// $Revision: 3.9 $
+// $Revision: 3.10 $
 //
 // $Log: pollring.h,v $
+// Revision 3.10  2009/09/18 09:18:06  taurel
+// - End of attribute serialization implementation?
+//
 // Revision 3.9  2009/01/21 12:47:15  taurel
 // - Change CopyRights for 2009
 //
@@ -233,7 +236,7 @@ public:
 	void insert_data(CORBA::Any *,struct timeval &);
 	void insert_data(Tango::AttributeValueList *,struct timeval &);
 	void insert_data(Tango::AttributeValueList_3 *,struct timeval &);
-	void insert_data(Tango::AttributeValueList_4 *,struct timeval &);
+	void insert_data(Tango::AttributeValueList_4 *,struct timeval &,bool);
 	void insert_except(Tango::DevFailed *,struct timeval &);
 
 	void force_copy_data(Tango::AttributeValueList_4 *);
