@@ -1,4 +1,4 @@
-static const char *RcsId = "$Id: pollthread.cpp,v 3.26 2009/02/16 09:30:37 jensmeyer Exp $\n$Name:  $";
+static const char *RcsId = "$Id: pollthread.cpp,v 3.27 2009/10/23 14:36:27 taurel Exp $\n$Name: Release_7_1_1 $";
 
 //+============================================================================
 //
@@ -33,9 +33,15 @@ static const char *RcsId = "$Id: pollthread.cpp,v 3.26 2009/02/16 09:30:37 jensm
 // You should have received a copy of the GNU Lesser General Public License
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 //
-// $Revision: 3.26 $
+// $Revision: 3.27 $
 //
 // $Log: pollthread.cpp,v $
+// Revision 3.27  2009/10/23 14:36:27  taurel
+// - Tango 7.1.1
+// - Fix bugs 2880372 and 2881841
+// - Now support event in case of Tango system with multi db server
+// - The polling threads start with polling inactive
+//
 // Revision 3.26  2009/02/16 09:30:37  jensmeyer
 // Modified print_list() method to handle sub device diagnostics.
 //
@@ -306,7 +312,7 @@ PollObjType PollThread::type_to_del = Tango::POLL_CMD;
 //--------------------------------------------------------------------------
 
 PollThread::PollThread(PollThCmd &cmd,TangoMonitor &m,bool heartbeat): shared_cmd(cmd),p_mon(m),
-					    sleep(1),polling_stop(false),
+					    sleep(1),polling_stop(true),
 					    attr_names(1),tune_ctr(1),
 					    need_two_tuning(false),auto_upd(-1),send_heartbeat(heartbeat)
 {
@@ -315,6 +321,9 @@ PollThread::PollThread(PollThCmd &cmd,TangoMonitor &m,bool heartbeat): shared_cm
 	cci = 0;
 	dummy_cl_id.cpp_clnt(cci);
 	
+	if (heartbeat == true)
+		polling_stop = false;
+	
 #ifdef _TG_WINDOWS_
 	LARGE_INTEGER f;
 	BOOL is_ctr;
