@@ -10,9 +10,45 @@
 //
 // author(s) :          E.Taurel
 //
-// $Revision: 3.4 $
+// Copyright (C) :      2004,2005,2006,2007,2008,2009
+//						European Synchrotron Radiation Facility
+//                      BP 220, Grenoble 38043
+//                      FRANCE
+//
+// This file is part of Tango.
+//
+// Tango is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+// 
+// Tango is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+// 
+// You should have received a copy of the GNU Lesser General Public License
+// along with Tango.  If not, see <http://www.gnu.org/licenses/>.
+//
+// $Revision: 3.8 $
 //
 // $Log: seqvec.h,v $
+// Revision 3.8  2009/01/21 12:49:03  taurel
+// - Change CopyRights for 2009
+//
+// Revision 3.7  2008/10/06 15:01:36  taurel
+// - Changed the licensing info from GPL to LGPL
+//
+// Revision 3.6  2008/10/03 06:53:09  taurel
+// - Add some licensing info in each files
+//
+// Revision 3.5  2008/05/20 12:44:14  taurel
+// - Commit after merge with release 7 branch
+//
+// Revision 3.4.2.1  2008/05/20 06:17:46  taurel
+// - Last commit before merge with trunk
+// (start the implementation of the new DevEncoded data type)
+//
 // Revision 3.4  2007/04/16 14:57:42  taurel
 // - Added 3 new attributes data types (DevULong, DevULong64 and DevState)
 // - Ported to omniORB4.1
@@ -117,10 +153,6 @@
 // New methods re_throw_exception(). Read_attributes supports AllAttr mnemonic A new add_attribute()method in DeviceImpl class New way to define attribute properties New pattern to prevent full re-compile For multi-classes DS, it is now possible to use the Util::get_device_by_name() method in device constructor Adding << operator ovebloading Fix devie CORBA ref. number when device constructor sends an excep.
 //
 //
-// copyleft :           European Synchrotron Radiation Facility
-//                      BP 220, Grenoble 38043
-//                      FRANCE
-//
 //=============================================================================
 
 #ifndef _SECVEC_H
@@ -738,6 +770,15 @@ ostream &operator<<(ostream &lval,const DevVarStringArray &rval);
  * @param rval The DevVarStateArray sequence to be printed
  */
 ostream &operator<<(ostream &lval,const DevVarStateArray &rval);
+/**
+ * Print a DevVarEncodedArray.
+ *
+ * One line is printed for each sequence element.
+ *
+ * @param lval The C++ stream used for printing
+ * @param rval The DevVarEncodedArray sequence to be printed
+ */
+ostream &operator<<(ostream &lval,const DevVarEncodedArray &rval);
 //@}
 
 //#endif // TANGO_HAS_LOG4TANGO
