@@ -1,4 +1,4 @@
-static const char *RcsId = "$Id: subdev_diag.cpp,v 1.7 2009/04/29 14:34:09 jensmeyer Exp $\n$Name:  $";
+static const char *RcsId = "$Id: subdev_diag.cpp,v 1.8 2009/09/07 15:05:39 taurel Exp $\n$Name: Release_7_1_1 $";
 
 //+=============================================================================
 //
@@ -31,9 +31,12 @@ static const char *RcsId = "$Id: subdev_diag.cpp,v 1.7 2009/04/29 14:34:09 jensm
 // You should have received a copy of the GNU Lesser General Public License
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 //
-// $Revision: 1.7 $
+// $Revision: 1.8 $
 //
 // $Log: subdev_diag.cpp,v $
+// Revision 1.8  2009/09/07 15:05:39  taurel
+// - Fix a small typos in printed message
+//
 // Revision 1.7  2009/04/29 14:34:09  jensmeyer
 // Added some more debug info.
 //
@@ -105,7 +108,7 @@ SubDevDiag::~SubDevDiag()
 
 void SubDevDiag::set_associated_device(string dev_name) 
 {
-	cout4 << "SubDevDiag::get_associated_device() entering ... ";
+	cout4 << "SubDevDiag::set_associated_device() entering ... ";
 	
 	// get thread
 	omni_thread *th = omni_thread::self();
