@@ -1,4 +1,4 @@
-static const char *RcsId = "$Id: utils.cpp,v 3.58 2009/03/18 10:23:12 taurel Exp $\n$Name:  $";
+static const char *RcsId = "$Id: utils.cpp,v 3.61 2009/10/26 13:49:54 taurel Exp $\n$Name: Release_7_1_1 $";
 
 //+=============================================================================
 //
@@ -31,9 +31,19 @@ static const char *RcsId = "$Id: utils.cpp,v 3.58 2009/03/18 10:23:12 taurel Exp
 // You should have received a copy of the GNU Lesser General Public License
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 //
-// $Revision: 3.58 $
+// $Revision: 3.61 $
 //
 // $Log: utils.cpp,v $
+// Revision 3.61  2009/10/26 13:49:54  taurel
+// - Add an exception case in the Util::get_device_list_by_class() method
+//
+// Revision 3.60  2009/09/03 15:26:32  taurel
+// - Wrongly spell _TG_WINDOWS_ !!
+//
+// Revision 3.59  2009/06/17 08:44:45  taurel
+// - Unix servers are now listenning also on a UNIX domain socket for
+// looback communication
+//
 // Revision 3.58  2009/03/18 10:23:12  taurel
 // - Fix bug for Windows in GUI mode
 //
@@ -144,264 +154,6 @@ static const char *RcsId = "$Id: utils.cpp,v 3.58 2009/03/18 10:23:12 taurel Exp
 // - Add DB server cache in DS used during DS startup sequence
 // - Comment out the sleep time during DS startup sequence
 //
-// Revision 3.29  2007/05/17 07:59:07  taurel
-// - The polling is not configured via a separate thread any more. The polling thread add_obj_polling method has been modified to support a parameter telling to the polling thread when it has to polled the object.
-// Add device name in monitor print message
-// Add device_destroyer method in DeviceClass class
-//
-// Revision 3.28  2007/05/15 07:46:59  taurel
-// - The polling thread is not configured by a separate thread any more.
-// The Add_obj_polling command now support a delta_t to start the first polling
-//
-// Revision 3.27  2007/04/20 14:41:34  taurel
-// - Ported to Windows 64 bits x64 architecture
-//
-// Revision 3.26  2007/04/16 14:57:45  taurel
-// - Added 3 new attributes data types (DevULong, DevULong64 and DevState)
-// - Ported to omniORB4.1
-// - Increased the MAX_TRANSFER_SIZE to 256 MBytes
-// - Added a new filterable field in the archive event
-//
-// Revision 3.25  2007/03/29 07:11:06  taurel
-// - Change some data types for 64 bits compatibility
-//
-// Revision 3.24  2007/03/12 15:16:57  taurel
-// - Change the way to return Tango lib release
-//
-// Revision 3.23  2007/03/06 08:19:03  taurel
-// - Added 64 bits data types for 64 bits computer...
-//
-// Revision 3.22  2007/02/16 10:40:57  taurel
-// - Implementing a new types of event on the Attribute configuration
-//
-// Revision 3.21  2007/01/19 15:45:53  taurel
-// - Added the Utils::get_tango_lib_release() method
-//
-// Revision 3.20  2006/10/06 06:46:53  jensmeyer
-// Corrected omnithread initialisation in server_init in the case of a windows service.
-//
-// Revision 3.19  2006/05/25 10:21:23  taurel
-// - Create the per-thread data for main thread in server_init() method instead of server_run(). It was the reason of a seg fault when DS aborted in its startup sequence due to device init_device() method throwing exception
-//
-// Revision 3.18  2006/05/18 09:31:17  taurel
-// - Oups a bug in C++ server introduced by the port of Python DS to windows.Now, it  is fixed.
-//
-// Revision 3.17  2006/05/18 08:51:56  taurel
-// - Miscellaneous changes due to Python device server ported to Windows
-// - Fix some bugs discovered by Windows VC8 using the test suite
-// - Update Windows resource file include path
-// - Fix some Windows VC8 warnings
-//
-// Revision 3.16  2006/02/20 08:16:25  taurel
-// - Add a new method in DeviceClass to delete a device at run-time
-//
-// Revision 3.15  2006/02/17 16:49:57  jensmeyer
-// Corrections when porting to VC7 under windows
-//
-// Revision 3.14  2006/01/20 08:38:39  taurel
-// - Added necessary changes to support Device server written in Python
-//
-// Revision 3.13  2005/08/09 15:47:34  jensmeyer
-// Changed the clean-up mechanism when shutting down
-// the ORB. Destroy ORB when returning from run().
-//
-// Revision 3.12  2005/06/29 08:31:19  taurel
-// - Last commit before release 5.2 ?
-//
-// Revision 3.11  2005/05/25 06:05:40  taurel
-// - Again some minors changes before 5.2
-//
-// Revision 3.10  2005/05/10 16:10:18  taurel
-// - Fix windows VC7 warnings
-//
-// Revision 3.9  2005/04/15 11:34:07  taurel
-// - Changes to support Tango on 64 bits computer
-// - Support for Linux 2.6 kernel with NPTL (Signal management)
-//
-// Revision 3.8  2005/03/14 09:49:29  taurel
-// - Fix some bugs in filedatabase (Change in the data transferred between client and
-//   server).
-// - Fix bug in event re-connection
-// - Add event support even for device server started with the -file command line option
-//
-// Revision 3.7  2005/01/13 08:30:36  taurel
-// - Merge trunk with Release_5_0 from brach Release_5_branch
-//
-// Revision 3.6.2.11  2004/12/06 14:39:30  taurel
-// - Polling starts in a separate thread
-// - For Windows : Polling thread cmd/attr measurement used PerformanceCounter
-// - Fix bug in pollext.h in methods to externally fill polling buffer
-//
-// Revision 3.6.2.10  2004/11/26 13:53:21  taurel
-// - Fix bug if exception thrown during Util class construction
-// - Change attribute label and format default values
-//
-// Revision 3.6.2.9  2004/11/10 13:00:55  taurel
-// - Some minor changes for the WIN32 port
-//
-// Revision 3.6.2.8  2004/11/09 09:57:49  taurel
-// - Fix one memory leak and some minor changes
-// - Force database file writing when server exit
-// - Some minor changes for the -file option for WIN32
-//
-// Revision 3.6.2.7  2004/10/27 05:59:47  taurel
-// - Some minor changes to compile on all our supported platforms
-//
-// Revision 3.6.2.6  2004/10/22 11:26:33  taurel
-// Added warning alarm
-// Change attribute config. It now includes alarm and event parameters
-// Array attribute property now supported
-// subscribe_event throws exception for change event if they are not correctly configured
-// Change in the polling thread: The event heartbeat has its own work in the work list
-// Also add some event_unregister
-// Fix order in which classes are destructed
-// Fix bug in asynchronous mode (PUSH_CALLBACK). The callback thread ate all the CPU
-// Change in the CORBA info call for the device type
-//
-// Revision 3.6.2.5  2004/10/14 07:54:35  maxchiandone
-// avoid starting with -nodb and -file together
-//
-// Revision 3.6.2.4  2004/10/05 13:55:03  maxchiandone
-// First upload for filedatabase.
-//
-// Revision 3.6.2.3  2004/09/15 06:47:17  taurel
-// - Added four new types for attributes (boolean, float, unsigned short and unsigned char)
-// - It is also possible to read state and status as attributes
-// - Fix bug in Database::get_class_property() method (missing ends insertion)
-// - Fix bug in admin device DevRestart command (device name case problem)
-//
-// Revision 3.6.2.2  2004/07/15 15:04:06  taurel
-// - Added the way to externally filled the polling buffer for attribute
-//   (Command will come soon)
-//
-// Revision 3.6.2.1  2004/07/08 11:02:13  taurel
-// - Add possibility to have command/attribute polling buffer depth specified
-//   individually
-//
-// Revision 3.6  2004/07/07 08:40:13  taurel
-//
-// - Fisrt commit after merge between Trunk and release 4 branch
-// - Add EventData copy ctor, asiignement operator and dtor
-// - Add Database and DeviceProxy::get_alias() method
-// - Add AttributeProxy ctor from "device_alias/attribute_name"
-// - Exception thrown when subscribing two times for exactly yhe same event
-//
-// Revision 3.5  2003/08/21 07:24:37  taurel
-// - End of the implementation of the new way to transfer data for read and
-//   write attributes (better use of exception)
-// - Added Attribute::set_date() and Attribute::set_value_date_quality() methods
-// - Added DeviceAttribute ctors from "const char *"
-// - Enable writing of spectrum and image attributes
-// - Many new DeviceAttribute ctors/inserters to enable easy image and spectrums
-//   attribute writing
-// - Attribute date automatically set in case of attribute quality factor set to INVALID
-// - Change in the polling thread discarding element algo. to support case of polling
-//   several cmd/atts at the same polling period with cmd/attr having a long response time
-// - Take cmd/attr execution time into account in the "Data not updated since" polling
-//   status string
-// - Split "str().c_str()" code in two lines of code. It was the reason of some problem
-//   on Windows device server
-// - Add the possibility to set a cmd/attr polling as "externally triggered". Add method
-//   to send trigger to the polling thread
-//
-// Revision 3.4  2003/07/03 07:40:51  taurel
-// - Change in Tango IDL file : Implement a new way to tranfer data for read_attribute and write_attribute CORBA operation
-// - Handle this new IDL release in DeviceProxy class
-// - New exception methods in DeviceAttribute class
-// - New way to get data out of DeviceAttribute object
-// - Fix bugs in DeviceProxy copy constructor and assignement operator
-// - Change some method names in DeviceDataHistory and DeviceAttributeHistory classes
-// - Change the implementation of the DeviceProxy::write_attribute() method to avoid DeviceAttribute copying
-// - Clean-up how a server is killed via a CTRL-C or a dserver device kill command
-// - Add a server_cleanup() method in the Util class
-// - Win32 : Update debug menu in the server graphical window to support logging feature
-// - Win32 : Display library CVS tag in the "Help->About" sub-window
-//
-// Revision 3.3.2.11  2004/05/17 15:33:35  taurel
-// - Add code in polling_configure() method to make the main thread known to
-//   omni threads for Windows DS used as services with polled command/attributes
-//
-// Revision 3.3.2.10  2004/03/09 16:36:37  taurel
-// - Added HP aCC port (thanks to Claudio from Elettra)
-// - Some last small bugs fixes
-//
-// Revision 3.3.2.9  2004/02/27 16:47:01  taurel
-// - Updated DeviceImpl and Util classes sizes for compatibility
-//
-// Revision 3.3.2.8  2004/02/25 16:27:44  taurel
-// Minor changes to compile library using Solaris CC compiler
-//
-// Revision 3.3.2.7  2004/02/18 15:06:18  taurel
-// Now the DevRestart command immediately restart device event (if any). Previously, it was possible to wait up to 200 secondes before they
-// restart
-//
-// Revision 3.3.2.6  2004/02/06 11:58:52  taurel
-// - Many changes in the event system
-//
-// Revision 3.3.2.5  2004/01/20 08:32:37  taurel
-// -First commit after merge with the event branch and work on the AttributeProxy class
-// - Fix bug in the stream "clear()" method usage when used with gcc 3.3
-//
-// Revision 3.3.2.4  2003/11/28 17:08:44  taurel
-// Changes to handle tango lib build as a Windows DLL and used in a device
-// server
-//
-// Revision 3.3.2.2  2003/10/03 13:34:26  taurel
-// - Fix bug for device server started without database, with device name specified on command line using mix of upper and lower cases
-// - It's now possible to send a command to the polling thread from itself
-// - Add a release lock if the insert into the polling buffer failed
-//
-// Revision 3.3.2.1  2003/09/30 11:49:25  taurel
-// Add some changes foreseen for release 4.1 and already implemented on
-// the trunck into this release 4.0 branch
-//
-// Revision 3.3  2003/05/28 14:55:10  taurel
-// Add the include (conditionally) of the include files generated by autoconf
-//
-// Revision 3.2  2003/05/16 08:46:16  taurel
-// Many changes for release 3.0.1. The most important ones are :
-// - Timeout are backs
-// - Multiple db servers (change in TANGO_HOST syntax)
-// - Added methods to print DeviceData, DeviceDataHistory, DeviceAttribute and DeviceAttributeHistory instances
-// - Attributes name stored in blackbox
-// - Remove check if a class is created without any device
-// - It's now possible to create a DeviceProxy from its alias name
-// - Command, attribute names are case insensitive
-// - Change parameters of some DeviceProxy logging methods
-// - Change parameters of DeviceProxy asynchronous replies calls
-// - New serialization model in device server (no serialization model)
-// - Win32 (2000) device server service does not exit at loggoff anymore
-// - Miscellaneous bug fixes
-//
-// Revision 3.1  2003/04/02 12:26:04  taurel
-// Miscellaneous changes to :
-//  - Modify TANGO_HOST env. variable syntax to be able to have several db servers
-//  - Asynchronous calls are now done on device_2 or device depending on the device IDL version
-//  - Timeout are bcks (omniORB 4.0.1)
-//  - Fix bug when killing a device server via the kill command of the admin device
-//    (Solaris only)
-//  - Cleanup device server code to have only one ORB and one db connection within a server
-// Revision 3.0.2.2  2003/07/17 03:46:46  andy_gotz
-// Added new events "on_valid" and "on_state_change"; factorized EventSupplier::detect_and_push_events() method;
-// Catching more exceptions when creating EventSupplier, device server will start without Notification service;
-// Added AttributeProxy and DbAttribute classes to api; created test programs in test directory
-//
-// Revision 3.0.2.1  2003/04/08 13:12:53  andy_gotz
-// first version of TANGO events
-//
-// Revision 3.0  2003/03/25 16:47:51  taurel
-// Many changes for Tango release 3.0 including
-// - Added full logging features
-// - Added asynchronous calls
-// - Host name of clients now stored in black-box
-// - Three serialization model in DS
-// - Fix miscellaneous bugs
-// - Ported to gcc 3.2
-// - Added ApiUtil::cleanup() and destructor methods
-// - Some internal cleanups
-// - Change the way how TangoMonitor class is implemented. It's a recursive
-//   mutex
-//
 //-=============================================================================
 
 #if HAVE_CONFIG_H
@@ -614,6 +366,10 @@ void Util::effective_job(int argc,char *argv[])
 			{"supportCurrent","0"},
 			{"verifyObjectExistsAndType","0"},
 			{"giopMaxMsgSize",MAX_TRANSFER_SIZE},
+#ifndef _TG_WINDOWS_
+			{"endPoint","giop:tcp::"},
+			{"endPoint","giop:unix:"},
+#endif
 			{0,0}};
 			
 			orb = CORBA::ORB_init(argc,argv,"omniORB4",options);
@@ -630,10 +386,15 @@ void Util::effective_job(int argc,char *argv[])
 			{"supportCurrent","0"},
 			{"verifyObjectExistsAndType","0"},
 			{"giopMaxMsgSize",MAX_TRANSFER_SIZE},
+#ifndef _TG_WINDOWS_
+			{"endPoint","giop:tcp::"},
+			{"endPoint","giop:unix:"},
+#endif
 			{0,0}};
 			
 			orb = CORBA::ORB_init(argc,argv,"omniORB4",options);
 		}
+		
 
 #ifndef TANGO_HAS_LOG4TANGO
 
@@ -2143,6 +1904,13 @@ void Util::server_cleanup()
 vector<DeviceImpl *> &Util::get_device_list_by_class(const string &class_name)
 {
 
+	if (cl_list_ptr == NULL)
+	{
+		Except::throw_exception((const char *)"API_DeviceNotFound",
+				        (const char *)"It's too early to call this method. Devices are not created yet!",
+				        (const char *)"Util::get_device_list_by_class()");
+	}
+	
 //
 // Retrieve class list. Don't use the get_dserver_device() method followed by
 // the get_class_list(). In case of several classes embedded within
