@@ -1,4 +1,4 @@
-static const char *RcsId = "$Id: utils_polling.cpp,v 3.9 2009/04/01 06:31:25 taurel Exp $";
+static const char *RcsId = "$Id: utils_polling.cpp,v 3.12 2009/11/10 12:08:28 taurel Exp $";
 
 //+=============================================================================
 //
@@ -31,9 +31,21 @@ static const char *RcsId = "$Id: utils_polling.cpp,v 3.9 2009/04/01 06:31:25 tau
 // You should have received a copy of the GNU Lesser General Public License
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 //
-// $Revision: 3.9 $
+// $Revision: 3.12 $
 //
 // $Log: utils_polling.cpp,v $
+// Revision 3.12  2009/11/10 12:08:28  taurel
+// - Change the default value for the UtilExt::poll_pool_size data member
+//
+// Revision 3.11  2009/11/02 08:35:47  taurel
+// - Fix warnings reported when compiling using the option -Wall
+//
+// Revision 3.10  2009/08/27 07:23:45  taurel
+// - Commit after another merge with Release_7_0_2-bugfixes branch
+//
+// Revision 3.9.2.1  2009/07/02 07:07:27  taurel
+// - Fix a string comparaison problem (lowercase - uppercase)
+//
 // Revision 3.9  2009/04/01 06:31:25  taurel
 // - Only some changes in printed messages when using -v5
 //
@@ -771,7 +783,7 @@ int Util::create_poll_thread(const char *dev_name,bool startup,int smallest_upd)
 //
 // Check if the pool is full
 //
-	
+
 	if (ext->poll_ths.size() != ext->poll_pool_size)
 	{
 
@@ -1100,7 +1112,7 @@ PollingThreadInfo *Util::get_polling_thread_info_by_id(int th_id)
 //
 //-----------------------------------------------------------------------------
 
-void Util::check_pool_conf(DServer *admin_dev,long pool_size)
+void Util::check_pool_conf(DServer *admin_dev,unsigned long pool_size)
 {
 
 //
@@ -1147,7 +1159,10 @@ void Util::check_pool_conf(DServer *admin_dev,long pool_size)
 //
 // Check if the device is instanciated in this server
 //
-			
+	
+			string entry_lower(*iter_entry);
+			transform(entry_lower.begin(),entry_lower.end(),entry_lower.begin(),::tolower);
+					
 			for (loop = 0;loop < nb_dev;++loop)
 			{
 				string real_dev_name((*dev_list)[loop]);
@@ -1156,7 +1171,9 @@ void Util::check_pool_conf(DServer *admin_dev,long pool_size)
 				pos = pos + 2;
 				real_dev_name = real_dev_name.substr(pos);
 				
-				if (*iter_entry == real_dev_name)
+				transform(real_dev_name.begin(),real_dev_name.end(),real_dev_name.begin(),::tolower);
+				
+				if (entry_lower == real_dev_name)
 					break;
 			}
 
@@ -1234,7 +1251,7 @@ void Util::check_pool_conf(DServer *admin_dev,long pool_size)
 		{
 			vector<string> polled_dev_th;
 			get_th_polled_devs(i + pool_size,polled_dev_th);
-			int loop = 0;
+			unsigned long loop = 0;
 			vector<string>::iterator it;
 			for (it = polled_dev_th.begin();it != polled_dev_th.end();++it)
 			{
